@@ -48,10 +48,12 @@
 /* ************************************************************************ */
 
 // Declarations
-#include "CMakeBuilder.h"
 #include "CMakeGenerator.h"
+
+#include "CMakeBuilder.h"
 #include "fileextmanager.h"
 #include "fileutils.h"
+
 #include <algorithm>
 
 // wxWidgets
@@ -65,23 +67,32 @@
 #include "globals.h"
 
 #define CODELITE_CMAKE_PREFIX "# -*- CMakeLists.txt generated by CodeLite IDE. Do not edit by hand -*-"
+#define CMAKELISTS_USER_CODE_01_PREFIX "#{{{{ User Code 01"
+#define CMAKELISTS_USER_CODE_02_PREFIX "#{{{{ User Code 02"
 #define CMAKELISTS_USER_CODE_1_PREFIX "#{{{{ User Code 1"
 #define CMAKELISTS_USER_CODE_2_PREFIX "#{{{{ User Code 2"
 #define CMAKELISTS_USER_CODE_3_PREFIX "#{{{{ User Code 3"
 #define CMAKELISTS_USER_CODE_END "#}}}}"
 
-static wxArrayString wxArrayUniqueMerge(const wxArrayString& arr1, const wxArrayString& arr2)
+namespace
+{
+wxArrayString wxArrayUniqueMerge(const wxArrayString& arr1, const wxArrayString& arr2)
 {
     wxArrayString outArr;
     for(size_t i = 0; i < arr1.size(); ++i) {
-        if(outArr.Index(arr1.Item(i)) == wxNOT_FOUND) { outArr.Add(arr1.Item(i)); }
+        if(outArr.Index(arr1.Item(i)) == wxNOT_FOUND) {
+            outArr.Add(arr1.Item(i));
+        }
     }
 
     for(size_t i = 0; i < arr2.size(); ++i) {
-        if(outArr.Index(arr2.Item(i)) == wxNOT_FOUND) { outArr.Add(arr2.Item(i)); }
+        if(outArr.Index(arr2.Item(i)) == wxNOT_FOUND) {
+            outArr.Add(arr2.Item(i));
+        }
     }
     return outArr;
 }
+} // namespace
 
 CMakeGenerator::CMakeGenerator()
     : m_counter(0)
@@ -156,37 +167,24 @@ bool CMakeGenerator::Generate(ProjectPtr p)
     const wxFileName filename(p->GetFileName().GetPath(), CMakePlugin::CMAKELISTS_FILE);
 
     // Check for file existance and read any user code from the current CMakeLists.txt file
-    if(!CheckExists(filename)) return false;
+    if(!CheckExists(filename))
+        return false;
 
     // File content
     wxString mainProjectContent;
 
     // Print project name
     mainProjectContent << CODELITE_CMAKE_PREFIX << "\n\n";
-    mainProjectContent << "cmake_minimum_required(VERSION 2.8.11)\n\n";
+    mainProjectContent << "cmake_minimum_required(VERSION 3.0)\n";
+    AddUserCodeSection(mainProjectContent, CMAKELISTS_USER_CODE_01_PREFIX, m_userBlock01);
+    mainProjectContent << "enable_language(CXX C ASM)\n";
     mainProjectContent << "# Project name\n";
     mainProjectContent << "project(" << p->GetName() << ")\n\n";
+    AddUserCodeSection(mainProjectContent, CMAKELISTS_USER_CODE_02_PREFIX, m_userBlock02);
 
     mainProjectContent << "# This setting is useful for providing JSON file used by CodeLite for code completion\n";
     mainProjectContent << "set(CMAKE_EXPORT_COMPILE_COMMANDS 1)\n\n";
 
-    // Set the output directory. We want a common location for all projects
-    // so we set it under cmake-build-Debug/bin
-    wxFileName fnWorkspace = workspace->GetFileName();
-    fnWorkspace.MakeRelativeTo(p->GetFileName().GetPath());
-    wxString outputDir;
-
-    wxFileName workspaceBuildFoler(CMakeBuilder::GetWorkspaceBuildFolder(false), "");
-    outputDir << "${CMAKE_CURRENT_LIST_DIR}/" << fnWorkspace.GetPath() << "/" << workspaceBuildFoler.GetDirs().Last()
-              << "/output";
-
-    mainProjectContent << "# Set default locations\n";
-    mainProjectContent << "set(CL_OUTPUT_DIRECTORY " << outputDir << ")\n";
-    mainProjectContent << "set(CMAKE_LIBRARY_OUTPUT_DIRECTORY ${CL_OUTPUT_DIRECTORY})\n";
-    mainProjectContent << "set(CMAKE_RUNTIME_OUTPUT_DIRECTORY ${CL_OUTPUT_DIRECTORY})\n";
-    mainProjectContent << "set(CMAKE_ARCHIVE_OUTPUT_DIRECTORY ${CL_OUTPUT_DIRECTORY})\n";
-    mainProjectContent << "\n";
-
     // Export common variables into CMake variables
     {
         mainProjectContent << "set(CONFIGURATION_NAME \"" << workspace->GetBuildMatrix()->GetSelectedConfigurationName()
@@ -194,6 +192,28 @@ bool CMakeGenerator::Generate(ProjectPtr p)
         mainProjectContent << "\n";
     }
 
+    wxFileName fn = workspace->GetFileName();
+    fn.MakeRelativeTo(p->GetFileName().GetPath());
+
+    wxString workspacePath = fn.GetPath(false, wxPATH_UNIX);
+    if(workspacePath.IsEmpty()) {
+        workspacePath = ".";
+    }
+    mainProjectContent << "set(CL_WORKSPACE_DIRECTORY " << workspacePath << ")\n";
+
+    // Set the output directory. We want a common location for all projects
+    // so we set it under cmake-build-Debug/bin
+    wxString outputDir;
+    outputDir << "${CMAKE_CURRENT_LIST_DIR}/${CL_WORKSPACE_DIRECTORY}/"
+              << "cmake-build-${CONFIGURATION_NAME}/output";
+
+    mainProjectContent << "# Set default locations\n";
+    mainProjectContent << "set(CL_OUTPUT_DIRECTORY " << outputDir << ")\n";
+    mainProjectContent << "set(CMAKE_LIBRARY_OUTPUT_DIRECTORY ${CL_OUTPUT_DIRECTORY})\n";
+    mainProjectContent << "set(CMAKE_RUNTIME_OUTPUT_DIRECTORY ${CL_OUTPUT_DIRECTORY})\n";
+    mainProjectContent << "set(CMAKE_ARCHIVE_OUTPUT_DIRECTORY ${CL_OUTPUT_DIRECTORY})\n";
+    mainProjectContent << "\n";
+
     // Environment variables
     {
         wxString variables = workspace->GetEnvironmentVariabels(); // Nice typo
@@ -206,7 +226,9 @@ bool CMakeGenerator::Generate(ProjectPtr p)
             for(wxArrayString::const_iterator it = list.begin(), ite = list.end(); it != ite; ++it) {
                 // Split into name, value pair
                 const wxArrayString pair = wxSplit(*it, '=');
-                if(pair.IsEmpty()) { continue; }
+                if(pair.IsEmpty()) {
+                    continue;
+                }
                 const wxString& name = pair[0];
                 const wxString value = (pair.GetCount() >= 2) ? pair[1] : "";
 
@@ -255,9 +277,15 @@ wxString CMakeGenerator::GenerateProject(ProjectPtr project, bool topProject, co
 
     // Get the project build configuration and compiler
     BuildConfigPtr buildConf = project->GetBuildConfiguration(configName);
-    if(!buildConf) return "";
+    if(!buildConf)
+        return "";
+
+    wxArrayString cppSources, cSources, resourceFiles, asmSources;
+    cppSources.reserve(allFiles.size());
+    cSources.reserve(allFiles.size());
+    resourceFiles.reserve(allFiles.size());
+    asmSources.reserve(allFiles.size());
 
-    wxArrayString cppSources, cSources, resourceFiles;
     std::for_each(allFiles.begin(), allFiles.end(), [&](const Project::FilesMap_t::value_type& vt) {
         clProjectFile::Ptr_t file = vt.second;
         if(!file->IsExcludeFromConfiguration(buildConf->GetName())) {
@@ -266,12 +294,15 @@ wxString CMakeGenerator::GenerateProject(ProjectPtr project, bool topProject, co
             wxString file_name;
             file_name << "${CMAKE_CURRENT_LIST_DIR}/" << file->GetFilenameRelpath();
             file_name.Replace("\\", "/");
-            if(FileExtManager::GetType(fn.GetFullName()) == FileExtManager::TypeSourceC) {
+            wxString fullname = fn.GetFullName();
+            if(FileExtManager::GetType(fullname) == FileExtManager::TypeSourceC) {
                 cSources.Add(file_name);
-            } else if(FileExtManager::GetType(fn.GetFullName()) == FileExtManager::TypeSourceCpp) {
+            } else if(FileExtManager::GetType(fullname) == FileExtManager::TypeSourceCpp) {
                 cppSources.Add(file_name);
-            } else if(FileExtManager::GetType(fn.GetFullName()) == FileExtManager::TypeResource) {
+            } else if(FileExtManager::GetType(fullname) == FileExtManager::TypeResource) {
                 resourceFiles.Add(file_name);
+            } else if(FileExtManager::GetType(fullname) == FileExtManager::TypeAsm) {
+                asmSources.Add(file_name);
             }
         }
     });
@@ -286,23 +317,30 @@ wxString CMakeGenerator::GenerateProject(ProjectPtr project, bool topProject, co
     }
 
     CompilerPtr compiler = buildConf->GetCompiler();
-    if(!compiler) { return ""; }
+    if(!compiler) {
+        return "";
+    }
 
     wxFileName projectPath = project->GetFileName();
 
     // Output file name
     wxFileName filename(projectDir, CMakePlugin::CMAKELISTS_FILE);
 
-    if(!CheckExists(filename)) return "";
+    if(!CheckExists(filename))
+        return "";
 
     // File content
     wxString content;
-    if(!topProject) { content << Prefix(project); }
+    if(!topProject) {
+        content << Prefix(project);
+    }
 
     if(topProject) {
         // Add the dependencies
         wxArrayString projectsArr = project->GetDependencies(buildConf->GetName());
-        if(!projectsArr.IsEmpty()) { content << "## Add the dependencies\n"; }
+        if(!projectsArr.IsEmpty()) {
+            content << "## Add the dependencies\n";
+        }
 
         for(size_t i = 0; i < projectsArr.GetCount(); ++i) {
             ProjectPtr pProj = clCxxWorkspaceST::Get()->GetProject(projectsArr.Item(i));
@@ -337,7 +375,9 @@ wxString CMakeGenerator::GenerateProject(ProjectPtr project, bool topProject, co
             includePath.Replace("$(WorkspacePath)", "${WORKSPACE_PATH}");
             includePath.Replace("$(WorkspaceConfiguration)", "${CONFIGURATION_NAME}");
             includePath.Replace("$(ProjectPath)", projectPathVariableValue);
-            if(includePath.IsEmpty()) { continue; }
+            if(includePath.IsEmpty()) {
+                continue;
+            }
             content << "    " << includes.Item(i) << "\n";
         }
         content << "\n)\n\n";
@@ -374,7 +414,9 @@ wxString CMakeGenerator::GenerateProject(ProjectPtr project, bool topProject, co
             for(size_t i = 0; i < defines.GetCount(); ++i) {
                 wxString& pp = defines.Item(i);
                 pp.Trim().Trim(false);
-                if(pp.IsEmpty()) { continue; }
+                if(pp.IsEmpty()) {
+                    continue;
+                }
                 content << "    -D" << pp << "\n";
             }
             content << ")\n\n";
@@ -485,6 +527,15 @@ wxString CMakeGenerator::GenerateProject(ProjectPtr project, bool topProject, co
             content << "    )\n";
             content << "endif(WIN32)\n\n";
         }
+
+        if(!asmSources.IsEmpty()) {
+            content << "# Define the ASM sources\n";
+            content << "set ( ASM_SRCS\n";
+            for(size_t i = 0; i < asmSources.GetCount(); ++i) {
+                content << "    " << asmSources.Item(i) << "\n";
+            }
+            content << ")\n\n";
+        }
     }
 
     // Add CXX compiler options
@@ -526,15 +577,16 @@ wxString CMakeGenerator::GenerateProject(ProjectPtr project, bool topProject, co
     {
         wxString type = buildConf->GetProjectType();
         if(type == PROJECT_TYPE_EXECUTABLE) {
-            content << "add_executable(" << project->GetName() << " ${RC_SRCS} ${CXX_SRCS} ${C_SRCS})\n";
+            content << "add_executable(" << project->GetName() << " ${RC_SRCS} ${CXX_SRCS} ${C_SRCS} ${ASM_SRCS})\n";
             content << "target_link_libraries(" << project->GetName() << " ${LINK_OPTIONS})\n\n";
 
         } else if(type == PROJECT_TYPE_DYNAMIC_LIBRARY) {
-            content << "add_library(" << project->GetName() << " SHARED ${RC_SRCS} ${CXX_SRCS} ${C_SRCS})\n";
+            content << "add_library(" << project->GetName()
+                    << " SHARED ${RC_SRCS} ${CXX_SRCS} ${C_SRCS} ${ASM_SRCS})\n";
             content << "target_link_libraries(" << project->GetName() << " ${LINK_OPTIONS})\n\n";
 
         } else {
-            content << "add_library(" << project->GetName() << " ${RC_SRCS} ${CXX_SRCS} ${C_SRCS})\n\n";
+            content << "add_library(" << project->GetName() << " ${RC_SRCS} ${CXX_SRCS} ${C_SRCS} ${ASM_SRCS})\n\n";
         }
     }
 
@@ -619,7 +671,9 @@ bool CMakeGenerator::CanGenerate(ProjectPtr project)
     wxArrayString projects = project->GetDependencies(buildConf->GetName());
     for(size_t i = 0; i < projects.size(); ++i) {
         ProjectPtr p = workspace->GetProject(projects.Item(i));
-        if(p) { cmakelistsArr.push_back(wxFileName(p->GetFileName().GetPath(), CMakePlugin::CMAKELISTS_FILE)); }
+        if(p) {
+            cmakelistsArr.push_back(wxFileName(p->GetFileName().GetPath(), CMakePlugin::CMAKELISTS_FILE));
+        }
     }
 
     // Read each of the CMakeLists.txt file in the array, and check if we can find our top level comment
@@ -627,7 +681,9 @@ bool CMakeGenerator::CanGenerate(ProjectPtr project)
         const wxFileName& fn = cmakelistsArr.at(i);
         wxString content;
         if(fn.Exists() && FileUtils::ReadFileContent(fn, content)) {
-            if(!content.StartsWith(CODELITE_CMAKE_PREFIX)) { return false; }
+            if(!content.StartsWith(CODELITE_CMAKE_PREFIX)) {
+                return false;
+            }
         }
     }
     return true;
@@ -648,7 +704,9 @@ void CMakeGenerator::ExpandOptions(const wxString& options, wxString& content, w
         if(cmpOption.StartsWith(wxT("$(shell "), &tmp) || cmpOption.StartsWith(wxT("`"), &tmp)) {
             cmpOption.swap(tmp);
             tmp.Clear();
-            if(cmpOption.EndsWith(wxT(")"), &tmp) || cmpOption.EndsWith(wxT("`"), &tmp)) { cmpOption.swap(tmp); }
+            if(cmpOption.EndsWith(wxT(")"), &tmp) || cmpOption.EndsWith(wxT("`"), &tmp)) {
+                cmpOption.swap(tmp);
+            }
 
             wxString varname;
             varname << "CL_VAR_" << (++m_counter);
@@ -675,10 +733,14 @@ wxString CMakeGenerator::Prefix(ProjectPtr project)
     wxString content;
 
     content << CODELITE_CMAKE_PREFIX << "\n\n";
-    content << "cmake_minimum_required(VERSION 2.8.11)\n\n";
+    content << "cmake_minimum_required(VERSION 3.0)\n";
+    
+    AddUserCodeSection(content, CMAKELISTS_USER_CODE_01_PREFIX, m_userBlock01);
+    content << "enable_language(CXX C ASM)\n\n";
 
     // Print project name
     content << "project(" << project->GetName() << ")\n\n";
+    AddUserCodeSection(content, CMAKELISTS_USER_CODE_02_PREFIX, m_userBlock02);
     return content;
 }
 
@@ -687,13 +749,17 @@ bool CMakeGenerator::IsCustomCMakeLists(const wxFileName& fn)
     if(fn.FileExists()) {
         wxFileName fn;
         wxString content;
-        if(FileUtils::ReadFileContent(fn, content)) { return !content.StartsWith(CODELITE_CMAKE_PREFIX); }
+        if(FileUtils::ReadFileContent(fn, content)) {
+            return !content.StartsWith(CODELITE_CMAKE_PREFIX);
+        }
     }
     return false;
 }
 
 void CMakeGenerator::ReadUserCode(const wxString& content)
 {
+    m_userBlock01.clear();
+    m_userBlock02.clear();
     m_userBlock1.clear();
     m_userBlock2.clear();
     m_userBlock3.clear();
@@ -708,6 +774,10 @@ void CMakeGenerator::ReadUserCode(const wxString& content)
             ReadUntilEndOfUserBlock(lines, m_userBlock2);
         } else if(curline.StartsWith(CMAKELISTS_USER_CODE_3_PREFIX)) {
             ReadUntilEndOfUserBlock(lines, m_userBlock3);
+        } else if(curline.StartsWith(CMAKELISTS_USER_CODE_01_PREFIX)) {
+            ReadUntilEndOfUserBlock(lines, m_userBlock01);
+        } else if(curline.StartsWith(CMAKELISTS_USER_CODE_02_PREFIX)) {
+            ReadUntilEndOfUserBlock(lines, m_userBlock02);
         }
     }
 }
@@ -725,7 +795,9 @@ void CMakeGenerator::ReadUntilEndOfUserBlock(wxArrayString& lines, wxString& con
             // removeLf = true;
         }
     }
-    if(removeLf) { content.RemoveLast(); }
+    if(removeLf) {
+        content.RemoveLast();
+    }
 }
 
 void CMakeGenerator::AddUserCodeSection(wxString& content, const wxString& sectionPrefix, const wxString& sectionCode)
