@@ -1,14 +1,18 @@
 #include "CIncludeStatementCollector.h"
-#include "CxxScannerTokens.h"
 #include "CxxPreProcessor.h"
+#include "CxxScannerTokens.h"
 #include "file_logger.h"
 
-CIncludeStatementCollector::CIncludeStatementCollector(CxxPreProcessor* pp, const wxFileName& filename)
+CIncludeStatementCollector::CIncludeStatementCollector(CxxPreProcessor* pp, const wxFileName& filename,
+                                                       std::unordered_set<wxString>& visitedFiles)
     : CxxScannerBase(pp, filename)
+    , m_visitedFiles(visitedFiles)
 {
 }
 
-CIncludeStatementCollector::~CIncludeStatementCollector() {}
+CIncludeStatementCollector::~CIncludeStatementCollector()
+{
+}
 
 void CIncludeStatementCollector::OnToken(CxxLexerToken& token)
 {
@@ -18,9 +22,8 @@ void CIncludeStatementCollector::OnToken(CxxLexerToken& token)
         // we found an include statement, recurse into it
         wxFileName include;
         if(m_preProcessor->ExpandInclude(m_filename, token.GetWXString(), include)) {
-            CIncludeStatementCollector* scanner = new CIncludeStatementCollector(m_preProcessor, include);
-            scanner->Parse();
-            wxDELETE(scanner);
+            CIncludeStatementCollector scanner(m_preProcessor, include, m_visitedFiles);
+            scanner.Parse();
             clDEBUG1() << "<== Resuming parser on file:" << m_filename << clEndl;
         }
         break;
