@@ -3,13 +3,14 @@
 
 #include "CxxLexerAPI.h"
 #include "codelite_exports.h"
+#include "macros.h"
 #include "smart_ptr.h"
+
 #include <map>
 #include <set>
 #include <unordered_map>
 #include <vector>
 #include <wx/string.h>
-#include "macros.h"
 #include <wxStringHash.h>
 
 class WXDLLIMPEXP_CL CxxVariable
@@ -60,7 +61,8 @@ protected:
     wxString m_defaultValue;
     eCxxStandard m_standard;
     wxString m_pointerOrReference;
-    bool m_isAuto;
+    bool m_isAuto = false;
+    int m_lineNumber = wxNOT_FOUND;
 
 public:
     typedef SmartPtr<CxxVariable> Ptr_t;
@@ -93,7 +95,7 @@ public:
      * @brief return true if this variable was constructed from a statement like:
      * using MyInt = int;
      */
-    bool IsUsing() const { return GetTypeAsString() == "using"; }
+    bool IsUsing() const { return GetTypeAsString() == "using" && !m_defaultValue.IsEmpty(); }
 
     /**
      * @brief is this a valid variable?
@@ -105,6 +107,9 @@ public:
      */
     bool IsAuto() const { return m_isAuto; }
 
+    void SetLine(int l) { m_lineNumber = l; }
+    int GetLineNumber() const { return m_lineNumber; }
+
     void SetIsAuto(bool b) { m_isAuto = b; }
     /**
      * @brief return a string representation for this variable
