@@ -1,6 +1,8 @@
-#include "CxxScannerTokens.h"
 #include "CxxVariableScanner.h"
+
+#include "CxxScannerTokens.h"
 #include "file_logger.h"
+
 #include <algorithm>
 #include <unordered_set>
 
@@ -14,7 +16,9 @@ CxxVariableScanner::CxxVariableScanner(const wxString& buffer, eCxxStandard stan
     , m_macros(macros)
     , m_isFuncSignature(isFuncSignature)
 {
-    if(!m_buffer.IsEmpty() && m_buffer[0] == '(') { m_buffer.Remove(0, 1); }
+    if(!m_buffer.IsEmpty() && m_buffer[0] == '(') {
+        m_buffer.Remove(0, 1);
+    }
     m_nativeTypes.insert(T_AUTO);
     m_nativeTypes.insert(T_BOOL);
     m_nativeTypes.insert(T_CHAR);
@@ -29,15 +33,16 @@ CxxVariableScanner::CxxVariableScanner(const wxString& buffer, eCxxStandard stan
     m_nativeTypes.insert(T_UNSIGNED);
     m_nativeTypes.insert(T_VOID);
     m_nativeTypes.insert(T_WCHAR_T);
+    // optimize the buffer
+    DoOptimizeBuffer();
 }
 
 CxxVariableScanner::~CxxVariableScanner() {}
 
 CxxVariable::Vec_t CxxVariableScanner::GetVariables(bool sort)
 {
-    wxString strippedBuffer;
-    OptimizeBuffer(m_buffer, strippedBuffer);
-    CxxVariable::Vec_t vars = DoGetVariables(strippedBuffer, sort);
+    // this call does nothing if the buffer was already optimized
+    CxxVariable::Vec_t vars = DoGetVariables(GetOptimizeBuffer(), sort);
     if(sort) {
         std::sort(vars.begin(), vars.end(),
                   [&](CxxVariable::Ptr_t a, CxxVariable::Ptr_t b) { return a->GetName() < b->GetName(); });
@@ -151,7 +156,8 @@ bool CxxVariableScanner::ReadType(CxxVariable::LexerToken::Vec_t& vartype, bool&
                     break;
                 case '*':
                 case '&':
-                case '@': // AngelScript
+                case '@':       // AngelScript
+                case T_AND_AND: // C++11 reference rvalue
                     // Part of the name
                     UngetToken(token);
                     return true;
@@ -172,7 +178,9 @@ bool CxxVariableScanner::ReadType(CxxVariable::LexerToken::Vec_t& vartype, bool&
     return false;
 }
 
-bool CxxVariableScanner::ReadName(wxString& varname, wxString& pointerOrRef, wxString& varInitialization)
+thread_local std::unordered_set<int> s_validLocalTerminators;
+bool CxxVariableScanner::ReadName(wxString& varname, wxString& pointerOrRef, int& line_number,
+                                  wxString& varInitialization)
 {
     CxxLexerToken token;
     while(GetNextToken(token)) {
@@ -184,16 +192,19 @@ bool CxxVariableScanner::ReadName(wxString& varname, wxString& pointerOrRef, wxS
                 return false;
             }
             varname = token.GetWXString();
+            line_number = token.GetLineNumber();
             varInitialization.Clear();
             pointerOrRef = "@";
             return true;
         } else if(token.GetType() == T_IDENTIFIER) {
             varname = token.GetWXString();
-            
-            // When parsing function signature, we don't have multiple arguments 
+
+            // When parsing function signature, we don't have multiple arguments
             // tied to the same TYPE
-            if(m_isFuncSignature) { return false; }
-            
+            if(m_isFuncSignature) {
+                return false;
+            }
+
             // Peek at the next token
             // We can expect "=", "," "(", ";" or ")"
             // Examples:
@@ -201,7 +212,6 @@ bool CxxVariableScanner::ReadName(wxString& varname, wxString& pointerOrRef, wxS
             // TYPE name, secondVariable;
             // TYPE name(10);
             // TYPE name;
-            static std::unordered_set<int> s_validLocalTerminators;
             if(s_validLocalTerminators.empty()) {
                 s_validLocalTerminators.insert((int)',');
                 s_validLocalTerminators.insert((int)'=');
@@ -230,7 +240,9 @@ bool CxxVariableScanner::ReadName(wxString& varname, wxString& pointerOrRef, wxS
             ConsumeInitialization(varInitialization);
 
             // Now that we got the name, check if have more variables to expect
-            if(!GetNextToken(token)) { return false; }
+            if(!GetNextToken(token)) {
+                return false;
+            }
 
             if((token.GetType() == '{') && !varInitialization.IsEmpty()) {
                 // Don't collect functions and consider them as variables
@@ -239,7 +251,9 @@ bool CxxVariableScanner::ReadName(wxString& varname, wxString& pointerOrRef, wxS
                 return false;
             }
 
-            if(!varInitialization.empty()) { varInitialization.RemoveLast(); }
+            if(!varInitialization.empty()) {
+                varInitialization.RemoveLast();
+            }
 
             // If we found comma, return true. Unless we are parsing a function signature
             if(!m_isFuncSignature && (token.GetType() == ',')) {
@@ -248,7 +262,7 @@ bool CxxVariableScanner::ReadName(wxString& varname, wxString& pointerOrRef, wxS
                 UngetToken(token);
                 return false;
             }
-        } else if(token.GetType() == '*' || token.GetType() == '&') {
+        } else if(token.GetType() == '*' || token.GetType() == '&' || token.GetType() == T_AND_AND) {
             pointerOrRef << token.GetWXString();
         } else {
             return false;
@@ -261,14 +275,34 @@ void CxxVariableScanner::ConsumeInitialization(wxString& consumed)
 {
     CxxLexerToken token;
     wxString dummy;
-    if(!GetNextToken(token)) return;
+    if(!GetNextToken(token))
+        return;
+
     int type = wxNOT_FOUND;
     int tokType = token.GetType();
+    if(tokType == '=') {
+        CxxLexerToken next_token;
+        if(!GetNextToken(next_token))
+            return;
+
+        if(next_token.GetType() == '[') {
+            // ... = [ -> we expect lambda to come
+            return;
+        } else if(next_token.GetType() == ']') {
+            // ... =] -> lambda body is expected
+            return;
+        } else {
+            UngetToken(next_token);
+        }
+    }
+
     if(tokType == '(') {
         // Read the initialization
         std::unordered_set<int> delims;
         delims.insert(')');
-        if(ReadUntil(delims, token, consumed) == wxNOT_FOUND) { return; }
+        if(ReadUntil(delims, token, consumed) == wxNOT_FOUND) {
+            return;
+        }
         consumed.Prepend("(");
         // Now read until the delimiter
         delims.clear();
@@ -281,7 +315,9 @@ void CxxVariableScanner::ConsumeInitialization(wxString& consumed)
         // Array
         std::unordered_set<int> delims;
         delims.insert(']');
-        if(ReadUntil(delims, token, consumed) == wxNOT_FOUND) { return; }
+        if(ReadUntil(delims, token, consumed) == wxNOT_FOUND) {
+            return;
+        }
         consumed.Prepend("[");
         // Now read until the delimiter
         delims.clear();
@@ -293,7 +329,9 @@ void CxxVariableScanner::ConsumeInitialization(wxString& consumed)
         // Read the initialization
         std::unordered_set<int> delims;
         delims.insert('}');
-        if(ReadUntil(delims, token, consumed) == wxNOT_FOUND) { return; }
+        if(ReadUntil(delims, token, consumed) == wxNOT_FOUND) {
+            return;
+        }
         consumed.Prepend("{");
         // Now read until the delimiter
         delims.clear();
@@ -316,7 +354,9 @@ void CxxVariableScanner::ConsumeInitialization(wxString& consumed)
         type = ReadUntil(delims, token, dummy);
     }
 
-    if(type == ',' || type == (int)'{' || type == ';') { UngetToken(token); }
+    if(type == ',' || type == (int)'{' || type == ';') {
+        UngetToken(token);
+    }
 }
 
 int CxxVariableScanner::ReadUntil(const std::unordered_set<int>& delims, CxxLexerToken& token, wxString& consumed)
@@ -366,10 +406,13 @@ bool CxxVariableScanner::GetNextToken(CxxLexerToken& token)
 
     while(true) {
         res = ::LexerNext(m_scanner, token);
-        if(!res) break;
+        if(!res)
+            break;
 
         // Ignore any T_IDENTIFIER which is declared as macro
-        if((token.GetType() == T_IDENTIFIER) && m_macros.count(token.GetWXString())) { continue; }
+        if((token.GetType() == T_IDENTIFIER) && m_macros.count(token.GetWXString())) {
+            continue;
+        }
         break;
     }
 
@@ -387,12 +430,15 @@ bool CxxVariableScanner::GetNextToken(CxxLexerToken& token)
     return res;
 }
 
-void CxxVariableScanner::OptimizeBuffer(const wxString& buffer, wxString& stripped_buffer)
+void CxxVariableScanner::DoOptimizeBuffer()
 {
-    stripped_buffer.Clear();
-    Scanner_t sc = ::LexerNew(buffer);
+    if(m_buffer_optimized) {
+        return;
+    }
+
+    Scanner_t sc = ::LexerNew(m_buffer);
     if(!sc) {
-        clWARNING() << "CxxVariableScanner::OptimizeBuffer(): failed to create Scanner_t" << clEndl;
+        clWARNING() << "CxxVariableScanner::DoOptimizeBuffer(): failed to create Scanner_t" << clEndl;
         return; // Failed to allocate scanner
     }
 
@@ -406,7 +452,9 @@ void CxxVariableScanner::OptimizeBuffer(const wxString& buffer, wxString& stripp
     int parenthesisDepth = 0;
     while(::LexerNext(sc, tok)) {
         // Skip prep processing state
-        if(userData && userData->IsInPreProcessorSection()) { continue; }
+        if(userData && userData->IsInPreProcessorSection()) {
+            continue;
+        }
 
         // Return the working buffer, which depends on the current state
         wxString& buffer = Buffer();
@@ -415,9 +463,18 @@ void CxxVariableScanner::OptimizeBuffer(const wxString& buffer, wxString& stripp
         switch(tok.GetType()) {
         case T_PP_STATE_EXIT:
             break;
-        case T_FOR:
-            OnForLoop(sc);
-            break;
+        case T_FOR: {
+            wxString variable_definition;
+            if(OnForLoop(sc, variable_definition)) {
+                // move the variable to the next scope
+                Buffer() << "for () {";
+                PushBuffer();
+                Buffer() << variable_definition;
+            } else {
+                // single line for()
+                Buffer() << "for ()";
+            }
+        } break;
         case T_CATCH:
             OnCatch(sc);
             break;
@@ -429,11 +486,8 @@ void CxxVariableScanner::OptimizeBuffer(const wxString& buffer, wxString& stripp
             break;
         case '(':
             buffer << tok.GetWXString();
-            if(lastToken.GetType() == ']') {
-                OnLambda(sc);
-            } else {
-                ++parenthesisDepth;
-                PushBuffer();
+            if(skip_parenthesis_block(sc)) {
+                buffer << ")";
             }
             break;
         case '{':
@@ -449,11 +503,6 @@ void CxxVariableScanner::OptimizeBuffer(const wxString& buffer, wxString& stripp
             --parenthesisDepth;
             buffer = PopBuffer();
             buffer << ")";
-            // The closing curly bracket is added *after* we switch buffers
-            // if(parenthesisDepth == 0) {
-            //     buffer << tok.GetWXString();
-            // } else {
-            // }
             break;
         default:
             buffer << tok.GetWXString() << " ";
@@ -464,8 +513,11 @@ void CxxVariableScanner::OptimizeBuffer(const wxString& buffer, wxString& stripp
     ::LexerDestroy(&sc);
 
     // Merge the buffers
-    stripped_buffer.Clear();
-    std::for_each(m_buffers.rbegin(), m_buffers.rend(), [&](const wxString& buffer) { stripped_buffer << buffer; });
+    std::for_each(m_buffers.rbegin(), m_buffers.rend(), [&](const wxString& buffer) {
+        // append the buffers in reverse order
+        m_optimized_buffer << buffer;
+    });
+    m_buffer_optimized = true;
 }
 
 CxxVariable::Vec_t CxxVariableScanner::DoGetVariables(const wxString& buffer, bool sort)
@@ -474,7 +526,8 @@ CxxVariable::Vec_t CxxVariableScanner::DoGetVariables(const wxString& buffer, bo
     m_scanner = ::LexerNew(buffer);
     m_eof = false;
     m_parenthesisDepth = 0;
-    if(!m_scanner) return CxxVariable::Vec_t(); // Empty list
+    if(!m_scanner)
+        return CxxVariable::Vec_t(); // Empty list
 
     CxxVariable::Vec_t vars;
 
@@ -482,20 +535,30 @@ CxxVariable::Vec_t CxxVariableScanner::DoGetVariables(const wxString& buffer, bo
     while(!IsEof()) {
         bool isAuto;
         CxxVariable::LexerToken::Vec_t vartype;
-        if(!ReadType(vartype, isAuto)) continue;
+        if(!ReadType(vartype, isAuto))
+            continue;
 
         // Get the variable(s) name
         wxString varname, pointerOrRef, varInitialization;
         bool cont = false;
         do {
-            cont = ReadName(varname, pointerOrRef, varInitialization);
+            int line_number = wxNOT_FOUND;
+            cont = ReadName(varname, pointerOrRef, line_number, varInitialization);
             CxxVariable::Ptr_t var(new CxxVariable(m_standard));
             var->SetName(varname);
             var->SetType(vartype);
             var->SetDefaultValue(varInitialization);
             var->SetPointerOrReference(pointerOrRef);
             var->SetIsAuto(isAuto);
-            if(var->IsOk()) {
+            var->SetLine(line_number);
+
+            // the below condition fixes this type:
+            // if(something && GetCtrl(). -> we can mistaken this as: VarType: something, VarName: GetCtrl, And
+            // pointerOrRef: &&
+            bool not_ok = varInitialization.Contains("(") && pointerOrRef == "&&";
+            if(not_ok) {
+                break;
+            } else if(var->IsOk()) {
                 vars.push_back(var);
             } else if(!varInitialization.IsEmpty()) {
                 // This means that the above was a function call
@@ -526,7 +589,9 @@ CxxVariable::Map_t CxxVariableScanner::GetVariablesMap()
     CxxVariable::Vec_t l = GetVariables(true);
     CxxVariable::Map_t m;
     std::for_each(l.begin(), l.end(), [&](CxxVariable::Ptr_t v) {
-        if(m.count(v->GetName()) == 0) { m.insert(std::make_pair(v->GetName(), v)); }
+        if(m.count(v->GetName()) == 0) {
+            m.insert(std::make_pair(v->GetName(), v));
+        }
     });
     return m;
 }
@@ -545,7 +610,8 @@ CxxVariable::Vec_t CxxVariableScanner::DoParseFunctionArguments(const wxString&
     m_scanner = ::LexerNew(buffer);
     m_eof = false;
     m_parenthesisDepth = 0;
-    if(!m_scanner) return CxxVariable::Vec_t(); // Empty list
+    if(!m_scanner)
+        return CxxVariable::Vec_t(); // Empty list
 
     CxxVariable::Vec_t vars;
 
@@ -553,17 +619,20 @@ CxxVariable::Vec_t CxxVariableScanner::DoParseFunctionArguments(const wxString&
     while(!IsEof()) {
         bool isAuto;
         CxxVariable::LexerToken::Vec_t vartype;
-        if(!ReadType(vartype, isAuto)) continue;
+        if(!ReadType(vartype, isAuto))
+            continue;
 
         // Get the variable(s) name
+        int line_number = wxNOT_FOUND;
         wxString varname, pointerOrRef, varInitialization;
-        ReadName(varname, pointerOrRef, varInitialization);
+        ReadName(varname, pointerOrRef, line_number, varInitialization);
         CxxVariable::Ptr_t var(new CxxVariable(m_standard));
         var->SetName(varname);
         var->SetType(vartype);
         var->SetDefaultValue(varInitialization);
         var->SetPointerOrReference(pointerOrRef);
         var->SetIsAuto(isAuto);
+        var->SetLine(line_number);
         vars.push_back(var);
     }
     ::LexerDestroy(&m_scanner);
@@ -586,43 +655,88 @@ void CxxVariableScanner::UngetToken(const CxxLexerToken& token)
 
 wxString& CxxVariableScanner::Buffer() { return m_buffers[0]; }
 
-bool CxxVariableScanner::OnForLoop(Scanner_t scanner)
+bool CxxVariableScanner::OnForLoop(Scanner_t scanner, wxString& variable_definition)
 {
     CxxLexerToken tok;
 
     // The next token must be '('
-    if(!::LexerNext(scanner, tok)) return false;
+    if(!::LexerNext(scanner, tok))
+        return false;
 
     // Parser error
-    if(tok.GetType() != '(') return false;
+    if(tok.GetType() != '(')
+        return false;
 
-    int depth(1);
-    wxString& buffer = Buffer();
-    bool lookingForFirstSemiColon = true;
-    while(::LexerNext(scanner, tok)) {
-        // Skip prep processing state
-        // 'for' and 'catch' parenthesis content is kept in the buffer
+    constexpr int STATE_NORMAL = 0;
+    constexpr int STATE_CXX11 = 1;
+    int state = STATE_NORMAL;
+
+    int depth = 0;
+    bool cont = true;
+    while(cont && ::LexerNext(scanner, tok)) {
+        if(tok.is_keyword() || tok.is_builtin_type()) {
+            variable_definition << " " << tok.GetWXString();
+            continue;
+        }
         switch(tok.GetType()) {
         case '(':
+        case '<':
+        case '[':
+        case '{':
             depth++;
-            if(lookingForFirstSemiColon) { buffer << "("; }
+            variable_definition << tok.GetWXString();
+            break;
+        case '>':
+        case ']':
+        case '}':
+            depth--;
+            variable_definition << tok.GetWXString();
             break;
         case ')':
-            depth--;
-            if(lookingForFirstSemiColon) { buffer << ")"; }
-            if(depth == 0) return true;
+            if(depth == 0) {
+                // we are done
+                cont = false;
+                if(state == STATE_CXX11) {
+                    // append ".begin()"
+                    variable_definition << ".begin()";
+                }
+                variable_definition << ";";
+            } else {
+                variable_definition << ")";
+                depth--;
+            }
+            break;
+        case ':':
+            // c++11 ranged for loop
+            state = STATE_CXX11;
+            // we are going to create a variable of this type:
+            // TYPENAME name = CONTAINER.begin();
+            variable_definition << "=";
+            break;
+        case T_IDENTIFIER:
+            variable_definition << " " << tok.GetWXString();
             break;
         case ';':
-        case ':': // C++11 ranged for
-            if(lookingForFirstSemiColon) { buffer << ";"; }
-            lookingForFirstSemiColon = false;
+            // no need to check for depth, we cant have ';' in non depth 0
+            variable_definition << ";";
+            cont = false;
             break;
         default:
-            if(lookingForFirstSemiColon) { buffer << tok.GetWXString() << " "; }
+            variable_definition << tok.GetWXString();
             break;
         }
     }
-    return false;
+
+    // read the remainder (for C++11 ranged loop we already consumed the closing parenthesis)
+    if(state == STATE_NORMAL && !SkipToClosingParenthesis(scanner)) {
+        return false;
+    }
+
+    // we are now expecting a '{'
+    ::LexerNext(scanner, tok);
+    if(tok.GetType() != '{')
+        return false;
+    return true;
 }
 
 bool CxxVariableScanner::OnCatch(Scanner_t scanner)
@@ -630,10 +744,12 @@ bool CxxVariableScanner::OnCatch(Scanner_t scanner)
     CxxLexerToken tok;
 
     // The next token must be '('
-    if(!::LexerNext(scanner, tok)) return false;
+    if(!::LexerNext(scanner, tok))
+        return false;
 
     // Parser error
-    if(tok.GetType() != '(') return false;
+    if(tok.GetType() != '(')
+        return false;
     int depth(1);
     wxString& buffer = Buffer();
     buffer << ";"; // Help the parser
@@ -646,7 +762,9 @@ bool CxxVariableScanner::OnCatch(Scanner_t scanner)
         case ')':
             --depth;
             buffer << tok.GetWXString();
-            if(depth == 0) { return true; }
+            if(depth == 0) {
+                return true;
+            }
             break;
         default:
             buffer << tok.GetWXString() << " ";
@@ -662,10 +780,12 @@ bool CxxVariableScanner::OnWhile(Scanner_t scanner)
     CxxLexerToken tok;
 
     // The next token must be '('
-    if(!::LexerNext(scanner, tok)) return false;
+    if(!::LexerNext(scanner, tok))
+        return false;
 
     // Parser error
-    if(tok.GetType() != '(') return false;
+    if(tok.GetType() != '(')
+        return false;
     int depth(1);
     while(::LexerNext(scanner, tok)) {
         switch(tok.GetType()) {
@@ -674,7 +794,8 @@ bool CxxVariableScanner::OnWhile(Scanner_t scanner)
             break;
         case ')':
             --depth;
-            if(depth == 0) return true;
+            if(depth == 0)
+                return true;
             break;
         default:
             break;
@@ -689,10 +810,12 @@ bool CxxVariableScanner::OnDeclType(Scanner_t scanner)
     wxString& buffer = Buffer();
 
     // The next token must be '('
-    if(!::LexerNext(scanner, tok)) return false;
+    if(!::LexerNext(scanner, tok))
+        return false;
 
     // Parser error
-    if(tok.GetType() != '(') return false;
+    if(tok.GetType() != '(')
+        return false;
     int depth(1);
     buffer << "decltype(";
     while(::LexerNext(scanner, tok)) {
@@ -704,7 +827,9 @@ bool CxxVariableScanner::OnDeclType(Scanner_t scanner)
         case ')':
             --depth;
             buffer << ")";
-            if(depth == 0) { return true; }
+            if(depth == 0) {
+                return true;
+            }
             break;
         default:
             break;
@@ -722,30 +847,86 @@ wxString& CxxVariableScanner::PushBuffer()
 
 wxString& CxxVariableScanner::PopBuffer()
 {
-    if(m_buffers.size() > 1) { m_buffers.erase(m_buffers.begin()); }
+    if(m_buffers.size() > 1) {
+        m_buffers.erase(m_buffers.begin());
+    }
     return m_buffers[0];
 }
 
-bool CxxVariableScanner::OnLambda(Scanner_t scanner)
+bool CxxVariableScanner::SkipToClosingParenthesis(Scanner_t scanner)
 {
+    int depth = 0;
     CxxLexerToken tok;
-    int depth(1);
-    wxString& buffer = Buffer();
     while(::LexerNext(scanner, tok)) {
         switch(tok.GetType()) {
         case '(':
-            ++depth;
-            buffer << tok.GetWXString();
+            depth++;
             break;
         case ')':
-            --depth;
-            buffer << tok.GetWXString();
-            if(depth == 0) { return true; }
+            if(depth == 0) {
+                return true;
+            }
+            depth--;
             break;
         default:
-            buffer << tok.GetWXString() << " ";
             break;
         }
     }
     return false;
 }
+
+wxString CxxVariableScanner::ToString(CxxVariable::LexerToken::Vec_t& vartype)
+{
+    wxString str;
+    for(const auto& token : vartype) {
+        str << token.text << " ";
+    }
+    str.Trim();
+    return str;
+}
+
+bool CxxVariableScanner::skip_parenthesis_block(Scanner_t scanner)
+{
+    int depth = 0;
+    CxxLexerToken token;
+    while(::LexerNext(scanner, token)) {
+        // Skip prep processing state
+        switch(token.GetType()) {
+        case '(':
+            depth++;
+            break;
+        case ')':
+            if(depth == 0) {
+                return true;
+            }
+            depth--;
+            break;
+        default:
+            break;
+        }
+    }
+    return false;
+}
+
+bool CxxVariableScanner::skip_curly_brackets_block(Scanner_t scanner)
+{
+    int depth = 0;
+    CxxLexerToken token;
+    while(::LexerNext(scanner, token)) {
+        // Skip prep processing state
+        switch(token.GetType()) {
+        case '{':
+            depth++;
+            break;
+        case '}':
+            if(depth == 0) {
+                return true;
+            }
+            depth--;
+            break;
+        default:
+            break;
+        }
+    }
+    return false;
+}
\ No newline at end of file
