@@ -2,8 +2,7 @@
 
 static int counter = 0;
 
-LSP::DidChangeTextDocumentRequest::DidChangeTextDocumentRequest(const wxFileName& filename,
-                                                                const std::string& fileContent)
+LSP::DidChangeTextDocumentRequest::DidChangeTextDocumentRequest(const wxString& filename, const wxString& fileContent)
 {
     SetMethod("textDocument/didChange");
     m_params.reset(new DidChangeTextDocumentParams());
