@@ -1,10 +1,10 @@
 #include "DidCloseTextDocumentRequest.h"
 
-LSP::DidCloseTextDocumentRequest::DidCloseTextDocumentRequest(const wxFileName& filename)
+LSP::DidCloseTextDocumentRequest::DidCloseTextDocumentRequest(const wxString& filename)
 {
     SetMethod("textDocument/didClose");
     m_params.reset(new DidCloseTextDocumentParams());
-    m_params->As<DidCloseTextDocumentParams>()->SetTextDocument(TextDocumentIdentifier(filename.GetFullPath()));
+    m_params->As<DidCloseTextDocumentParams>()->SetTextDocument(TextDocumentIdentifier(filename));
 }
 
 LSP::DidCloseTextDocumentRequest::~DidCloseTextDocumentRequest() {}
