@@ -1,9 +1,10 @@
 #ifndef DIDOPENTEXTDOCUMENTREQUEST_H
 #define DIDOPENTEXTDOCUMENTREQUEST_H
 
-#include "MessageWithParams.h"
-#include <wx/filename.h>
 #include "LSP/Notification.h"
+#include "MessageWithParams.h"
+
+#include <wx/filename.h>
 
 namespace LSP
 {
@@ -11,7 +12,7 @@ namespace LSP
 class WXDLLIMPEXP_CL DidOpenTextDocumentRequest : public LSP::Notification
 {
 public:
-    DidOpenTextDocumentRequest(const wxFileName& filename, const std::string& text, const wxString& langugage);
+    explicit DidOpenTextDocumentRequest(const wxString& filename, const wxString& text, const wxString& langugage);
     virtual ~DidOpenTextDocumentRequest();
 };
 
