@@ -2,7 +2,7 @@
 #include "LSP/LSPEvent.h"
 #include "LSP/json_rpc_params.h"
 
-LSP::GotoImplementationRequest::GotoImplementationRequest(const wxFileName& filename, size_t line, size_t column)
+LSP::GotoImplementationRequest::GotoImplementationRequest(const wxString& filename, size_t line, size_t column)
 {
     SetMethod("textDocument/implementation");
     m_params.reset(new TextDocumentPositionParams());
@@ -12,27 +12,28 @@ LSP::GotoImplementationRequest::GotoImplementationRequest(const wxFileName& file
 
 LSP::GotoImplementationRequest::~GotoImplementationRequest() {}
 
-void LSP::GotoImplementationRequest::OnResponse(const LSP::ResponseMessage& response, wxEvtHandler* owner,
-                                                IPathConverter::Ptr_t pathConverter)
+void LSP::GotoImplementationRequest::OnResponse(const LSP::ResponseMessage& response, wxEvtHandler* owner)
 {
     JSONItem result = response.Get("result");
-    if(!result.isOk()) { return; }
+    if(!result.isOk()) {
+        return;
+    }
     LSP::Location loc;
     if(result.isArray()) {
-        loc.FromJSON(result.arrayItem(0), pathConverter);
+        loc.FromJSON(result.arrayItem(0));
     } else {
-        loc.FromJSON(result, pathConverter);
+        loc.FromJSON(result);
     }
 
     // We send the same event for declaraion as we do for definition
-    if(!loc.GetUri().IsEmpty()) {
+    if(!loc.GetPath().IsEmpty()) {
         LSPEvent definitionEvent(wxEVT_LSP_DEFINITION);
         definitionEvent.SetLocation(loc);
         owner->AddPendingEvent(definitionEvent);
     }
 }
 
-bool LSP::GotoImplementationRequest::IsValidAt(const wxFileName& filename, size_t line, size_t col) const
+bool LSP::GotoImplementationRequest::IsValidAt(const wxString& filename, size_t line, size_t col) const
 {
     return (m_filename == filename) && (m_line == line) && (m_column == col);
 }
