@@ -15,8 +15,8 @@ class WXDLLIMPEXP_CL Serializable
 public:
     Serializable() {}
     virtual ~Serializable() {}
-    virtual JSONItem ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const = 0;
-    virtual void FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter) = 0;
+    virtual JSONItem ToJSON(const wxString& name) const = 0;
+    virtual void FromJSON(const JSONItem& json) = 0;
 };
 
 };     // namespace LSP
