@@ -1,11 +1,12 @@
 #ifndef MESSAGE_H
 #define MESSAGE_H
 
-#include "codelite_exports.h"
-#include "JSONObject.h"
-#include "JSON.h"
-#include <string>
 #include "IPathConverter.hpp"
+#include "JSON.h"
+#include "JSONObject.h"
+#include "codelite_exports.h"
+#include <string>
+#include <memory>
 
 namespace LSP
 {
@@ -19,13 +20,19 @@ public:
 public:
     Message();
     virtual ~Message();
-    virtual JSONItem ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const;
-    virtual void FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter);
+    virtual JSONItem ToJSON(const wxString& name) const;
+    virtual void FromJSON(const JSONItem& json);
 
     /**
      * @brief serialize this message into string
      */
-    virtual std::string ToString(IPathConverter::Ptr_t pathConverter) const = 0;
+    virtual std::string ToString() const = 0;
+
+    /**
+     * @brief return the **first** JSON payload from the network buffer
+     * @param network_buffer - network buffer (may contain multiple messages)
+     */
+    static std::unique_ptr<JSON> GetJSONPayload(wxString& network_buffer);
 
     template <typename T> T* As() const { return dynamic_cast<T*>(const_cast<Message*>(this)); }
 };
