@@ -3,6 +3,7 @@
 
 #include "IPathConverter.hpp"
 #include "LSP/MessageWithParams.h"
+#include "wx/string.h"
 #include <wx/filename.h>
 
 namespace LSP
@@ -11,6 +12,7 @@ namespace LSP
 class WXDLLIMPEXP_SDK Request : public LSP::MessageWithParams
 {
     int m_id = wxNOT_FOUND;
+    wxString m_server_name;
 
 public:
     Request();
@@ -19,8 +21,8 @@ public:
     void SetId(int id) { this->m_id = id; }
     int GetId() const { return m_id; }
 
-    virtual JSONItem ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const;
-    virtual void FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter);
+    virtual JSONItem ToJSON(const wxString& name) const;
+    virtual void FromJSON(const JSONItem& json);
 
     /**
      * @brief is this request position dependant? (i.e. the response should be diplsayed where the request was
@@ -33,7 +35,7 @@ public:
      * a given position. Usually, when the user moves while waiting for a response, it makes no sense on
      * displaying the response in the wrong location...
      */
-    virtual bool IsValidAt(const wxFileName& filename, size_t line, size_t col) const
+    virtual bool IsValidAt(const wxString& filename, size_t line, size_t col) const
     {
         wxUnusedVar(filename);
         wxUnusedVar(line);
@@ -45,13 +47,14 @@ public:
      * @brief this method will get called by the protocol for handling the response.
      * Override it in the various requests
      */
-    virtual void OnResponse(const LSP::ResponseMessage& response, wxEvtHandler* owner,
-                            IPathConverter::Ptr_t pathConverter)
+    virtual void OnResponse(const LSP::ResponseMessage& response, wxEvtHandler* owner)
     {
         wxUnusedVar(response);
         wxUnusedVar(owner);
-        wxUnusedVar(pathConverter);
     }
+
+    void SetServerName(const wxString& server_name) { this->m_server_name = server_name; }
+    const wxString& GetServerName() const { return m_server_name; }
 };
 }; // namespace LSP
 
