@@ -5,21 +5,70 @@
 #include "JSON.h"
 #include "JSONObject.h"
 #include "codelite_exports.h"
+#include "fileutils.h"
+
 #include <vector>
 #include <wx/sharedptr.h>
 
 namespace LSP
 {
+enum eSymbolKind {
+    kSK_File = 1,
+    kSK_Module = 2,
+    kSK_Namespace = 3,
+    kSK_Package = 4,
+    kSK_Class = 5,
+    kSK_Method = 6,
+    kSK_Property = 7,
+    kSK_Field = 8,
+    kSK_Constructor = 9,
+    kSK_Enum = 10,
+    kSK_Interface = 11,
+    kSK_Function = 12,
+    kSK_Variable = 13,
+    kSK_Constant = 14,
+    kSK_String = 15,
+    kSK_Number = 16,
+    kSK_Boolean = 17,
+    kSK_Array = 18,
+    kSK_Object = 19,
+    kSK_Key = 20,
+    kSK_Null = 21,
+    kSK_EnumMember = 22,
+    kSK_Struct = 23,
+    kSK_Event = 24,
+    kSK_Operator = 25,
+    kSK_TypeParameter = 26,
+};
+
+class WXDLLIMPEXP_CL URI
+{
+    wxString m_path;
+    wxString m_uri;
+
+private:
+    URI(const wxString& str) = delete;
+    URI& operator=(const wxString& str) = delete;
+
+public:
+    URI() {}
+    ~URI() {}
+
+    static void FromString(const wxString& str, URI* o);
+
+    const wxString& GetPath() const;
+    const wxString& GetUrl() const;
+};
 //===----------------------------------------------------------------------------------
 // TextDocumentContentChangeEvent
 //===----------------------------------------------------------------------------------
 class WXDLLIMPEXP_CL TextDocumentContentChangeEvent : public Serializable
 {
-    std::string m_text;
+    wxString m_text;
 
 public:
-    virtual JSONItem ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const;
-    virtual void FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter);
+    virtual JSONItem ToJSON(const wxString& name) const;
+    virtual void FromJSON(const JSONItem& json);
 
     TextDocumentContentChangeEvent() {}
     TextDocumentContentChangeEvent(const wxString& text)
@@ -27,8 +76,8 @@ public:
     {
     }
     virtual ~TextDocumentContentChangeEvent() {}
-    TextDocumentContentChangeEvent& SetText(const std::string& text);
-    const std::string& GetText() const { return m_text; }
+    TextDocumentContentChangeEvent& SetText(const wxString& text);
+    const wxString& GetText() const { return m_text; }
 };
 
 //===----------------------------------------------------------------------------------
@@ -36,24 +85,23 @@ public:
 //===----------------------------------------------------------------------------------
 class WXDLLIMPEXP_CL TextDocumentIdentifier : public Serializable
 {
-    wxFileName m_filename;
+    URI m_filename;
 
 public:
-    virtual JSONItem ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const;
-    virtual void FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter);
+    virtual JSONItem ToJSON(const wxString& name) const;
+    virtual void FromJSON(const JSONItem& json);
 
     TextDocumentIdentifier() {}
-    TextDocumentIdentifier(const wxFileName& filename)
-        : m_filename(filename)
-    {
-    }
+    TextDocumentIdentifier(const wxString& filename) { URI::FromString(filename, &m_filename); }
+
     virtual ~TextDocumentIdentifier() {}
-    TextDocumentIdentifier& SetFilename(const wxFileName& filename)
+    TextDocumentIdentifier& SetFilename(const wxString& filename)
     {
-        this->m_filename = filename;
+        URI::FromString(filename, &m_filename);
         return *this;
     }
-    const wxFileName& GetFilename() const { return m_filename; }
+    const wxString& GetPath() const { return m_filename.GetPath(); }
+    const wxString& GetPathAsURI() const { return m_filename.GetUrl(); }
 };
 
 //===----------------------------------------------------------------------------------
@@ -64,8 +112,8 @@ class WXDLLIMPEXP_CL VersionedTextDocumentIdentifier : public TextDocumentIdenti
     int m_version = 1;
 
 public:
-    virtual JSONItem ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const;
-    virtual void FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter);
+    virtual JSONItem ToJSON(const wxString& name) const;
+    virtual void FromJSON(const JSONItem& json);
 
     VersionedTextDocumentIdentifier() {}
     VersionedTextDocumentIdentifier(int version)
@@ -90,8 +138,8 @@ class WXDLLIMPEXP_CL Position : public Serializable
     int m_character = wxNOT_FOUND;
 
 public:
-    virtual void FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter);
-    virtual JSONItem ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const;
+    virtual void FromJSON(const JSONItem& json);
+    virtual JSONItem ToJSON(const wxString& name) const;
 
     Position(int line, int col)
         : m_line(line)
@@ -100,6 +148,22 @@ public:
     }
     Position() {}
     virtual ~Position() {}
+    bool operator==(const Position& rhs) const
+    {
+        return this->m_line == rhs.m_line && this->m_character == rhs.m_character;
+    }
+    bool operator!=(const Position& rhs) const { return !(*this == rhs); }
+    bool operator<(const Position& rhs) const
+    {
+        if(this->m_line == rhs.m_line) {
+            return this->m_character < rhs.m_character;
+        } else {
+            return this->m_line < rhs.m_line;
+        }
+    }
+    bool operator>(const Position& rhs) const { return rhs < *this; }
+    bool operator<=(const Position& rhs) const { return !(*this > rhs); }
+    bool operator>=(const Position& rhs) const { return !(*this < rhs); }
     Position& SetCharacter(int character)
     {
         this->m_character = character;
@@ -124,8 +188,8 @@ class WXDLLIMPEXP_CL Range : public Serializable
     Position m_end;
 
 public:
-    virtual void FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter);
-    virtual JSONItem ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const;
+    virtual void FromJSON(const JSONItem& json);
+    virtual JSONItem ToJSON(const wxString& name) const;
 
     Range(const Position& start, const Position& end)
         : m_start(start)
@@ -161,8 +225,8 @@ class WXDLLIMPEXP_CL TextEdit : public LSP::Serializable
 public:
     TextEdit() {}
     virtual ~TextEdit() {}
-    virtual void FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter);
-    virtual JSONItem ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const;
+    virtual void FromJSON(const JSONItem& json);
+    virtual JSONItem ToJSON(const wxString& name) const;
     void SetNewText(const wxString& newText) { this->m_newText = newText; }
     void SetRange(const Range& range) { this->m_range = range; }
     const wxString& GetNewText() const { return m_newText; }
@@ -172,18 +236,21 @@ public:
 
 class WXDLLIMPEXP_CL Location : public Serializable
 {
-    wxString m_uri;
+    URI m_uri;
     Range m_range;
+    wxString m_pattern;
+    wxString m_name;
 
 public:
-    virtual void FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter);
-    virtual JSONItem ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const;
+    virtual void FromJSON(const JSONItem& json);
+    virtual JSONItem ToJSON(const wxString& name) const;
 
     Location(const wxString& uri, const Range& range)
-        : m_uri(uri)
-        , m_range(range)
+        : m_range(range)
     {
+        URI::FromString(uri, &m_uri);
     }
+
     Location() {}
     virtual ~Location() {}
     Location& SetRange(const Range& range)
@@ -191,13 +258,19 @@ public:
         this->m_range = range;
         return *this;
     }
-    Location& SetUri(const wxString& uri)
+    Location& SetPath(const wxString& path)
     {
-        this->m_uri = uri;
+        URI::FromString(path, &m_uri);
         return *this;
     }
+
     const Range& GetRange() const { return m_range; }
-    const wxString& GetUri() const { return m_uri; }
+    const wxString& GetPathAsURI() const { return m_uri.GetUrl(); }
+    const wxString& GetPath() const { return m_uri.GetPath(); }
+    void SetPattern(const wxString& pattern) { this->m_pattern = pattern; }
+    const wxString& GetPattern() const { return m_pattern; }
+    void SetName(const wxString& name) { this->m_name = name; }
+    const wxString& GetName() const { return m_name; }
 };
 
 //===----------------------------------------------------------------------------------
@@ -205,22 +278,23 @@ public:
 //===----------------------------------------------------------------------------------
 class WXDLLIMPEXP_CL TextDocumentItem : public Serializable
 {
-    wxFileName m_uri;
+    URI m_uri;
     wxString m_languageId;
-    std::string m_text;
+    wxString m_text;
     int m_version = 1;
 
 public:
-    virtual void FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter);
-    virtual JSONItem ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const;
+    virtual void FromJSON(const JSONItem& json);
+    virtual JSONItem ToJSON(const wxString& name) const;
 
-    TextDocumentItem(const wxFileName& uri, const wxString& langId, const std::string& text, int version = 1)
-        : m_uri(uri)
-        , m_languageId(langId)
+    TextDocumentItem(const wxString& uri, const wxString& langId, const wxString& text, int version = 1)
+        : m_languageId(langId)
         , m_text(text)
         , m_version(version)
     {
+        URI::FromString(uri, &m_uri);
     }
+
     TextDocumentItem() {}
     virtual ~TextDocumentItem() {}
     TextDocumentItem& SetLanguageId(const wxString& languageId)
@@ -233,19 +307,21 @@ public:
         this->m_text = text;
         return *this;
     }
-    TextDocumentItem& SetUri(const wxFileName& uri)
+    TextDocumentItem& SetUri(const wxString& uri)
     {
-        this->m_uri = uri;
+        URI::FromString(uri, &m_uri);
         return *this;
     }
+
     TextDocumentItem& SetVersion(int version)
     {
         this->m_version = version;
         return *this;
     }
     const wxString& GetLanguageId() const { return m_languageId; }
-    const std::string& GetText() const { return m_text; }
-    const wxFileName& GetUri() const { return m_uri; }
+    const wxString& GetText() const { return m_text; }
+    const wxString& GetPathAsURI() const { return m_uri.GetUrl(); }
+    const wxString& GetPath() const { return m_uri.GetPath(); }
     int GetVersion() const { return m_version; }
 };
 
@@ -269,8 +345,8 @@ public:
     }
     const wxString& GetDocumentation() const { return m_documentation; }
     const wxString& GetLabel() const { return m_label; }
-    virtual void FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter);
-    virtual JSONItem ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const;
+    virtual void FromJSON(const JSONItem& json);
+    virtual JSONItem ToJSON(const wxString& name) const;
 
     typedef std::vector<ParameterInformation> Vec_t;
 };
@@ -305,8 +381,8 @@ public:
     }
     const wxString& GetDocumentation() const { return m_documentation; }
     const wxString& GetLabel() const { return m_label; }
-    virtual void FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter);
-    virtual JSONItem ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const;
+    virtual void FromJSON(const JSONItem& json);
+    virtual JSONItem ToJSON(const wxString& name) const;
 };
 
 class WXDLLIMPEXP_CL SignatureHelp : public LSP::Serializable
@@ -337,8 +413,56 @@ public:
     int GetActiveParameter() const { return m_activeParameter; }
     int GetActiveSignature() const { return m_activeSignature; }
     const SignatureInformation::Vec_t& GetSignatures() const { return m_signatures; }
-    virtual void FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter);
-    virtual JSONItem ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const;
+    virtual void FromJSON(const JSONItem& json);
+    virtual JSONItem ToJSON(const wxString& name) const;
+};
+
+class WXDLLIMPEXP_CL MarkupContent : public LSP::Serializable
+{
+    wxString m_kind;
+    wxString m_value;
+
+public:
+    MarkupContent() {}
+    virtual ~MarkupContent() {}
+    MarkupContent& SetKind(const wxString& kind)
+    {
+        this->m_kind = kind;
+        return *this;
+    }
+    const wxString& GetKind() const { return m_kind; }
+    MarkupContent& SetValue(const wxString& value)
+    {
+        this->m_value = value;
+        return *this;
+    }
+    const wxString& GetValue() const { return m_value; }
+    virtual void FromJSON(const JSONItem& json);
+    virtual JSONItem ToJSON(const wxString& name) const;
+};
+
+class WXDLLIMPEXP_CL Hover : public LSP::Serializable
+{
+    MarkupContent m_contents;
+    Range m_range;
+
+public:
+    Hover() {}
+    virtual ~Hover() {}
+    Hover& SetContents(const MarkupContent& contents)
+    {
+        this->m_contents = contents;
+        return *this;
+    }
+    const MarkupContent& GetContents() const { return m_contents; }
+    Hover& SetRange(const Range& range)
+    {
+        this->m_range = range;
+        return *this;
+    }
+    const Range& GetRange() const { return m_range; }
+    virtual void FromJSON(const JSONItem& json);
+    virtual JSONItem ToJSON(const wxString& name) const;
 };
 
 class WXDLLIMPEXP_CL Diagnostic : public Serializable
@@ -347,8 +471,8 @@ class WXDLLIMPEXP_CL Diagnostic : public Serializable
     wxString m_message;
 
 public:
-    virtual void FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter);
-    virtual JSONItem ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const;
+    virtual void FromJSON(const JSONItem& json);
+    virtual JSONItem ToJSON(const wxString& name) const;
 
     Diagnostic(const Range& range, const wxString& message)
         : m_range(range)
@@ -370,5 +494,113 @@ public:
     }
     const wxString& GetMessage() const { return m_message; }
 };
+
+class WXDLLIMPEXP_CL DocumentSymbol : public Serializable
+{
+    /**
+     * The name of this symbol. Will be displayed in the user interface and therefore must not be
+     * an empty string or a string only consisting of white spaces.
+     */
+    wxString name;
+
+    /**
+     * More detail for this symbol, e.g the signature of a function.
+     */
+    wxString detail;
+
+    /**
+     * The kind of this symbol.
+     */
+    eSymbolKind kind;
+
+    /**
+     * The range enclosing this symbol not including leading/trailing whitespace but everything else
+     * like comments. This information is typically used to determine if the clients cursor is
+     * inside the symbol to reveal in the symbol in the UI.
+     */
+    Range range;
+
+    /**
+     * The range that should be selected and revealed when this symbol is being picked, e.g the name of a function.
+     * Must be contained by the `range`.
+     */
+    Range selectionRange;
+
+    /**
+     * Children of this symbol, e.g. properties of a class.
+     */
+    std::vector<DocumentSymbol> children;
+
+public:
+    virtual void FromJSON(const JSONItem& json);
+    virtual JSONItem ToJSON(const wxString& name) const;
+
+    DocumentSymbol() {}
+    virtual ~DocumentSymbol() {}
+
+    void SetChildren(const std::vector<DocumentSymbol>& children) { this->children = children; }
+    void SetDetail(const wxString& detail) { this->detail = detail; }
+    void SetKind(const eSymbolKind& kind) { this->kind = kind; }
+    void SetName(const wxString& name) { this->name = name; }
+    void SetRange(const Range& range) { this->range = range; }
+    void SetSelectionRange(const Range& selectionRange) { this->selectionRange = selectionRange; }
+    const std::vector<DocumentSymbol>& GetChildren() const { return children; }
+    const wxString& GetDetail() const { return detail; }
+    const eSymbolKind& GetKind() const { return kind; }
+    const wxString& GetName() const { return name; }
+    const Range& GetRange() const { return range; }
+    const Range& GetSelectionRange() const { return selectionRange; }
+};
+
+class WXDLLIMPEXP_CL SymbolInformation : public Serializable
+{
+    /**
+     * The name of this symbol.
+     */
+    wxString name;
+
+    /**
+     * The kind of this symbol.
+     */
+    eSymbolKind kind;
+
+    /**
+     * The location of this symbol. The location's range is used by a tool
+     * to reveal the location in the editor. If the symbol is selected in the
+     * tool the range's start information is used to position the cursor. So
+     * the range usually spans more then the actual symbol's name and does
+     * normally include things like visibility modifiers.
+     *
+     * The range doesn't have to denote a node range in the sense of a abstract
+     * syntax tree. It can therefore not be used to re-construct a hierarchy of
+     * the symbols.
+     */
+    Location location;
+
+    /**
+     * The name of the symbol containing this symbol. This information is for
+     * user interface purposes (e.g. to render a qualifier in the user interface
+     * if necessary). It can't be used to re-infer a hierarchy for the document
+     * symbols.
+     */
+    wxString containerName;
+
+public:
+    virtual void FromJSON(const JSONItem& json);
+    virtual JSONItem ToJSON(const wxString& name) const;
+
+    SymbolInformation() {}
+    virtual ~SymbolInformation() {}
+
+    void SetContainerName(const wxString& containerName) { this->containerName = containerName; }
+    void SetKind(const eSymbolKind& kind) { this->kind = kind; }
+    void SetLocation(const Location& location) { this->location = location; }
+    void SetName(const wxString& name) { this->name = name; }
+    const wxString& GetContainerName() const { return containerName; }
+    const eSymbolKind& GetKind() const { return kind; }
+    const Location& GetLocation() const { return location; }
+    const wxString& GetName() const { return name; }
+};
+
 };     // namespace LSP
 #endif // JSONRPC_BASICTYPES_H
