@@ -7,17 +7,30 @@ namespace LSP
 {
 TextDocumentPositionParams::TextDocumentPositionParams() {}
 
-void TextDocumentPositionParams::FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter)
+void TextDocumentPositionParams::FromJSON(const JSONItem& json)
 {
-    m_textDocument.FromJSON(json, pathConverter);
-    m_position.FromJSON(json, pathConverter);
+    m_textDocument.FromJSON(json["textDocument"]);
+    m_position.FromJSON(json["position"]);
 }
 
-JSONItem TextDocumentPositionParams::ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const
+JSONItem TextDocumentPositionParams::ToJSON(const wxString& name) const
 {
     JSONItem json = JSONItem::createObject(name);
-    json.append(m_textDocument.ToJSON("textDocument", pathConverter));
-    json.append(m_position.ToJSON("position", pathConverter));
+    json.append(m_textDocument.ToJSON("textDocument"));
+    json.append(m_position.ToJSON("position"));
+    return json;
+}
+//===----------------------------------------------
+// SemanticTokensParams
+//===----------------------------------------------
+SemanticTokensParams::SemanticTokensParams() {}
+
+void SemanticTokensParams::FromJSON(const JSONItem& json) { m_textDocument.FromJSON(json["textDocument"]); }
+
+JSONItem SemanticTokensParams::ToJSON(const wxString& name) const
+{
+    JSONItem json = JSONItem::createObject(name);
+    json.append(m_textDocument.ToJSON("textDocument"));
     return json;
 }
 
@@ -26,15 +39,12 @@ JSONItem TextDocumentPositionParams::ToJSON(const wxString& name, IPathConverter
 //===----------------------------------------------------------------------------------
 DidOpenTextDocumentParams::DidOpenTextDocumentParams() {}
 
-void DidOpenTextDocumentParams::FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter)
-{
-    m_textDocument.FromJSON(json, pathConverter);
-}
+void DidOpenTextDocumentParams::FromJSON(const JSONItem& json) { m_textDocument.FromJSON(json["textDocument"]); }
 
-JSONItem DidOpenTextDocumentParams::ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const
+JSONItem DidOpenTextDocumentParams::ToJSON(const wxString& name) const
 {
     JSONItem json = JSONItem::createObject(name);
-    json.append(m_textDocument.ToJSON("textDocument", pathConverter));
+    json.append(m_textDocument.ToJSON("textDocument"));
     return json;
 }
 
@@ -43,15 +53,12 @@ JSONItem DidOpenTextDocumentParams::ToJSON(const wxString& name, IPathConverter:
 //===----------------------------------------------------------------------------------
 DidCloseTextDocumentParams::DidCloseTextDocumentParams() {}
 
-void DidCloseTextDocumentParams::FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter)
-{
-    m_textDocument.FromJSON(json, pathConverter);
-}
+void DidCloseTextDocumentParams::FromJSON(const JSONItem& json) { m_textDocument.FromJSON(json["textDocument"]); }
 
-JSONItem DidCloseTextDocumentParams::ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const
+JSONItem DidCloseTextDocumentParams::ToJSON(const wxString& name) const
 {
     JSONItem json = JSONItem::createObject(name);
-    json.append(m_textDocument.ToJSON("textDocument", pathConverter));
+    json.append(m_textDocument.ToJSON("textDocument"));
     return json;
 }
 
@@ -60,28 +67,28 @@ JSONItem DidCloseTextDocumentParams::ToJSON(const wxString& name, IPathConverter
 //===----------------------------------------------------------------------------------
 DidChangeTextDocumentParams::DidChangeTextDocumentParams() {}
 
-void DidChangeTextDocumentParams::FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter)
+void DidChangeTextDocumentParams::FromJSON(const JSONItem& json)
 {
-    m_textDocument.FromJSON(json, pathConverter);
+    m_textDocument.FromJSON(json["textDocument"]);
     m_contentChanges.clear();
     if(json.hasNamedObject("contentChanges")) {
         JSONItem arr = json.namedObject("contentChanges");
         int count = arr.arraySize();
         for(int i = 0; i < count; ++i) {
             TextDocumentContentChangeEvent c;
-            c.FromJSON(arr.arrayItem(i), pathConverter);
+            c.FromJSON(arr.arrayItem(i));
             m_contentChanges.push_back(c);
         }
     }
 }
 
-JSONItem DidChangeTextDocumentParams::ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const
+JSONItem DidChangeTextDocumentParams::ToJSON(const wxString& name) const
 {
     JSONItem json = JSONItem::createObject(name);
-    json.append(m_textDocument.ToJSON("textDocument", pathConverter));
+    json.append(m_textDocument.ToJSON("textDocument"));
     JSONItem arr = JSONItem::createArray("contentChanges");
     for(size_t i = 0; i < m_contentChanges.size(); ++i) {
-        arr.arrayAppend(m_contentChanges[i].ToJSON("", pathConverter));
+        arr.arrayAppend(m_contentChanges[i].ToJSON(""));
     }
     json.append(arr);
     return json;
@@ -92,16 +99,16 @@ JSONItem DidChangeTextDocumentParams::ToJSON(const wxString& name, IPathConverte
 //===----------------------------------------------------------------------------------
 DidSaveTextDocumentParams::DidSaveTextDocumentParams() {}
 
-void DidSaveTextDocumentParams::FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter)
+void DidSaveTextDocumentParams::FromJSON(const JSONItem& json)
 {
-    m_textDocument.FromJSON(json, pathConverter);
-    m_text = json.namedObject("text").toString();
+    m_textDocument.FromJSON(json["textDocument"]);
+    m_text = json["text"].toString();
 }
 
-JSONItem DidSaveTextDocumentParams::ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const
+JSONItem DidSaveTextDocumentParams::ToJSON(const wxString& name) const
 {
     JSONItem json = JSONItem::createObject(name);
-    json.append(m_textDocument.ToJSON("textDocument", pathConverter));
+    json.append(m_textDocument.ToJSON("textDocument"));
     json.addProperty("text", m_text);
     return json;
 }
@@ -111,14 +118,44 @@ JSONItem DidSaveTextDocumentParams::ToJSON(const wxString& name, IPathConverter:
 //===----------------------------------------------------------------------------------
 CompletionParams::CompletionParams() {}
 
-void CompletionParams::FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter)
+void CompletionParams::FromJSON(const JSONItem& json) { TextDocumentPositionParams::FromJSON(json); }
+
+JSONItem CompletionParams::ToJSON(const wxString& name) const
 {
-    TextDocumentPositionParams::FromJSON(json, pathConverter);
+    JSONItem json = TextDocumentPositionParams::ToJSON(name);
+    return json;
 }
 
-JSONItem CompletionParams::ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const
+//===----------------------------------------------------------------------------------
+// DocumentSymbolParams
+//===----------------------------------------------------------------------------------
+DocumentSymbolParams::DocumentSymbolParams() {}
+
+void DocumentSymbolParams::FromJSON(const JSONItem& json) { m_textDocument.FromJSON(json["textDocument"]); }
+
+JSONItem DocumentSymbolParams::ToJSON(const wxString& name) const
 {
-    JSONItem json = TextDocumentPositionParams::ToJSON(name, pathConverter);
+    JSONItem json = JSONItem::createObject(name);
+    json.append(m_textDocument.ToJSON("textDocument"));
+    return json;
+}
+
+ReferenceParams::ReferenceParams(bool includeDeclaration)
+    : m_includeDeclaration(includeDeclaration)
+{
+}
+
+void ReferenceParams::FromJSON(const JSONItem& json)
+{
+    TextDocumentPositionParams::FromJSON(json);
+    m_includeDeclaration = json["context"]["includeDeclaration"].toBool(m_includeDeclaration);
+}
+
+JSONItem ReferenceParams::ToJSON(const wxString& name) const
+{
+    JSONItem json = TextDocumentPositionParams::ToJSON(name);
+    auto context = json.AddObject("context");
+    context.addProperty("includeDeclaration", m_includeDeclaration);
     return json;
 }
 }; // namespace LSP
