@@ -1,20 +1,19 @@
 #ifndef SERVICEPROVIDERMANAGER_H
 #define SERVICEPROVIDERMANAGER_H
 
-#include "codelite_exports.h"
 #include "ServiceProvider.h"
-#include <vector>
+#include "cl_command_event.h"
+#include "codelite_exports.h"
 #include <unordered_map>
+#include <vector>
 #include <wx/event.h>
 
 namespace std
 {
-    template <>
-    struct hash<eServiceType>
-    {
-        std::size_t operator()(const eServiceType& t) const { return static_cast<std::size_t>(t); }
-    };
-}
+template <> struct hash<eServiceType> {
+    std::size_t operator()(const eServiceType& t) const { return static_cast<std::size_t>(t); }
+};
+} // namespace std
 
 // Similar to EventNotifier class.
 // But process events in order. Each 'handler' (aka: ServiceProvider)
@@ -33,19 +32,23 @@ protected:
     void Unregister(ServiceProvider* provider);
     eServiceType GetServiceFromEvent(wxEvent& event);
 
+    void OnActiveEditorChanged(wxCommandEvent& event);
+    void OnEditorSaved(clCommandEvent& event);
+    void RequestSemanticsHighlights(const wxString& filename);
+
 public:
     static ServiceProviderManager& Get();
-    
+
     /**
      * @brief remove all providers
      */
     void UnregisterAll();
-    
+
     /**
      * @brief process service event
      */
     virtual bool ProcessEvent(wxEvent& event);
-    
+
     /**
      * @brief sort the service providers for a given type
      */
