@@ -1,13 +1,14 @@
 #include "UnixProcess.h"
 #if defined(__WXGTK__) || defined(__WXOSX__)
+#include "file_logger.h"
+
+#include <cl_command_event.h>
+#include <fileutils.h>
+#include <processreaderthread.h>
 #include <signal.h>
 #include <string.h>
 #include <sys/select.h>
 #include <sys/types.h>
-#include "file_logger.h"
-#include <cl_command_event.h>
-#include <processreaderthread.h>
-#include <fileutils.h>
 
 UnixProcess::UnixProcess(wxEvtHandler* owner, const wxArrayString& args)
     : m_owner(owner)
@@ -16,12 +17,14 @@ UnixProcess::UnixProcess(wxEvtHandler* owner, const wxArrayString& args)
 
     // Open the pipes
     if(!m_childStdin.Open() || !m_childStderr.Open() || !m_childStdout.Open()) {
-        clERROR() << "Could not open redirection pipes." << strerror(errno);
+        clERROR() << "Could not open redirection pipes." << strerror(errno) << endl;
         return;
     }
 
     child_pid = fork();
-    if(child_pid == -1) { clERROR() << _("Failed to start child process") << strerror(errno); }
+    if(child_pid == -1) {
+        clERROR() << _("Failed to start child process") << strerror(errno) << endl;
+    }
     if(child_pid == 0) {
         // In child process
         dup2(m_childStdin.GetReadFd(), STDIN_FILENO);
@@ -33,7 +36,13 @@ UnixProcess::UnixProcess(wxEvtHandler* owner, const wxArrayString& args)
 
         char** argv = new char*[args.size() + 1];
         for(size_t i = 0; i < args.size(); ++i) {
-            std::string cstr_arg = FileUtils::ToStdString(args[i]);
+            wxString wx_arg = args[i];
+            wx_arg.Trim();
+            if(wx_arg.StartsWith("\"") && wx_arg.EndsWith("\"") && wx_arg.size() >= 2) {
+                wx_arg.Remove(0, 1).RemoveLast();
+            }
+
+            std::string cstr_arg = FileUtils::ToStdString(wx_arg);
             argv[i] = new char[cstr_arg.length() + 1];
             strcpy(argv[i], cstr_arg.c_str());
             argv[i][cstr_arg.length()] = 0;
@@ -43,7 +52,7 @@ UnixProcess::UnixProcess(wxEvtHandler* owner, const wxArrayString& args)
         int errNo = errno;
         if(result == -1) {
             // Note: no point writing to stdout here, it has been redirected
-            clERROR() << "Error: Failed to launch program" << args << "." << strerror(errNo);
+            clERROR() << "Error: Failed to launch program" << args << "." << strerror(errNo) << endl;
             exit(EXIT_FAILURE);
         }
     } else {
@@ -86,7 +95,9 @@ bool UnixProcess::ReadAll(int fd, std::string& content, int timeoutMilliseconds)
             if(len > 0) {
                 buff[len] = 0;
                 content.append(buff);
-                if(content.length() >= MAX_BUFF_SIZE) { return true; }
+                if(content.length() >= MAX_BUFF_SIZE) {
+                    return true;
+                }
                 // clear the tv struct so next select() call will return immediately
                 tv.tv_usec = 0;
                 tv.tv_sec = 0;
@@ -125,7 +136,7 @@ bool UnixProcess::Write(int fd, const std::string& message, std::atomic_bool& sh
             tmp.erase(0, bytes);
         }
     }
-    clDEBUG() << "Wrote message of size:" << message.length();
+    LOG_IF_TRACE { clDEBUG1() << "Wrote message of size:" << message.length() << endl; }
     return tmp.empty();
 }
 
@@ -142,12 +153,16 @@ int UnixProcess::Wait()
 
 void UnixProcess::Stop()
 {
-    if(child_pid != wxNOT_FOUND) { ::kill(child_pid, SIGTERM); }
+    if(child_pid != wxNOT_FOUND) {
+        ::kill(child_pid, SIGTERM);
+    }
 }
 
 void UnixProcess::Write(const std::string& message)
 {
-    if(!m_writerThread) { return; }
+    if(!m_writerThread) {
+        return;
+    }
     m_outgoingQueue.Post(message);
 }
 
@@ -161,7 +176,7 @@ void UnixProcess::StartWriterThread()
                     UnixProcess::Write(fd, buffer, std::ref(process->m_goingDown));
                 }
             }
-            clDEBUG() << "UnixProcess writer thread: going down";
+            clDEBUG() << "UnixProcess writer thread: going down" << endl;
         },
         this, m_childStdin.GetWriteFd());
 }
@@ -174,6 +189,10 @@ void UnixProcess::StartReaderThread()
                 std::string content;
                 if(!ReadAll(stdoutFd, content, 10)) {
                     clProcessEvent evt(wxEVT_ASYNC_PROCESS_TERMINATED);
+                    wxString error_message;
+                    int exit_code = process->Wait();
+                    error_message << "Process exit code (" << exit_code << "):" << strerror(exit_code);
+                    evt.SetString(error_message);
                     process->m_owner->AddPendingEvent(evt);
                     break;
                 } else if(!content.empty()) {
@@ -192,7 +211,7 @@ void UnixProcess::StartReaderThread()
                     process->m_owner->AddPendingEvent(evt);
                 }
             }
-            clDEBUG() << "UnixProcess reader thread: going down";
+            clDEBUG() << "UnixProcess reader thread: going down" << endl;
         },
         this, m_childStdout.GetReadFd(), m_childStderr.GetReadFd());
 }
