@@ -5,9 +5,7 @@ clFileSystemEvent::clFileSystemEvent(wxEventType commandType, int winid)
 {
 }
 
-clFileSystemEvent::~clFileSystemEvent()
-{
-}
+clFileSystemEvent::~clFileSystemEvent() {}
 
 clFileSystemEvent::clFileSystemEvent(const clFileSystemEvent& event)
     : clCommandEvent(event)
@@ -18,10 +16,11 @@ clFileSystemEvent::clFileSystemEvent(const clFileSystemEvent& event)
 clFileSystemEvent& clFileSystemEvent::operator=(const clFileSystemEvent& src)
 {
     clCommandEvent::operator=(src);
-    
+
     // clFileSystemEvent specifics
     m_path = src.m_path;
     m_newpath = src.m_newpath;
     m_paths = src.m_paths;
+    m_flags = src.m_flags;
     return *this;
 }
