@@ -26,6 +26,13 @@ public:
         kIsSymlink = (1 << 3),
     };
 
+    enum eSearchFlags {
+        SF_NONE = 0,
+        SF_EXCLUDE_HIDDEN_DIRS = (1 << 0),
+        SF_DONT_FOLLOW_SYMLINKS = (1 << 1),
+        SF_DEFAULT = SF_EXCLUDE_HIDDEN_DIRS | SF_DONT_FOLLOW_SYMLINKS,
+    };
+
 public:
     clFilesScanner();
     virtual ~clFilesScanner();
@@ -58,6 +65,16 @@ public:
      */
     size_t ScanNoRecurse(const wxString& rootFolder, clFilesScanner::EntryData::Vec_t& results,
                          const wxString& matchSpec = "*");
+
+    /**
+     * @brief a raw version for scanning files
+     * @param rootFolder the root folder
+     * @param on_folder_cb called whenever a folder is found. return true to traverse into this folder or false to skip
+     * it
+     * @param on_file_cb called when a file is found.
+     */
+    void ScanWithCallbacks(const wxString& rootFolder, std::function<bool(const wxString&)>&& on_folder_cb,
+                           std::function<void(const wxArrayString&)>&& on_file_cb, size_t search_flags = SF_DEFAULT);
 };
 
 #endif // CLFILESCOLLECTOR_H
