@@ -27,6 +27,8 @@
 #define CLCOMMANDEVENT_H
 
 #include "LSP/CompletionItem.h"
+#include "UIBreakpoint.hpp"
+#include "asyncprocess.h"
 #include "clDebuggerBreakpoint.hpp"
 #include "clEditorConfig.h"
 #include "clGotoEntry.h"
@@ -34,6 +36,7 @@
 #include "entry.h"
 #include "ssh_account_info.h"
 #include "wxCodeCompletionBoxEntry.hpp"
+
 #include <vector>
 #include <wx/arrstr.h>
 #include <wx/event.h>
@@ -240,6 +243,34 @@ public:
 typedef void (wxEvtHandler::*clSourceControlEventFunction)(clSourceControlEvent&);
 #define clSourceControlEventHandler(func) wxEVENT_HANDLER_CAST(clSourceControlEventFunction, func)
 
+/// Source control event
+struct WXDLLIMPEXP_CL RecentWorkspace {
+    wxString m_category;
+    wxString m_account; // for remote workspaces, which account does this workspace belongs to
+    wxString m_name;
+    wxString path;
+};
+
+class WXDLLIMPEXP_CL clRecentWorkspaceEvent : public clCommandEvent
+{
+protected:
+    std::vector<RecentWorkspace> m_workspaces;
+
+public:
+    clRecentWorkspaceEvent(wxEventType commandType = wxEVT_NULL, int winid = 0);
+    clRecentWorkspaceEvent(const clRecentWorkspaceEvent& event);
+    clRecentWorkspaceEvent& operator=(const clRecentWorkspaceEvent& src);
+    virtual ~clRecentWorkspaceEvent();
+    virtual wxEvent* Clone() const;
+
+    void SetWorkspaces(const std::vector<RecentWorkspace>& workspaces) { this->m_workspaces = workspaces; }
+    const std::vector<RecentWorkspace>& GetWorkspaces() const { return m_workspaces; }
+    std::vector<RecentWorkspace>& GetWorkspaces() { return m_workspaces; }
+};
+
+typedef void (wxEvtHandler::*clRecentWorkspaceEventFunction)(clRecentWorkspaceEvent&);
+#define clRecentWorkspaceEventHandler(func) wxEVENT_HANDLER_CAST(clRecentWorkspaceEventFunction, func)
+
 /// a clCodeCompletionEvent
 class WXDLLIMPEXP_CL clCodeCompletionEvent : public clCommandEvent
 {
@@ -425,6 +456,7 @@ class WXDLLIMPEXP_CL clDebugEvent : public clCommandEvent
     bool m_isSSHDebugging = false;
     wxString m_sshAccount;
     wxString m_alternateDebuggerPath; // Holds the path to an alternate debugger executable
+    UIBreakpoint m_uiBreakpoint;
 
 public:
     // Special features not available by all the debuggers
@@ -446,6 +478,9 @@ public:
     virtual ~clDebugEvent();
     virtual wxEvent* Clone() const { return new clDebugEvent(*this); };
 
+    void SetUiBreakpoint(const UIBreakpoint& uiBreakpoint) { this->m_uiBreakpoint = uiBreakpoint; }
+    const UIBreakpoint& GetUiBreakpoint() const { return m_uiBreakpoint; }
+
     void SetAlternateDebuggerPath(const wxString& alternateDebuggerPath)
     {
         this->m_alternateDebuggerPath = alternateDebuggerPath;
@@ -825,7 +860,6 @@ class WXDLLIMPEXP_CL clLanguageServerEvent : public clCommandEvent
 public:
     enum eFlags {
         kEnabled = (1 << 0),
-        kSSHEnabled = (1 << 1),
         kDisaplyDiags = (1 << 2),
     };
 
@@ -843,10 +877,9 @@ protected:
     wxString m_lspName;
     wxString m_lspCommand;
     size_t m_flags = 0;
-    wxString m_sshAccount;
     size_t m_priority = 50;
     wxString m_connectionString;
-    std::vector<std::pair<wxString, wxString>> m_enviroment;
+    clEnvList_t m_enviroment;
     wxString m_initOptions;
     wxArrayString m_languages;
     eAction m_action = kInvalidAction;
@@ -865,7 +898,6 @@ public:
     void SetLspCommand(const wxString& lspCommand) { this->m_lspCommand = lspCommand; }
     void SetLspName(const wxString& lspName) { this->m_lspName = lspName; }
     void SetPriority(size_t priority) { this->m_priority = priority; }
-    void SetSshAccount(const wxString& sshAccount) { this->m_sshAccount = sshAccount; }
     const wxString& GetConnectionString() const { return m_connectionString; }
     size_t GetFlags() const { return m_flags; }
     const wxString& GetInitOptions() const { return m_initOptions; }
@@ -873,11 +905,12 @@ public:
     const wxString& GetLspCommand() const { return m_lspCommand; }
     const wxString& GetLspName() const { return m_lspName; }
     size_t GetPriority() const { return m_priority; }
-    const wxString& GetSshAccount() const { return m_sshAccount; }
     void SetAction(const eAction& action) { this->m_action = action; }
     const eAction& GetAction() const { return m_action; }
     void SetRootUri(const wxString& rootUri) { this->m_rootUri = rootUri; }
     const wxString& GetRootUri() const { return m_rootUri; }
+    void SetEnviroment(const clEnvList_t& enviroment) { this->m_enviroment = enviroment; }
+    const clEnvList_t& GetEnviroment() const { return m_enviroment; }
 };
 
 typedef void (wxEvtHandler::*clLanguageServerEventFunction)(clLanguageServerEvent&);
