@@ -7,10 +7,12 @@ wxDEFINE_EVENT(wxEVT_EDITOR_CONFIG_CHANGED, wxCommandEvent);
 
 // workspace loading related event
 wxDEFINE_EVENT(wxEVT_WORKSPACE_LOADED, clWorkspaceEvent);
+wxDEFINE_EVENT(wxEVT_WORKSPACE_PLUGIN_OPEN, clWorkspaceEvent);
 wxDEFINE_EVENT(wxEVT_WORKSPACE_RELOAD_STARTED, clWorkspaceEvent);
 wxDEFINE_EVENT(wxEVT_WORKSPACE_RELOAD_ENDED, clWorkspaceEvent);
 wxDEFINE_EVENT(wxEVT_WORKSPACE_CLOSED, clWorkspaceEvent);
 wxDEFINE_EVENT(wxEVT_WORKSPACE_CLOSING, clWorkspaceEvent);
+wxDEFINE_EVENT(wxEVT_WORKSPACE_FILES_SCANNED, clWorkspaceEvent);
 
 wxDEFINE_EVENT(wxEVT_WORKSPACE_CONFIG_CHANGED, wxCommandEvent);
 wxDEFINE_EVENT(wxEVT_FILE_VIEW_INIT_DONE, wxCommandEvent);
@@ -116,6 +118,7 @@ wxDEFINE_EVENT(wxEVT_FINDBAR_RELEASE_EDITOR, clFindEvent);
 wxDEFINE_EVENT(wxEVT_FINDINFILES_DLG_SHOWING, clFindInFilesEvent);
 wxDEFINE_EVENT(wxEVT_FINDINFILES_DLG_DISMISSED, clFindInFilesEvent);
 wxDEFINE_EVENT(wxEVT_FINDINFILES_OPEN_MATCH, clFindInFilesEvent);
+wxDEFINE_EVENT(wxEVT_FINDINFILES_STOP_SEARCH, clFindInFilesEvent);
 wxDEFINE_EVENT(wxEVT_CMD_BUILD_PROJECT_ONLY, wxCommandEvent);
 wxDEFINE_EVENT(wxEVT_CMD_CLEAN_PROJECT_ONLY, wxCommandEvent);
 wxDEFINE_EVENT(wxEVT_CL_THEME_CHANGED, wxCommandEvent);
@@ -143,6 +146,8 @@ wxDEFINE_EVENT(wxEVT_DBG_UI_SHOW_CURSOR, clDebugEvent);
 wxDEFINE_EVENT(wxEVT_DBG_UI_RESTART, clDebugEvent);
 wxDEFINE_EVENT(wxEVT_DBG_IS_RUNNING, clDebugEvent);
 wxDEFINE_EVENT(wxEVT_DBG_UI_TOGGLE_BREAKPOINT, clDebugEvent);
+wxDEFINE_EVENT(wxEVT_DBG_UI_BREAKPOINT_ADDED, clDebugEvent);
+wxDEFINE_EVENT(wxEVT_DBG_UI_BREAKPOINT_DELETED, clDebugEvent);
 wxDEFINE_EVENT(wxEVT_DBG_CAN_INTERACT, clDebugEvent);
 wxDEFINE_EVENT(wxEVT_DBG_EXPR_TOOLTIP, clDebugEvent);
 
@@ -181,6 +186,8 @@ wxDEFINE_EVENT(wxEVT_EDITOR_INITIALIZING, clCommandEvent);
 wxDEFINE_EVENT(wxEVT_FILE_SYSTEM_UPDATED, clFileSystemEvent);
 wxDEFINE_EVENT(wxEVT_FILES_MODIFIED_REPLACE_IN_FILES, clFileSystemEvent);
 wxDEFINE_EVENT(wxEVT_SAVE_SESSION_NEEDED, clCommandEvent);
+wxDEFINE_EVENT(wxEVT_SESSION_LOADING, clCommandEvent);
+wxDEFINE_EVENT(wxEVT_SESSION_LOADED, clCommandEvent);
 wxDEFINE_EVENT(wxEVT_ENVIRONMENT_VARIABLES_MODIFIED, clCommandEvent);
 wxDEFINE_EVENT(wxEVT_DND_FOLDER_DROPPED, clCommandEvent);
 wxDEFINE_EVENT(wxEVT_DND_FILE_DROPPED, clCommandEvent);
@@ -216,3 +223,5 @@ wxDEFINE_EVENT(wxEVT_LSP_ENABLE_SERVER, clLanguageServerEvent);
 wxDEFINE_EVENT(wxEVT_LSP_DISABLE_SERVER, clLanguageServerEvent);
 wxDEFINE_EVENT(wxEVT_DOWNLOAD_FILE, clCommandEvent);
 wxDEFINE_EVENT(wxEVT_OPEN_FILE, clCommandEvent);
+wxDEFINE_EVENT(wxEVT_RECENT_WORKSPACE, clRecentWorkspaceEvent);
+wxDEFINE_EVENT(wxEVT_FILE_MODIFIED_EXTERNALLY, clFileSystemEvent);
