@@ -26,11 +26,13 @@
 #include "fileextmanager.h"
 
 #include "JSON.h"
+#include "file_logger.h"
 #include "fileutils.h"
 
 #include <wx/filename.h>
 #include <wx/regex.h>
 #include <wx/thread.h>
+#include <wx/tokenzr.h>
 #include <wx/xml/xml.h>
 
 struct Matcher {
@@ -50,17 +52,26 @@ struct Matcher {
 
     bool Matches(const wxString& in) const
     {
-        if(m_regex) {
-            return m_regex->Matches(in);
-        } else {
-            return in.Find(m_exactMatch) != wxNOT_FOUND;
+        auto lines = ::wxStringTokenize(in, "\r\n", wxTOKEN_STRTOK);
+        bool use_regex = m_regex;
+        for(const auto& line : lines) {
+            if(use_regex && m_regex->Matches(line)) {
+                return true;
+            } else if(!use_regex && line.Find(m_exactMatch) != wxNOT_FOUND) {
+                return true;
+            }
         }
+        return false;
     }
 };
-
-static std::unordered_map<wxString, FileExtManager::FileType> m_map;
-static std::vector<Matcher> m_matchers;
-static bool init_done = false;
+namespace
+{
+std::unordered_map<wxString, FileExtManager::FileType> m_map;
+std::unordered_map<wxString, std::vector<FileExtManager::FileType>> m_language_bundle;
+std::unordered_map<int, wxString> m_file_type_to_lang;
+std::vector<Matcher> m_matchers;
+bool init_done = false;
+}; // namespace
 
 void FileExtManager::Init()
 {
@@ -72,8 +83,8 @@ void FileExtManager::Init()
         m_map[wxT("c++")] = TypeSourceCpp;
         m_map[wxT("as")] = TypeSourceCpp;  // AngelScript files are handled as C++ source files in CodeLite
         m_map[wxT("ino")] = TypeSourceCpp; // Arduino sketches
-        m_map[wxT("c")] = TypeSourceC;
 
+        m_map[wxT("c")] = TypeSourceC;
         m_map[wxT("h")] = TypeHeader;
         m_map[wxT("hpp")] = TypeHeader;
         m_map[wxT("hxx")] = TypeHeader;
@@ -85,7 +96,9 @@ void FileExtManager::Init()
         m_map[wxT("res")] = TypeResource;
 
         m_map[wxT("y")] = TypeYacc;
+
         m_map[wxT("l")] = TypeLex;
+
         m_map[wxT("ui")] = TypeQtForm;
         m_map[wxT("qrc")] = TypeQtResource;
         m_map[wxT("qml")] = TypeJS;
@@ -93,6 +106,7 @@ void FileExtManager::Init()
         m_map[wxT("project")] = TypeProject;
         m_map[wxT("workspace")] = TypeWorkspace;
         m_map[wxT("fbp")] = TypeFormbuilder;
+
         m_map[wxT("cdp")] = TypeCodedesigner;
         m_map[wxT("erd")] = TypeErd;
 
@@ -112,6 +126,7 @@ void FileExtManager::Init()
         m_map[wxT("ts")] = TypeJS; // TypeScript, but we consider this a JavaScript
         m_map[wxT("py")] = TypePython;
         m_map["json"] = TypeJSON;
+        m_map["conf"] = TypeJSON; // CodeLite configuration files are marked as "conf"
 
         // Java file
         m_map[wxT("java")] = TypeJava;
@@ -164,6 +179,7 @@ void FileExtManager::Init()
         m_map["s"] = TypeAsm;
         m_map["yaml"] = TypeYAML;
         m_map["yml"] = TypeYAML;
+        m_map["clangd"] = TypeYAML;
         m_map["db"] = TypeDatabase;
         m_map["tags"] = TypeDatabase;
         m_map["lua"] = TypeLua;
@@ -173,6 +189,33 @@ void FileExtManager::Init()
         m_map["diff"] = TypeDiff;
 
         m_map["rb"] = TypeRuby;
+        m_map["md"] = TypeMarkdown;
+        m_map["dart"] = TypeDart;
+
+        m_language_bundle.insert({ "C/C++", { TypeSourceCpp, TypeSourceC, TypeHeader } });
+        m_language_bundle.insert({ "Windows resource files", { TypeResource } });
+        m_language_bundle.insert({ "Yacc", { TypeYacc } });
+        m_language_bundle.insert({ "Lex", { TypeLex } });
+        m_language_bundle.insert({ "Xml", { TypeProject, TypeWorkspace, TypeXml, TypeXRC, TypeSvg, TypeFormbuilder } });
+        m_language_bundle.insert({ "Yaml", { TypeYAML } });
+        m_language_bundle.insert({ "Json",
+                                   { TypeJSON, TypeWorkspaceFileSystem, TypeWxCrafter, TypeWorkspaceDocker,
+                                     TypeWorkspaceNodeJS, TypeWorkspacePHP } });
+        m_language_bundle.insert({ "Rust", { TypeRust } });
+        m_language_bundle.insert({ "Ruby", { TypeRuby } });
+        m_language_bundle.insert({ "Shell script", { TypeShellScript } });
+        m_language_bundle.insert({ "Java", { TypeJava } });
+        m_language_bundle.insert({ "Javascript/Typescript", { TypeJS } });
+        m_language_bundle.insert({ "Python", { TypePython } });
+        m_language_bundle.insert({ "PHP", { TypePhp } });
+        m_language_bundle.insert({ "CMake", { TypeCMake } });
+
+        // build the reverse search table: file type -> language
+        for(auto vt : m_language_bundle) {
+            for(auto t : vt.second) {
+                m_file_type_to_lang.insert({ (int)t, vt.first });
+            }
+        }
 
         // Initialize regexes:
         m_matchers.push_back(Matcher("#[ \t]*!(.*?)sh", TypeShellScript));
@@ -197,6 +240,17 @@ void FileExtManager::Init()
         m_matchers.push_back(Matcher("#include[ \t]+[\\<\"]", TypeSourceCpp));
     }
 }
+std::unordered_map<wxString, FileExtManager::FileType> FileExtManager::GetAllSupportedFileTypes()
+{
+    Init();
+    return m_map;
+}
+
+std::unordered_map<wxString, std::vector<FileExtManager::FileType>> FileExtManager::GetLanguageBundles()
+{
+    Init();
+    return m_language_bundle;
+}
 
 FileExtManager::FileType FileExtManager::GetType(const wxString& filename, FileExtManager::FileType defaultType)
 {
@@ -211,13 +265,17 @@ FileExtManager::FileType FileExtManager::GetType(const wxString& filename, FileE
     e.MakeLower();
     e.Trim().Trim(false);
 
-    std::unordered_map<wxString, FileType>::iterator iter = m_map.find(e);
+    auto iter = m_map.find(e);
     if(iter == m_map.end()) {
         // try to see if the file is a makefile
         if(fn.GetFullName().CmpNoCase(wxT("makefile")) == 0) {
             return TypeMakefile;
         } else if(fn.GetFullName().Lower() == "dockerfile") {
             return TypeDockerfile;
+        } else if(fn.GetFullName().CmpNoCase("README") == 0) {
+            return TypeMarkdown;
+        } else if(fn.GetFullName().CmpNoCase(".clangd") == 0) {
+            return TypeYAML;
         } else {
             // try auto detecting
             FileType autoDetectType = defaultType;
@@ -276,11 +334,22 @@ bool FileExtManager::AutoDetectByContent(const wxString& filename, FileExtManage
 {
     wxString fileContent;
     if(!FileUtils::ReadBufferFromFile(filename, fileContent, 1024)) {
+        clWARNING() << "Failed to read file's content" << endl;
         return false;
     }
+    return GetContentType(fileContent, fileType);
+}
 
+bool FileExtManager::GetContentType(const wxString& string_content, FileExtManager::FileType& fileType)
+{
     for(size_t i = 0; i < m_matchers.size(); ++i) {
-        if(m_matchers[i].Matches(fileContent)) {
+        if(m_matchers[i].Matches(string_content)) {
+            LOG_IF_TRACE
+            {
+                if(m_matchers[i].m_regex) {
+                    clDEBUG1() << "Matching part is:" << m_matchers[i].m_regex->GetMatch(string_content, 0) << endl;
+                }
+            }
             fileType = m_matchers[i].m_fileType;
             return true;
         }
@@ -327,3 +396,12 @@ bool FileExtManager::IsSymlinkFolder(const wxString& filename)
     return wxFileName::Exists(filename, wxFILE_EXISTS_NO_FOLLOW | wxFILE_EXISTS_SYMLINK) &&
            wxFileName::DirExists(filename);
 }
+
+wxString FileExtManager::GetLanguageFromType(FileExtManager::FileType file_type)
+{
+    if(m_file_type_to_lang.count((int)file_type) == 0) {
+        return wxEmptyString;
+    }
+
+    return m_file_type_to_lang.find((int)file_type)->second;
+}
\ No newline at end of file
