@@ -29,6 +29,7 @@
 #include "codelite_exports.h"
 #include "macros.h"
 #include "wx/filename.h"
+
 #include <wx/filename.h>
 #include <wx/log.h>
 
@@ -68,7 +69,10 @@ public:
      * @brief set the file content (replacing it)
      */
     static bool WriteFileContent(const wxFileName& fn, const wxString& content, const wxMBConv& conv = wxConvUTF8);
-
+    /**
+     * @brief append content to end of the file
+     */
+    static bool AppendFileContent(const wxFileName& fn, const wxString& content, const wxMBConv& conv = wxConvUTF8);
     /**
      * @brief open file explorer at given path
      */
@@ -197,6 +201,14 @@ public:
      */
     static bool IsDirectory(const wxString& filename);
 
+    /**
+     * @brief is `filename` an executable?
+     * on Linux/macOS, we check if the file is an ELF file, on Windows, we check if the
+     * file has the extension `.exe` or `.dll`
+     */
+    static bool IsBinaryExecutable(const wxString& filename);
+    static bool IsBinaryExecutable(const wxFileName& filename) { return IsBinaryExecutable(filename.GetFullPath()); }
+
     /**
      * @brief set permissions to filename
      */
