@@ -32,11 +32,16 @@
 #endif
 
 #include "asyncprocess.h"
+#include "cl_command_event.h"
+#include "codelite_events.h"
+#include "file_logger.h"
 #include "fileutils.h"
+#include "processreaderthread.h"
 #include "procutils.h"
 #include "winprocess.h"
 #include "wx/tokenzr.h"
 
+#include <memory>
 #include <stdio.h>
 #ifdef __WXMSW__
 #include "wx/msw/private.h"
@@ -51,29 +56,32 @@
 
 #endif
 
-static wxString WrapWithShell(const wxString& cmd)
+//-------------------------------------------------------------------
+// clShellProcessEvent
+//-------------------------------------------------------------------
+wxDEFINE_EVENT(wxEVT_SHELL_ASYNC_PROCESS_TERMINATED, clShellProcessEvent);
+clShellProcessEvent::clShellProcessEvent(const clShellProcessEvent& event) { *this = event; }
+
+clShellProcessEvent::clShellProcessEvent(wxEventType commandType, int winid)
+    : clCommandEvent(commandType, winid)
 {
-    wxString command;
-#ifdef __WXMSW__
-    wxChar* shell = wxGetenv(wxT("COMSPEC"));
-    if(!shell)
-        shell = (wxChar*)wxT("CMD.EXE");
-    command << shell << wxT(" /C ");
-    if(cmd.StartsWith("\"") && !cmd.EndsWith("\"")) {
-        command << "\"" << cmd << "\"";
-    } else {
-        command << cmd;
-    }
-#else
-    command << wxT("/bin/sh -c '");
-    wxString tmpcmd = cmd;
-    // escape any single quoutes
-    tmpcmd.Replace("'", "\\'");
-    command << tmpcmd << wxT("'");
-#endif
-    return command;
 }
 
+clShellProcessEvent::~clShellProcessEvent() {}
+
+clShellProcessEvent& clShellProcessEvent::operator=(const clShellProcessEvent& src)
+{
+    clCommandEvent::operator=(src);
+    m_pid = src.m_pid;
+    m_exitCode = src.m_exitCode;
+    m_output = src.m_output;
+    return *this;
+}
+
+//-------------------------------------------------------------------
+// clShellProcessEvent
+//-------------------------------------------------------------------
+
 ProcUtils::ProcUtils() {}
 
 ProcUtils::~ProcUtils() {}
@@ -153,7 +161,7 @@ PidVec_t ProcUtils::PS(const wxString& name)
     PID_COL = 0;
     MIN_COLUMNS_NUMBER = 5;
 #endif
-    command = WrapWithShell(command);
+    command = WrapInShell(command);
 
     wxString processOutput;
     IProcess::Ptr_t p(::CreateSyncProcess(command, IProcessCreateDefault | IProcessCreateWithHiddenConsole));
@@ -267,7 +275,10 @@ wxString ProcUtils::GetProcessNameByPid(long pid)
 
 void ProcUtils::ExecuteCommand(const wxString& command, wxArrayString& output, long flags)
 {
-    FILE* fp = nullptr;
+#ifdef __WXMSW__
+    wxExecute(command, output, flags);
+#else
+    FILE* fp;
     char line[512];
     memset(line, 0, sizeof(line));
     fp = popen(command.mb_str(wxConvUTF8), "r");
@@ -278,6 +289,7 @@ void ProcUtils::ExecuteCommand(const wxString& command, wxArrayString& output, l
         }
         pclose(fp);
     }
+#endif
 }
 
 void ProcUtils::ExecuteInteractiveCommand(const wxString& command) { wxShell(command); }
@@ -550,7 +562,49 @@ bool ProcUtils::Locate(const wxString& name, wxString& where)
 
 void ProcUtils::SafeExecuteCommand(const wxString& command, wxArrayString& output)
 {
+#ifdef __WXMSW__
+    wxString errMsg;
+    LOG_IF_TRACE { clDEBUG1() << "executing process:" << command << endl; }
+    std::unique_ptr<WinProcess> proc{ WinProcess::Execute(command, errMsg) };
+    if(!proc) {
+        return;
+    }
+
+    // wait for the process to terminate
+    wxString tmpbuf;
+    wxString buff;
+
+    LOG_IF_TRACE { clDEBUG1() << "reading process output..." << endl; }
+    while(proc->IsAlive()) {
+        tmpbuf.Clear();
+        if(proc->Read(tmpbuf)) {
+            // as long as we read something, dont sleep...
+            buff << tmpbuf;
+        } else {
+            wxThread::Sleep(1);
+        }
+    }
+    tmpbuf.Clear();
+    LOG_IF_TRACE
+    {
+        clDEBUG1() << "process terminated" << endl;
+        // Read any unread output
+        clDEBUG1() << "reading process output remainder..." << endl;
+    }
+    proc->Read(tmpbuf);
+    while(!tmpbuf.IsEmpty()) {
+        buff << tmpbuf;
+        tmpbuf.Clear();
+        proc->Read(tmpbuf);
+    }
+    proc->Cleanup();
+    LOG_IF_TRACE { clDEBUG1() << "reading process output remainder...done" << endl; }
+
+    // Convert buff into wxArrayString
+    output = ::wxStringTokenize(buff, "\n", wxTOKEN_STRTOK);
+#else
     ProcUtils::ExecuteCommand(command, output);
+#endif
 }
 
 wxString ProcUtils::SafeExecuteCommand(const wxString& command)
@@ -568,3 +622,114 @@ wxString ProcUtils::SafeExecuteCommand(const wxString& command)
     }
     return strOut;
 }
+
+wxString ProcUtils::GrepCommandOutput(const std::vector<wxString>& cmd, const wxString& find_what)
+{
+    IProcess::Ptr_t proc(::CreateAsyncProcess(nullptr, cmd, IProcessCreateDefault | IProcessCreateSync));
+    if(!proc) {
+        return wxEmptyString;
+    }
+
+    wxString output;
+    proc->WaitForTerminate(output);
+    auto lines = ::wxStringTokenize(output, "\n", wxTOKEN_STRTOK);
+    for(wxString& line : lines) {
+        line.Trim();
+        if(line.Contains(find_what)) {
+            return line;
+        }
+    }
+    return wxEmptyString;
+}
+
+namespace
+{
+class ProcessHelper : public wxProcess
+{
+    wxEvtHandler* m_handler = nullptr;
+    wxString m_output_file;
+    wxString m_process_output;
+
+private:
+    void ReadOutput()
+    {
+        FileUtils::Deleter d{ m_output_file };
+        FileUtils::ReadFileContent(m_output_file, m_process_output);
+    }
+
+public:
+    ProcessHelper(wxEvtHandler* sink, const wxString& output_file)
+        : m_handler(sink)
+        , m_output_file(output_file)
+    {
+    }
+    virtual ~ProcessHelper() {}
+
+    // Notify about the process termination
+    void OnTerminate(int pid, int status) override
+    {
+        if(status == 0) {
+            ReadOutput();
+        }
+
+        clShellProcessEvent event_terminated{ wxEVT_SHELL_ASYNC_PROCESS_TERMINATED };
+        event_terminated.SetPid(pid);
+        event_terminated.SetExitCode(status);
+        event_terminated.SetOutput(m_process_output);
+        m_handler->QueueEvent(event_terminated.Clone());
+        delete this;
+    }
+};
+} // namespace
+
+bool ProcUtils::ShellExecAsync(const wxString& command, long* pid, wxEvtHandler* sink)
+{
+    wxString filename = wxFileName::CreateTempFileName("clTempFile");
+    wxString theCommand = wxString::Format("%s > \"%s\" 2>&1", command, filename);
+    WrapInShell(theCommand);
+    long rc = ::wxExecute(theCommand, wxEXEC_ASYNC | wxEXEC_HIDE_CONSOLE, new ProcessHelper(sink, filename), nullptr);
+    if(rc > 0) {
+        *pid = rc;
+    }
+    return rc > 0;
+}
+
+int ProcUtils::ShellExecSync(const wxString& command, wxString* output)
+{
+    wxString filename = wxFileName::CreateTempFileName("clTempFile");
+    wxString theCommand = wxString::Format("%s > \"%s\" 2>&1", command, filename);
+    WrapInShell(theCommand);
+
+    wxArrayString out;
+    wxArrayString err;
+    int exit_code = ::wxExecute(theCommand, out, err, wxEXEC_SYNC | wxEXEC_HIDE_CONSOLE);
+
+    // read the process output and return it
+    FileUtils::Deleter d{ filename };
+    FileUtils::ReadFileContent(filename, *output);
+    return exit_code;
+}
+
+wxString& ProcUtils::WrapInShell(wxString& cmd)
+{
+    wxString command;
+#ifdef __WXMSW__
+    wxString shell = wxGetenv("COMSPEC");
+    if(shell.IsEmpty()) {
+        shell = "CMD.EXE";
+    }
+    command << shell << " /C ";
+    if(cmd.StartsWith("\"") && !cmd.EndsWith("\"")) {
+        command << "\"" << cmd << "\"";
+    } else {
+        command << cmd;
+    }
+#else
+    command << "/bin/sh -c '";
+    // escape any single quoutes
+    cmd.Replace("'", "\\'");
+    command << cmd << "'";
+#endif
+    cmd.swap(command);
+    return cmd;
+}
\ No newline at end of file
