@@ -25,11 +25,13 @@
 
 #ifdef __WXMSW__
 #include "winprocess_impl.h"
+
 #include "file_logger.h"
 #include "fileutils.h"
 #include "processreaderthread.h"
 #include "procutils.h"
 #include "smart_ptr.h"
+
 #include <atomic>
 #include <memory>
 #include <wx/filefn.h>
@@ -103,10 +105,11 @@ template <typename T> bool WriteStdin(const T& buffer, HANDLE hStdin, HANDLE hPr
         DWORD dwWritten = 0;
         if(!WriteFile(hStdin, buffer.c_str() + offset, bytesLeft, &dwWritten, NULL)) {
             int errorCode = GetLastError();
-            clERROR() << ">> WriteStdin: (WriteFile) error:" << errorCode;
+            LOG_IF_DEBUG { clDEBUG() << ">> WriteStdin: (WriteFile) error:" << errorCode << endl; }
             return false;
         }
         if(!CheckIsAlive(hProcess)) {
+            LOG_IF_DEBUG { clDEBUG() << "WriteStdin failed. Process is not alive" << endl; }
             return false;
         }
         if(dwWritten == 0) {
@@ -158,14 +161,12 @@ public:
         while(!thr->m_shutdown.load()) {
             std::string cstr;
             if(Q.ReceiveTimeout(50, cstr) == wxMSGQUEUE_NO_ERROR) {
-                if(!WriteStdin(cstr, hStdin, thr->m_hProcess)) {
-                    clERROR() << "WriteFile error:" << GetLastError();
-                } else {
-                    clDEBUG1() << "Writer thread: wrote buffer of" << cstr.length() << "bytes";
+                if(WriteStdin(cstr, hStdin, thr->m_hProcess)) {
+                    LOG_IF_TRACE { clDEBUG1() << "Writer thread: wrote buffer of" << cstr.length() << "bytes"; }
                 }
             }
         }
-        clDEBUG1() << "Write thread going down";
+        LOG_IF_TRACE { clDEBUG1() << "Write thread going down"; }
     }
 
     void Write(const std::string& buffer) { m_outgoingQueue.Post(buffer); }
@@ -177,10 +178,14 @@ static wxString __JoinArray(const wxArrayString& args, size_t flags)
     if(flags & IProcessWrapInShell) {
         // CMD /C [command] ...
         // Make sure that the first command is wrapped with "" if it contains spaces
-        clDEBUG1() << "==> __JoinArray called for" << args << endl;
-        clDEBUG1() << "args[2] is:" << args[2] << endl;
+        LOG_IF_TRACE
+        {
+            clDEBUG1() << "==> __JoinArray called for" << args << endl;
+            clDEBUG1() << "args[2] is:" << args[2] << endl;
+        }
+
         if((args.size() > 3) && (!args[2].StartsWith("\"")) && (args[2].Contains(" "))) {
-            clDEBUG() << "==> Fixing" << args << endl;
+            LOG_IF_DEBUG { clDEBUG() << "==> Fixing" << args << endl; }
             wxArrayString tmparr = args;
             wxString& firstCommand = tmparr[2];
             firstCommand.Prepend("\"").Append("\"");
@@ -213,7 +218,7 @@ IProcess* WinProcessImpl::Execute(wxEvtHandler* parent, const wxArrayString& arg
                                   const wxString& workingDirectory, IProcessCallback* cb)
 {
     wxString cmd = __JoinArray(args, flags);
-    clDEBUG1() << "Windows process starting:" << cmd << endl;
+    LOG_IF_TRACE { clDEBUG1() << "Windows process starting:" << cmd << endl; }
     return Execute(parent, cmd, flags, workingDirectory, cb);
 }
 
@@ -363,8 +368,7 @@ IProcess* WinProcessImpl::Execute(wxEvtHandler* parent, const wxString& cmd, siz
         siStartInfo.wShowWindow = SW_HIDE;
         creationFlags = CREATE_NEW_CONSOLE | CREATE_NEW_PROCESS_GROUP;
     }
-    clDEBUG1() << "Running process:" << cmd << endl;
-
+    LOG_IF_TRACE { clDEBUG1() << "Running process:" << cmd << endl; }
     BOOL ret = CreateProcess(NULL,
                              cmd.wchar_str(),   // shell line execution command
                              NULL,              // process security attributes
@@ -447,12 +451,13 @@ bool WinProcessImpl::Read(wxString& buff, wxString& buffErr)
     if(!DoReadFromPipe(hChildStderrRdDup, ((m_flags & IProcessStderrEvent) ? buffErr : buff))) {
         le2 = GetLastError();
     }
+
     if(!DoReadFromPipe(hChildStdoutRdDup, buff)) {
         le1 = GetLastError();
     }
     if((le1 == ERROR_NO_DATA) && (le2 == ERROR_NO_DATA)) {
         if(IsAlive()) {
-            wxThread::Sleep(5);
+            wxThread::Sleep(1);
             return true;
         }
     }
