@@ -25,6 +25,7 @@
 #ifndef DBGINTERFACE_H
 #define DBGINTERFACE_H
 
+#include "asyncprocess.h"
 #include "cl_command_event.h"
 #include "consolefinder.h"
 #include "debugger.h"
@@ -72,8 +73,6 @@ class DbgGdb : public wxEvtHandler, public IDebugger
     bool m_reverseDebugging;
     wxStringSet_t m_reversableCommands;
     bool m_isRecording;
-    bool m_isSSHDebugging = false;
-    SSHAccountInfo m_sshAccount;
 
 public:
     int m_internalBpId;
@@ -90,7 +89,7 @@ protected:
     void DoProcessAsyncCommand(wxString& line, wxString& id);
 
 protected:
-    bool DoLocateGdbExecutable(const wxString& debuggerPath, wxString& dbgExeName);
+    bool DoLocateGdbExecutable(const wxString& debuggerPath, wxString& dbgExeName, const DebugSessionInfo& sessionInfo);
     bool DoInitializeGdb(const DebugSessionInfo& sessionInfo);
     void SetCliHandler(DbgCmdCLIHandler* handler);
     DbgCmdCLIHandler* GetCliHandler();
@@ -112,16 +111,13 @@ public:
     void SetIsRecording(bool isRecording) { this->m_isRecording = isRecording; }
     bool IsRecording() const { return m_isRecording; }
 
-    bool IsSSHDebugging() const { return m_isSSHDebugging; }
-    const SSHAccountInfo& GetSshAccount() const { return m_sshAccount; }
-
 public:
     DbgGdb();
     virtual ~DbgGdb();
 
     //------ IDebugger ---------
-    virtual bool Start(const DebugSessionInfo& si);
-    virtual bool Attach(const DebugSessionInfo& si);
+    virtual bool Start(const DebugSessionInfo& si, clEnvList_t* env_list);
+    virtual bool Attach(const DebugSessionInfo& si, clEnvList_t* env_list);
     virtual bool Run(const wxString& args, const wxString& comm);
     virtual bool Stop();
     virtual bool Break(const clDebuggerBreakpoint& bp);
