@@ -19,8 +19,8 @@ protected:
     void DoDockerComposeContextMenu(wxMenu* menu, const wxString& docker_compose);
 
 protected:
-    void OnWorkspaceClosed(wxCommandEvent& event);
-    void OnWorkspaceOpened(wxCommandEvent& event);
+    void OnWorkspaceClosed(clWorkspaceEvent& event);
+    void OnWorkspaceOpened(clWorkspaceEvent& event);
     void OnFileContextMenu(clContextMenuEvent& event);
     void OnFindInFilesDismissed(clFindInFilesEvent& event);
     void OnFindInFilesShowing(clFindInFilesEvent& event); // override parent's method
