@@ -23,7 +23,7 @@ public:
     //--------------------------------------------
     // Abstract methods
     //--------------------------------------------
-    virtual void CreateToolBar(clToolBar* toolbar);
+    virtual void CreateToolBar(clToolBarGeneric* toolbar);
     /**
      * @brief Add plugin menu to the "Plugins" menu item in the menu bar
      */
