@@ -27,6 +27,7 @@
 
 #include "BreakpointInfoArray.hpp"
 #include "archive.h"
+#include "asyncprocess.h"
 #include "clDebuggerBreakpoint.hpp"
 #include "cl_standard_paths.h"
 #include "macros.h"
@@ -35,6 +36,7 @@
 #include "wx/arrstr.h"
 #include "wx/event.h"
 #include "wx/string.h"
+
 #include <wx/stdpaths.h>
 #include <wx/string.h>
 
@@ -146,6 +148,14 @@ typedef std::vector<LocalVariable> LocalVariables;
 typedef std::vector<DisassembleEntry> DisassembleEntryVec_t;
 typedef std::vector<DbgRegister> DbgRegistersVec_t;
 
+#define READ_CONFIG_PARAM(name, value) \
+    {                                  \
+        decltype(value) dummy;         \
+        if(arch.Read(name, dummy)) {   \
+            value = dummy;             \
+        }                              \
+    }
+
 class DebuggerInformation : public SerializedObject
 {
 public:
@@ -166,7 +176,7 @@ public:
     bool catchThrow;
     bool showTooltipsOnlyWithControlKeyIsDown;
     bool debugAsserts;
-    wxString startupCommands;
+    wxString initFileCommands;
     int maxDisplayStringSize = 200;
     int maxDisplayElements = 100;
     bool resolveLocals;
@@ -191,9 +201,9 @@ public:
         , useRelativeFilePaths(false)
         , maxCallStackFrames(500)
         , catchThrow(false)
-        , showTooltipsOnlyWithControlKeyIsDown(false)
+        , showTooltipsOnlyWithControlKeyIsDown(true)
         , debugAsserts(false)
-        , startupCommands(wxEmptyString)
+        , initFileCommands(wxEmptyString)
         , resolveLocals(true)
         , autoExpandTipItems(true)
         , applyBreakpointsAfterProgramStarted(false)
@@ -209,64 +219,68 @@ public:
 
     void Serialize(Archive& arch)
     {
-        arch.Write(wxT("name"), name);
-        arch.Write(wxT("path"), path);
-        arch.Write(wxT("enableDebugLog"), enableDebugLog);
-        arch.Write(wxT("enablePendingBreakpoints"), enablePendingBreakpoints);
-        arch.Write(wxT("breakAtWinMain"), breakAtWinMain);
-        arch.Write(wxT("showTerminal"), showTerminal);
-        arch.Write(wxT("consoleCommand"), consoleCommand);
-        arch.Write(wxT("useRelativeFilePaths"), useRelativeFilePaths);
-        arch.Write(wxT("maxCallStackFrames"), maxCallStackFrames);
-        arch.Write(wxT("catchThrow"), catchThrow);
-        arch.Write(wxT("showTooltips"), showTooltipsOnlyWithControlKeyIsDown);
-        arch.Write(wxT("debugAsserts"), debugAsserts);
-        arch.WriteCData(wxT("startupCommands"), startupCommands);
-        arch.Write(wxT("maxDisplayStringSize"), maxDisplayStringSize);
+        arch.Write("name", name);
+        arch.Write("path", path);
+        arch.Write("enableDebugLog", enableDebugLog);
+        arch.Write("enablePendingBreakpoints", enablePendingBreakpoints);
+        arch.Write("breakAtWinMain", breakAtWinMain);
+        arch.Write("showTerminal", showTerminal);
+        arch.Write("consoleCommand", consoleCommand);
+        arch.Write("useRelativeFilePaths", useRelativeFilePaths);
+        arch.Write("maxCallStackFrames", maxCallStackFrames);
+        arch.Write("catchThrow", catchThrow);
+        arch.Write("showTooltipsOnlyWithControlKeyIsDown", showTooltipsOnlyWithControlKeyIsDown);
+        arch.Write("debugAsserts", debugAsserts);
+        arch.WriteCData("startupCommands", initFileCommands);
+        arch.Write("maxDisplayStringSize", maxDisplayStringSize);
         arch.Write("maxDisplayElements", maxDisplayElements);
-        arch.Write(wxT("resolveLocals"), resolveLocals);
-        arch.Write(wxT("autoExpandTipItems"), autoExpandTipItems);
-        arch.Write(wxT("applyBreakpointsAfterProgramStarted"), applyBreakpointsAfterProgramStarted);
-        arch.Write(wxT("whenBreakpointHitRaiseCodelite"), whenBreakpointHitRaiseCodelite);
-        arch.Write(wxT("cygwinPathCommand"), cygwinPathCommand);
-        arch.Write(wxT("charArrAsPtr"), charArrAsPtr);
-        arch.Write(wxT("enableGDBPrettyPrinting"), enableGDBPrettyPrinting);
-        arch.Write(wxT("defaultHexDisplay"), defaultHexDisplay);
+        arch.Write("resolveLocals", resolveLocals);
+        arch.Write("autoExpandTipItems", autoExpandTipItems);
+        arch.Write("applyBreakpointsAfterProgramStarted", applyBreakpointsAfterProgramStarted);
+        arch.Write("whenBreakpointHitRaiseCodelite", whenBreakpointHitRaiseCodelite);
+        arch.Write("charArrAsPtr", charArrAsPtr);
+        arch.Write("enableGDBPrettyPrinting", enableGDBPrettyPrinting);
+        arch.Write("defaultHexDisplay", defaultHexDisplay);
         arch.Write("flags", flags);
+        arch.Write("cygwinPathCommand", cygwinPathCommand);
     }
 
     void DeSerialize(Archive& arch)
     {
-        arch.Read(wxT("name"), name);
-        arch.Read(wxT("path"), path);
-        arch.Read(wxT("enableDebugLog"), enableDebugLog);
-        arch.Read(wxT("enablePendingBreakpoints"), enablePendingBreakpoints);
-        arch.Read(wxT("breakAtWinMain"), breakAtWinMain);
-        arch.Read(wxT("showTerminal"), showTerminal);
-        arch.Read(wxT("consoleCommand"), consoleCommand);
-        arch.Read(wxT("useRelativeFilePaths"), useRelativeFilePaths);
-        arch.Read(wxT("maxCallStackFrames"), maxCallStackFrames);
-        arch.Read(wxT("catchThrow"), catchThrow);
-        arch.Read(wxT("showTooltips"), showTooltipsOnlyWithControlKeyIsDown);
-        arch.Read(wxT("debugAsserts"), debugAsserts);
+        READ_CONFIG_PARAM("name", name);
+        READ_CONFIG_PARAM("path", path);
+        READ_CONFIG_PARAM("enableDebugLog", enableDebugLog);
+        READ_CONFIG_PARAM("enablePendingBreakpoints", enablePendingBreakpoints);
+        READ_CONFIG_PARAM("breakAtWinMain", breakAtWinMain);
+        READ_CONFIG_PARAM("showTerminal", showTerminal);
+        READ_CONFIG_PARAM("consoleCommand", consoleCommand);
+        READ_CONFIG_PARAM("useRelativeFilePaths", useRelativeFilePaths);
+        READ_CONFIG_PARAM("maxCallStackFrames", maxCallStackFrames);
+        READ_CONFIG_PARAM("catchThrow", catchThrow);
+        READ_CONFIG_PARAM("showTooltipsOnlyWithControlKeyIsDown", showTooltipsOnlyWithControlKeyIsDown);
+        READ_CONFIG_PARAM("debugAsserts", debugAsserts);
 
-        arch.ReadCData(wxT("startupCommands"), startupCommands);
+        arch.ReadCData(wxT("startupCommands"), initFileCommands);
 
-        wxFileName codeliteInstallDir = wxFileName(clStandardPaths::Get().GetUserDataDir(), "gdb_printers");
-        startupCommands.Replace("$CodeLiteGdbPrinters", codeliteInstallDir.GetFullPath());
-        startupCommands.Trim();
+        wxFileName fnPrettyPrintersDir = wxFileName(clStandardPaths::Get().GetUserDataDir(), wxEmptyString);
+        fnPrettyPrintersDir.AppendDir("gdb_printers");
+        initFileCommands.Replace("${CODELITE_GDB_PRINTERS_DIR}", fnPrettyPrintersDir.GetPath());
+        initFileCommands.Trim();
 
-        arch.Read(wxT("maxDisplayStringSize"), maxDisplayStringSize);
-        arch.Read(wxT("maxDisplayElements"), maxDisplayElements);
-        arch.Read(wxT("resolveLocals"), resolveLocals);
-        arch.Read(wxT("autoExpandTipItems"), autoExpandTipItems);
-        arch.Read(wxT("applyBreakpointsAfterProgramStarted"), applyBreakpointsAfterProgramStarted);
-        arch.Read(wxT("whenBreakpointHitRaiseCodelite"), whenBreakpointHitRaiseCodelite);
-        arch.Read(wxT("cygwinPathCommand"), cygwinPathCommand);
-        arch.Read(wxT("charArrAsPtr"), charArrAsPtr);
-        arch.Read(wxT("enableGDBPrettyPrinting"), enableGDBPrettyPrinting);
-        arch.Read(wxT("defaultHexDisplay"), defaultHexDisplay);
-        arch.Read("flags", flags);
+        // use Linux style syntax
+        initFileCommands.Replace("\\", "/");
+
+        READ_CONFIG_PARAM("maxDisplayStringSize", maxDisplayStringSize);
+        READ_CONFIG_PARAM("maxDisplayElements", maxDisplayElements);
+        READ_CONFIG_PARAM("resolveLocals", resolveLocals);
+        READ_CONFIG_PARAM("autoExpandTipItems", autoExpandTipItems);
+        READ_CONFIG_PARAM("applyBreakpointsAfterProgramStarted", applyBreakpointsAfterProgramStarted);
+        READ_CONFIG_PARAM("whenBreakpointHitRaiseCodelite", whenBreakpointHitRaiseCodelite);
+        READ_CONFIG_PARAM("charArrAsPtr", charArrAsPtr);
+        READ_CONFIG_PARAM("enableGDBPrettyPrinting", enableGDBPrettyPrinting);
+        READ_CONFIG_PARAM("defaultHexDisplay", defaultHexDisplay);
+        READ_CONFIG_PARAM("flags", flags);
+        READ_CONFIG_PARAM("cygwinPathCommand", cygwinPathCommand);
     }
 };
 
@@ -311,7 +325,6 @@ public:
 
 /// This structure contains the information needed
 /// by the debugger to start a debug session
-class SSHAccountInfo;
 class DebugSessionInfo
 {
 public:
@@ -320,13 +333,13 @@ public:
     int PID = wxNOT_FOUND;                    /// Process ID to attach
     wxString cwd;                             /// Working directory
     std::vector<clDebuggerBreakpoint> bpList; /// Breakpoint list
-    wxArrayString cmds;                       /// Startup commands
-    wxString ttyName;                         /// TTY to use
-    wxArrayString searchPaths;                /// Additional search paths to pass to the debugger
-    bool enablePrettyPrinting = true;         /// Should we enable pretty printing?
-    bool isSSHDebugging = false;              /// Debugging over SSH
-    SSHAccountInfo* accountInfo =
-        nullptr; /// When isSSHDebugging is set true, this will hold the account details to login into
+    wxArrayString cmds;               /// Start-up commands (to be run after gdb starts, but before the user interacts)
+    wxString ttyName;                 /// TTY to use
+    wxArrayString searchPaths;        /// Additional search paths to pass to the debugger
+    bool enablePrettyPrinting = true; /// Should we enable pretty printing?
+    bool isSSHDebugging = false;      /// Debugging over SSH
+    wxString sshAccountName;          /// When isSSHDebugging is set true, holds the ssh account name
+    wxString init_file_content;       /// content to place in a .gdbinit like file
 };
 
 class IDebuggerObserver;
@@ -356,7 +369,9 @@ protected:
     wxString m_name;
     bool m_isRemoteDebugging;
     bool m_isRemoteExtended;
+    bool m_isSSHDebugging = false;
     wxString m_debuggeeProjectName;
+    wxString m_sshAccount;
 
 public:
     IDebugger()
@@ -371,6 +386,7 @@ public:
 
     void SetObserver(IDebuggerObserver* observer) { m_observer = observer; }
 
+    const wxString& GetSshAccount() const { return m_sshAccount; }
     IDebuggerObserver* GetObserver() { return m_observer; }
 
     void SetEnvironment(EnvironmentConfig* env) { m_env = env; }
@@ -380,12 +396,12 @@ public:
     DebuggerInformation GetDebuggerInformation() { return m_info; }
 
     void SetIsRemoteDebugging(bool isRemoteDebugging) { this->m_isRemoteDebugging = isRemoteDebugging; }
-
     bool GetIsRemoteDebugging() const { return m_isRemoteDebugging; }
-
     void SetIsRemoteExtended(bool isRemoteExtended) { this->m_isRemoteExtended = isRemoteExtended; }
-
     bool GetIsRemoteExtended() const { return m_isRemoteExtended; }
+    void SetIsSSHDebugging(bool isSSHDebugging) { this->m_isSSHDebugging = isSSHDebugging; }
+    bool IsSSHDebugging() const { return m_isSSHDebugging; }
+    void SetSshAccount(const wxString& sshAccount) { this->m_sshAccount = sshAccount; }
 
     /**
      * \brief Sets the logging level 'on the fly'
@@ -407,13 +423,13 @@ public:
      * \brief start the debugger by running an executable
      * \return true on success, false otherwise
      */
-    virtual bool Start(const DebugSessionInfo& info) = 0;
+    virtual bool Start(const DebugSessionInfo& info, clEnvList_t* env_list) = 0;
 
     /**
      * \brief start the debugger by attaching to a process
      * \return true on success, false otherwise
      */
-    virtual bool Attach(const DebugSessionInfo& info) = 0;
+    virtual bool Attach(const DebugSessionInfo& info, clEnvList_t* env_list) = 0;
 
     /**
      * \brief Run the program under the debugger. This method must be called *after* Start() has been called
