@@ -6,12 +6,11 @@
 
 #include <vector>
 
-using namespace std;
 using namespace LSP;
 
 class LSPOutlineViewDlg : public LSPOutlineViewDlgBase
 {
-    vector<SymbolInformation> m_symbols;
+    std::vector<SymbolInformation> m_symbols;
 
 private:
     void DoSelectionActivate();
@@ -23,7 +22,7 @@ public:
     LSPOutlineViewDlg(wxWindow* parent);
     virtual ~LSPOutlineViewDlg();
 
-    void SetSymbols(const vector<SymbolInformation>& symbols);
+    void SetSymbols(const std::vector<SymbolInformation>& symbols);
 
 protected:
     virtual void OnListKeyDown(wxKeyEvent& event);
