@@ -1,8 +1,12 @@
 #include "LSPPythonDetector.hpp"
+
+#include "Platform.hpp"
 #include "asyncprocess.h"
-#include "clPythonLocator.hpp"
+#include "file_logger.h"
 #include "globals.h"
+#include "procutils.h"
 #include "wx/filename.h"
+
 #include <cstdlib>
 
 LSPPythonDetector::LSPPythonDetector()
@@ -14,41 +18,25 @@ LSPPythonDetector::~LSPPythonDetector() {}
 
 bool LSPPythonDetector::DoLocate()
 {
-    clPythonLocator locator;
-    if(!locator.Locate()) {
+    wxString python;
+
+    // locate python3
+    if(!ThePlatform->Which("python", &python) && !ThePlatform->Which("python3", &python)) {
         return false;
     }
 
-    const wxString& pythonExe = locator.GetPython();
-    const wxString& pip = locator.GetPip();
-
     // Check if python-language-server is installed
-    wxFileName fnPython(pip);
-    wxString command;
-    command << pip;
-    ::WrapWithQuotes(command);
-
-    command << " list";
-
-    IProcess::Ptr_t proc(::CreateSyncProcess(command, IProcessCreateDefault, fnPython.GetPath()));
-    if(!proc) {
-        return false;
-    }
-
-    wxString output;
-    proc->WaitForTerminate(output);
-
-    if(!output.Contains("python-lsp-server")) {
+    wxString output = ProcUtils::GrepCommandOutput({ python, "-m", "pip", "list" }, "python-lsp-server");
+    if(output.empty()) {
+        // Not installed
         return false;
     }
 
     // We have it installed
+    wxString command;
+    ::WrapWithQuotes(python);
 
-    command.Clear();
-    command << pythonExe;
-    ::WrapWithQuotes(command);
-
-    command << " -m pylsp";
+    command << python << " -m pylsp";
     SetCommand(command);
     // Add support for the languages
     GetLangugaes().Add("python");
