@@ -1,6 +1,7 @@
 #include "LanguageServerConfig.h"
-#include <algorithm>
+
 #include <NodeJSLocator.h>
+#include <algorithm>
 
 LanguageServerConfig::LanguageServerConfig()
     : clConfigItem("LSPConfig")
@@ -66,19 +67,25 @@ void LanguageServerConfig::AddServer(const LanguageServerEntry& server)
 
 void LanguageServerConfig::RemoveServer(const wxString& name)
 {
-    if(m_servers.count(name)) { m_servers.erase(name); }
+    if(m_servers.count(name)) {
+        m_servers.erase(name);
+    }
 }
 
 const LanguageServerEntry& LanguageServerConfig::GetServer(const wxString& name) const
 {
     static LanguageServerEntry NullEntry;
-    if(m_servers.count(name) == 0) { return NullEntry; }
+    if(m_servers.count(name) == 0) {
+        return NullEntry;
+    }
     return m_servers.find(name)->second;
 }
 
 LanguageServerEntry& LanguageServerConfig::GetServer(const wxString& name)
 {
     static LanguageServerEntry NullEntry;
-    if(m_servers.count(name) == 0) { return NullEntry; }
+    if(m_servers.count(name) == 0) {
+        return NullEntry;
+    }
     return m_servers[name];
 }
