@@ -1,8 +1,8 @@
 #ifndef LANGUAGESERVERPAGE_H
 #define LANGUAGESERVERPAGE_H
 
-#include "UI.h"
 #include "LanguageServerEntry.h"
+#include "UI.h"
 
 class LanguageServerPage : public LanguageServerPageBase
 {
@@ -15,8 +15,8 @@ public:
     LanguageServerEntry GetData() const;
 
 protected:
-    virtual void OnBrowseWD(wxCommandEvent& event);
-    virtual void OnCommandUI(wxUpdateUIEvent& event);
-    virtual void OnSuggestLanguages(wxCommandEvent& event);
+    void OnBrowseWD(wxCommandEvent& event) override;
+    void OnCommandUI(wxUpdateUIEvent& event) override;
+    void OnSuggestLanguages(wxCommandEvent& event) override;
 };
 #endif // LANGUAGESERVERPAGE_H
