@@ -1,8 +1,12 @@
 #ifndef OUTPUTDEBUGSTRINGTHREAD_H
 #define OUTPUTDEBUGSTRINGTHREAD_H
 
-#include <wx/thread.h> // Base class: wxThread
 #include "cl_command_event.h"
+#include "wx/defs.h"
+#ifdef __WINDOWS__          // __WINDOWS__ defined by wx/defs.h
+#include "wx/msw/wrapwin.h" // includes windows.h
+#endif
+#include <wx/thread.h> // Base class: wxThread
 
 wxDECLARE_EVENT(wxEVT_OUTPUT_DEBUG_STRING, clCommandEvent);
 class OutputDebugStringThread : public wxThread
@@ -42,7 +46,7 @@ public:
      * \note This call must be called from the context of other thread (e.g. main thread)
      */
     void Start(int priority = WXTHREAD_DEFAULT_PRIORITY);
-    
+
     /**
      * @brief enable collection
      */
