@@ -30,7 +30,7 @@
 /** Implementing BuildTabSettingsBase */
 class BuildTabSetting : public BuildTabSettingsBase
 {
-    bool m_isModified;
+    bool m_isModified = false;
 
 public:
     BuildTabSetting(wxWindow* parent);
@@ -38,13 +38,11 @@ public:
     void SetIsModified(bool isModified) { this->m_isModified = isModified; }
     bool IsModified() const { return m_isModified; }
 
-    void SelectFont();
     void Save();
     void OnUpdateUI(wxUpdateUIEvent& event);
 
 protected:
-    virtual void OnAppearanceChanged(wxPropertyGridEvent& event);
-    virtual void OnCustomButtonClicked(wxCommandEvent& event);
+    virtual void OnChange(wxCommandEvent& event);
 };
 
 #endif // __buildsettingstab__
