@@ -33,6 +33,7 @@
 #include "clInfoBar.h"
 #include "clMainFrameHelper.h"
 #include "clStatusBar.h"
+#include "clToolBar.h"
 #include "cl_command_event.h"
 #include "cl_editor.h"
 #include "cl_process.h"
@@ -42,26 +43,25 @@
 #include "mainbook.h"
 #include "output_pane.h"
 #include "tags_options_dlg.h"
-#include "wx/aui/aui.h"
-#include "wx/choice.h"
-#include "wx/combobox.h"
-#include "wx/frame.h"
-#include "wx/timer.h"
 #include "wxCustomControls.hpp"
 
 #include <set>
+#include <wx/aui/aui.h>
+#include <wx/choice.h>
 #include <wx/cmndata.h>
+#include <wx/combobox.h>
 #include <wx/dcbuffer.h>
+#include <wx/frame.h>
 #include <wx/html/htmlwin.h>
 #include <wx/infobar.h>
 #include <wx/minifram.h>
 #include <wx/process.h>
 #include <wx/splash.h>
+#include <wx/timer.h>
 
 // forward decls
 class OnSysColoursChanged;
 class DebuggerToolBar;
-class clToolBar;
 class WebUpdateJob;
 class CodeLiteApp;
 class clSingleInstanceThread;
@@ -91,6 +91,8 @@ struct StartPageData {
 
 class clMainFrame : public wxFrame
 {
+    enum class ePostBuildEndAction { kNone, kRunProject, kRebuildProject };
+
     MainBook* m_mainBook;
     static clMainFrame* m_theFrame;
     clDockingManager m_mgr;
@@ -101,9 +103,8 @@ class clMainFrame : public wxFrame
     std::map<int, wxString> m_viewAsMap;
     TagsOptionsData m_tagsOptionsData;
     DebuggerPane* m_debuggerPane;
-    bool m_buildAndRun;
+    ePostBuildEndAction m_postBuildEndAction;
     GeneralInfo m_frameGeneralInfo;
-    std::map<int, wxString> m_toolbars;
     std::map<int, wxString> m_panes;
     wxMenu* m_cppMenu;
     bool m_highlightWord;
@@ -113,8 +114,7 @@ class clMainFrame : public wxFrame
     wxString m_defaultLayout;
     bool m_workspaceRetagIsRequired;
     bool m_loadLastSession;
-    wxSizer* m_toolbarsSizer = nullptr;
-    clThemedMenuBar* m_menuBar;
+    wxMenuBar* m_mainMenuBar;
     wxMenu* m_bookmarksDropDownMenu;
     bool m_noSavePerspectivePrompt;
 
@@ -138,12 +138,15 @@ class clMainFrame : public wxFrame
     wxPrintDialogData m_printDlgData;
     clMainFrameHelper::Ptr_t m_frameHelper;
     WebUpdateJob* m_webUpdate;
-    clToolBar* m_toolbar;
+    wxToolBar* m_mainToolbar;
+    clToolBarGeneric* m_pluginsToolbar;
     DebuggerToolBar* m_debuggerToolbar = nullptr;
     clInfoBar* m_infoBar = nullptr;
 #if !wxUSE_NATIVE_CAPTION
     clCaptionBar* m_captionBar = nullptr;
 #endif
+    // the main tool default style
+    int m_mainToolbarStyle = wxTB_FLAT | wxTB_NODIVIDER | wxTB_LEFT;
 
 public:
     static bool m_initCompleted;
@@ -154,9 +157,10 @@ protected:
     void DoCreateBuildDropDownMenu(wxMenu* menu);
     void DoShowToolbars(bool show, bool update = true);
     void InitializeLogo();
-    void DoFullscreen(bool b);
     void DoShowMenuBar(bool show);
     void OnSysColoursChanged(clCommandEvent& event);
+    void RestoreFrameSizeAndPosition();
+    void UpdateMainToolbarOrientation(int newOrientation);
 
 public:
     void Raise() override;
@@ -170,7 +174,7 @@ public:
      * @brief return the menu bar
      * @return
      */
-    clMenuBar* GetMainMenuBar() const { return m_menuBar; }
+    wxMenuBar* GetMainMenuBar() const { return m_mainMenuBar; }
 
     /**
      * @brief goto anything..
@@ -304,11 +308,23 @@ public:
     void OnSingleInstanceRaise(clCommandEvent& e);
 
     /**
-     * @brief rebuild the give project
+     * @brief build the given project
+     * @param projectName
+     */
+    void BuildProject(const wxString& projectName);
+
+    /**
+     * @brief rebuild the given project
      * @param projectName
      */
     void RebuildProject(const wxString& projectName);
 
+    /**
+     * @brief execute a built program without attaching a debugger
+     * @param promptToBuild
+     */
+    void ExecuteNoDebug(bool promptToBuild);
+
     /**
      * @brief handle custom build targets events
      */
@@ -353,6 +369,15 @@ private:
      * at construction time
      */
     void CreateGUIControls();
+
+    /**
+     * @brief construct the frame, we call this function in the first event loop after the application
+     * is ready
+     */
+    void Construct();
+
+    void PostConstruct();
+
     /**
      * \brief update the path & name of the build tool
      * on windows, try to locate make, followed by mingw32-make
@@ -370,14 +395,13 @@ private:
     void OnSplitSelectionUI(wxUpdateUIEvent& event);
 
     /// Toolbar management
-    void CreateToolBar(int toolSize);
+    void DoCreateToolBar(int toolSize);
     void ToggleToolBars(bool all);
     void ViewPaneUI(const wxString& paneName, wxUpdateUIEvent& event);
     void CreateRecentlyOpenedFilesMenu();
     void CreateWelcomePage();
     bool ReloadExternallyModifiedProjectFiles();
     void DoEnableWorkspaceViewFlag(bool enable, int flag);
-    void DoUpdatePerspectiveMenu();
     bool IsWorkspaceViewFlagEnabled(int flag);
     /**
      * @brief show the startup wizard
@@ -405,7 +429,7 @@ private:
 public:
     void ViewPane(const wxString& paneName, bool checked);
     void ShowOrHideCaptions();
-    clToolBar* GetMainToolBar() const { return m_toolbar; }
+    clToolBarGeneric* GetPluginsToolBar() const { return m_pluginsToolbar; }
     void ShowBuildMenu(clToolBar* toolbar, wxWindowID buttonID);
 
 protected:
@@ -454,8 +478,6 @@ protected:
     void OnIncrementalSearch(wxCommandEvent& event);
     void OnIncrementalReplace(wxCommandEvent& event);
     void OnIncrementalSearchUI(wxUpdateUIEvent& event);
-    void OnViewToolbar(wxCommandEvent& event);
-    void OnViewToolbarUI(wxUpdateUIEvent& event);
     void OnPrint(wxCommandEvent& event);
     void OnPageSetup(wxCommandEvent& event);
     void OnRecentWorkspaceUI(wxUpdateUIEvent& e);
@@ -515,6 +537,7 @@ protected:
     void OnCopyFilePathOnly(wxCommandEvent& event);
     void OnCopyFileName(wxCommandEvent& event);
     void OnHighlightWord(wxCommandEvent& event);
+    void OnHighlightWordUI(wxUpdateUIEvent& event);
     void OnShowNavBar(wxCommandEvent& e);
     void OnShowNavBarUI(wxUpdateUIEvent& e);
     void OnOpenShellFromFilePath(wxCommandEvent& e);
@@ -538,11 +561,6 @@ protected:
     void OnThemeChanged(wxCommandEvent& e);
     void OnEnvironmentVariablesModified(clCommandEvent& e);
 
-    // handle symbol tree events
-    void OnDatabaseUpgrade(wxCommandEvent& e);
-    void OnDatabaseUpgradeInternally(wxCommandEvent& e);
-    void OnRefreshPerspectiveMenu(wxCommandEvent& e);
-
     void OnRecentFile(wxCommandEvent& event);
     void OnRecentWorkspace(wxCommandEvent& event);
     void OnBackwardForward(wxCommandEvent& event);
@@ -587,7 +605,6 @@ protected:
     void OnCloseTabsToTheRight(wxCommandEvent& e);
     void OnWorkspaceMenuUI(wxUpdateUIEvent& e);
     void OnUpdateBuildRefactorIndexBar(wxCommandEvent& e);
-    void OnUpdateNumberOfBuildProcesses(wxCommandEvent& e);
     void OnBuildWorkspace(wxCommandEvent& e);
     void OnBuildWorkspaceUI(wxUpdateUIEvent& e);
     void OnCleanWorkspace(wxCommandEvent& e);
@@ -595,12 +612,6 @@ protected:
     void OnReBuildWorkspace(wxCommandEvent& e);
     void OnReBuildWorkspaceUI(wxUpdateUIEvent& e);
 
-    // Perspectives management
-    void OnChangePerspective(wxCommandEvent& e);
-    void OnChangePerspectiveUI(wxUpdateUIEvent& e);
-    void OnManagePerspectives(wxCommandEvent& e);
-    void OnSaveLayoutAsPerspective(wxCommandEvent& e);
-
     // EOL
     void OnConvertEol(wxCommandEvent& e);
     void OnViewDisplayEOL(wxCommandEvent& e);
@@ -609,7 +620,6 @@ protected:
     void OnViewDisplayEOL_UI(wxUpdateUIEvent& e);
 
     // Docking windows events
-    void OnAuiManagerRender(wxAuiManagerEvent& e);
     void OnDockablePaneClosed(wxAuiManagerEvent& e);
     void OnViewPane(wxCommandEvent& event);
     void OnViewPaneUI(wxUpdateUIEvent& event);
@@ -640,7 +650,6 @@ protected:
     void OnFindResourceXXX(wxCommandEvent& e);
     void OnShowActiveProjectSettings(wxCommandEvent& e);
     void OnShowActiveProjectSettingsUI(wxUpdateUIEvent& e);
-    void OnLoadPerspective(wxCommandEvent& e);
     void OnWorkspaceSettings(wxCommandEvent& e);
     void OnWorkspaceEditorPreferences(wxCommandEvent& e);
     void OnSetActivePoject(wxCommandEvent& e);
@@ -650,6 +659,15 @@ protected:
     void OnPchCacheStarted(wxCommandEvent& e);
     void OnPchCacheEnded(wxCommandEvent& e);
 
+    void OnMainToolBarPlaceTop(wxCommandEvent& event);
+    void OnMainToolBarPlaceTopUI(wxUpdateUIEvent& event);
+    void OnMainToolBarPlaceBottom(wxCommandEvent& event);
+    void OnMainToolBarPlaceBottomUI(wxUpdateUIEvent& event);
+    void OnMainToolBarPlaceLeft(wxCommandEvent& event);
+    void OnMainToolBarPlaceLeftUI(wxUpdateUIEvent& event);
+    void OnMainToolBarPlaceRight(wxCommandEvent& event);
+    void OnMainToolBarPlaceRightUI(wxUpdateUIEvent& event);
+
     // Misc
     void OnActivateEditor(wxCommandEvent& e);
     void OnActiveEditorChanged(wxCommandEvent& e);
