@@ -23,16 +23,18 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 
+#include "new_quick_watch_dlg.h"
+
 #include "clDebuggerEditItemDlg.h"
 #include "debuggerobserver.h"
 #include "editor_config.h"
 #include "frame.h"
 #include "globals.h"
-#include "new_quick_watch_dlg.h"
 #include "simpletable.h"
 #include "windowattrmanager.h"
 #include "wx/persist/window.h"
 #include "wx/popupwin.h"
+
 #include <cmath>
 #include <wx/cursor.h>
 #include <wx/log.h>
@@ -54,6 +56,14 @@ public:
     virtual ~QWTreeData() {}
 };
 
+#if wxVERSION_NUMBER >= 3104 && defined(__WXGTK3__)
+static void DoNothing(wxShowEvent& event)
+{
+    // Swallows wxEVT_SHOW, which would otherwise result in a zero clientsize due
+    // to a side-effect of the 3rd fix in https://trac.wxwidgets.org/ticket/16088
+}
+#endif
+
 DisplayVariableDlg::DisplayVariableDlg(wxWindow* parent)
     : clResizableTooltip(parent)
     , m_debugger(NULL)
@@ -63,6 +73,9 @@ DisplayVariableDlg::DisplayVariableDlg(wxWindow* parent)
     Centre();
     SetName("clDebuggerEditItemDlgBase");
     m_treeCtrl->Bind(wxEVT_TREE_ITEM_MENU, &DisplayVariableDlg::OnItemMenu, this);
+#if wxVERSION_NUMBER >= 3104 && defined(__WXGTK3__)
+    Bind(wxEVT_SHOW, DoNothing);
+#endif
 }
 
 DisplayVariableDlg::~DisplayVariableDlg()
@@ -117,7 +130,8 @@ void DisplayVariableDlg::BuildTree(const VariableObjChildren& children, IDebugge
     m_gdbId2ItemLeaf[m_mainVariableObject] = root;
 #endif
 
-    if(children.empty()) return;
+    if(children.empty())
+        return;
     DoAddChildren(root, children);
 }
 
@@ -132,7 +146,8 @@ void DisplayVariableDlg::AddItems(const wxString& varname, const VariableObjChil
 
 void DisplayVariableDlg::DoAddChildren(wxTreeItemId& item, const VariableObjChildren& children)
 {
-    if(item.IsOk() == false) return;
+    if(item.IsOk() == false)
+        return;
 
     if(m_treeCtrl->GetRootItem() != item && m_treeCtrl->ItemHasChildren(item)) {
         // delete the <dummy> node
@@ -140,7 +155,9 @@ void DisplayVariableDlg::DoAddChildren(wxTreeItemId& item, const VariableObjChil
         wxTreeItemId child = m_treeCtrl->GetFirstChild(item, kookie);
         while(child.IsOk()) {
             wxString itemText = m_treeCtrl->GetItemText(child);
-            if(itemText == wxT("<dummy>") || itemText == _("Loading...")) { m_treeCtrl->Delete(child); }
+            if(itemText == wxT("<dummy>") || itemText == _("Loading...")) {
+                m_treeCtrl->Delete(child);
+            }
             child = m_treeCtrl->GetNextChild(item, kookie);
         }
     }
@@ -149,7 +166,7 @@ void DisplayVariableDlg::DoAddChildren(wxTreeItemId& item, const VariableObjChil
         const VariableObjChild& ch = children[i];
 
         // Dont use ch.isAFake here since it will also returns true of inheritance
-        if(ch.varName != wxT("public") && ch.varName != wxT("private") && ch.varName != wxT("protected")) {
+        if(ch.varName != "public" && ch.varName != "private" && ch.varName != "protected") {
             // Real node
             wxTreeItemId child = m_treeCtrl->AppendItem(item, ch.varName, -1, -1, new QWTreeData(ch));
             if(ch.numChilds > 0) {
@@ -186,7 +203,9 @@ void DisplayVariableDlg::UpdateValue(const wxString& varname, const wxString& va
         if(item.IsOk()) {
             wxString curtext = m_treeCtrl->GetItemText(item);
 #ifdef __WXMAC__
-            if(item == m_treeCtrl->GetRootItem()) { curtext = curtext.BeforeFirst(wxT('=')); }
+            if(item == m_treeCtrl->GetRootItem()) {
+                curtext = curtext.BeforeFirst(wxT('='));
+            }
 #endif
             curtext << wxT(" = ") << value;
             m_treeCtrl->SetItemText(item, curtext);
@@ -240,10 +259,13 @@ void DisplayVariableDlg::OnItemMenu(wxTreeEvent& event)
     event.Skip();
     wxTreeItemId item = event.GetItem();
 
-    if(item.IsOk()) { m_treeCtrl->SelectItem(item); }
+    if(item.IsOk()) {
+        m_treeCtrl->SelectItem(item);
+    }
 
     // Dont show popup menu for fake nodes
-    if(IsFakeItem(item)) return;
+    if(IsFakeItem(item))
+        return;
 
     // Popup the menu
     wxMenu menu;
@@ -287,7 +309,8 @@ wxString DisplayVariableDlg::DoGetItemPath(const wxTreeItemId& treeItem)
         }
 
         // Are we at root yet?
-        if(m_treeCtrl->GetRootItem() == item) break;
+        if(m_treeCtrl->GetRootItem() == item)
+            break;
 
         // Surround this expression with parenthesiss
         item = m_treeCtrl->GetItemParent(item);
@@ -300,18 +323,22 @@ wxString DisplayVariableDlg::DoGetItemPath(const wxTreeItemId& treeItem)
         exprWithParentheses.Prepend(wxT("(")).Append(wxT(")."));
     }
 
-    if(!items.IsEmpty()) { exprWithParentheses.RemoveLast(); }
+    if(!items.IsEmpty()) {
+        exprWithParentheses.RemoveLast();
+    }
 
     return exprWithParentheses;
 }
 
 bool DisplayVariableDlg::IsFakeItem(const wxTreeItemId& item)
 {
-    if(item.IsOk() == false) return true; // fake
+    if(item.IsOk() == false)
+        return true; // fake
 
     if(item != m_treeCtrl->GetRootItem()) {
         QWTreeData* data = (QWTreeData*)m_treeCtrl->GetItemData(item);
-        if(data) return data->_voc.isAFake;
+        if(data)
+            return data->_voc.isAFake;
 
         return false;
 
@@ -327,7 +354,7 @@ void DisplayVariableDlg::OnMenuSelection(wxCommandEvent& e)
         if(e.GetId() == XRCID("tip_add_watch")) {
             wxString fullpath = DoGetItemPath(item);
             clMainFrame::Get()->GetDebuggerPane()->GetWatchesTable()->AddExpression(fullpath);
-            clMainFrame::Get()->GetDebuggerPane()->SelectTab(DebuggerPane::WATCHES);
+            clMainFrame::Get()->GetDebuggerPane()->SelectTab(wxGetTranslation(DebuggerPane::WATCHES));
             clMainFrame::Get()->GetDebuggerPane()->GetWatchesTable()->RefreshValues();
 
         } else if(e.GetId() == XRCID("tip_copy_value")) {
@@ -345,7 +372,8 @@ void DisplayVariableDlg::OnCreateVariableObjError(const DebuggerEventData& event
 
 void DisplayVariableDlg::DoEditItem(const wxTreeItemId& item)
 {
-    if(item.IsOk() == false) return;
+    if(item.IsOk() == false)
+        return;
 
     wxString oldText = m_treeCtrl->GetItemText(item);
     oldText = oldText.BeforeFirst(wxT('='));
@@ -369,10 +397,13 @@ void DisplayVariableDlg::DoEditItem(const wxTreeItemId& item)
     wxWindow::WarpPointer(oldPos.x, oldPos.y);
 #endif
 
-    if(res != wxID_OK) { return; }
+    if(res != wxID_OK) {
+        return;
+    }
 
     wxString newText = dlg.GetValue();
-    if(newText.IsEmpty()) return;
+    if(newText.IsEmpty())
+        return;
 
     wxString newExpr = DoGetItemPath(item);
     m_treeCtrl->SetItemText(item, newText);
@@ -392,9 +423,11 @@ void DisplayVariableDlg::DoEditItem(const wxTreeItemId& item)
         typecast.Trim().Trim(false);
 
         if(!typecast.IsEmpty()) {
-            if(!typecast.StartsWith(wxT("("))) typecast.Prepend(wxT("("));
+            if(!typecast.StartsWith(wxT("(")))
+                typecast.Prepend(wxT("("));
 
-            if(!typecast.EndsWith(wxT(")"))) typecast.Append(wxT(")"));
+            if(!typecast.EndsWith(wxT(")")))
+                typecast.Append(wxT(")"));
         }
 
         newExpr.Prepend(typecast);
@@ -420,7 +453,8 @@ bool CLPersistentDebuggerTip::Restore()
     long w(-1), h(-1);
     const bool hasSize = RestoreValue("w", &w) && RestoreValue("h", &h);
 
-    if(hasSize) puw->SetSize(w, h);
+    if(hasSize)
+        puw->SetSize(w, h);
 
     return hasSize;
 }
