@@ -22,6 +22,9 @@
 //
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
+#include "openwindowspanel.h"
+
+#include "ColoursAndFontsManager.h"
 #include "clToolBar.h"
 #include "clToolBarButtonBase.h"
 #include "cl_config.h"
@@ -30,8 +33,8 @@
 #include "globals.h"
 #include "imanager.h"
 #include "macros.h"
-#include "openwindowspanel.h"
 #include "pluginmanager.h"
+
 #include <algorithm>
 #include <wx/clntdata.h>
 #include <wx/filename.h>
@@ -44,25 +47,6 @@ EVT_MENU(XRCID("wxID_CLOSE_SELECTED"), OpenWindowsPanel::OnCloseSelectedFiles)
 EVT_MENU(XRCID("wxID_SAVE_SELECTED"), OpenWindowsPanel::OnSaveSelectedFiles)
 END_EVENT_TABLE()
 
-struct TabSorter {
-    bool operator()(const clTab& t1, const clTab& t2)
-    {
-        wxString file1, file2;
-        if(t1.isFile) {
-            file1 = t1.filename.GetFullName().Lower();
-        } else {
-            file1 = t1.text;
-        }
-
-        if(t2.isFile) {
-            file2 = t2.filename.GetFullName().Lower();
-        } else {
-            file2 = t2.text;
-        }
-        return file1.CmpNoCase(file2) < 0;
-    }
-};
-
 struct TabClientData : public wxClientData {
     clTab tab;
     bool isModified;
@@ -87,9 +71,9 @@ OpenWindowsPanel::OpenWindowsPanel(wxWindow* parent, const wxString& caption)
     // Disable the built in sorting, this control will take care of it
     m_dvListCtrl->SetSortFunction(nullptr);
     m_dvListCtrl->SetBitmaps(clGetManager()->GetStdIcons()->GetStandardMimeBitmapListPtr());
-    m_toolbar = new clToolBar(this);
+    m_toolbar = new clToolBarGeneric(this);
     auto images = m_toolbar->GetBitmapsCreateIfNeeded();
-    m_toolbar->AddTool(wxID_SORT_ASCENDING, _("Sort"), images->Add("sort"), "", wxITEM_CHECK);
+    m_toolbar->AddToggleButton(wxID_SORT_ASCENDING, images->Add("sort"), _("Sort"));
     m_toolbar->Realize();
     GetSizer()->Insert(0, m_toolbar, 0, wxEXPAND);
 
@@ -100,6 +84,7 @@ OpenWindowsPanel::OpenWindowsPanel(wxWindow* parent, const wxString& caption)
     m_toolbar->ToggleTool(XRCID("TabsSortTool"), cfg.Read(kConfigTabsPaneSortAlphabetically, true));
 
     EventNotifier::Get()->Connect(wxEVT_INIT_DONE, wxCommandEventHandler(OpenWindowsPanel::OnInitDone), NULL, this);
+    EventNotifier::Get()->Bind(wxEVT_BITMAPS_UPDATED, &OpenWindowsPanel::OnThemeChanged, this);
     Bind(wxEVT_IDLE, &OpenWindowsPanel::OnIdle, this);
 }
 
@@ -107,6 +92,7 @@ OpenWindowsPanel::~OpenWindowsPanel()
 {
     m_toolbar->Unbind(wxEVT_TOOL, &OpenWindowsPanel::OnSortItems, this, wxID_SORT_ASCENDING);
     m_toolbar->Unbind(wxEVT_UPDATE_UI, &OpenWindowsPanel::OnSortItemsUpdateUI, this, wxID_SORT_ASCENDING);
+    EventNotifier::Get()->Unbind(wxEVT_BITMAPS_UPDATED, &OpenWindowsPanel::OnThemeChanged, this);
 
     // clear list now, or wxGTK seems to crash on exit
     Clear();
@@ -245,7 +231,8 @@ void OpenWindowsPanel::DoSelectItem(IEditor* editor)
 
 void OpenWindowsPanel::OnSortItems(wxCommandEvent& event)
 {
-    if(event.IsChecked()) {
+    m_sortItems = event.IsChecked();
+    if(m_sortItems) {
         SortAlphabetically();
     } else {
         SortByEditorOrder();
@@ -257,7 +244,11 @@ void OpenWindowsPanel::OnSortItems(wxCommandEvent& event)
     clConfig::Get().Write(kConfigTabsPaneSortAlphabetically, event.IsChecked());
 }
 
-void OpenWindowsPanel::OnSortItemsUpdateUI(wxUpdateUIEvent& event) { event.Enable(m_dvListCtrl->GetItemCount()); }
+void OpenWindowsPanel::OnSortItemsUpdateUI(wxUpdateUIEvent& event)
+{
+    event.Enable(m_dvListCtrl->GetItemCount());
+    event.Check(m_sortItems);
+}
 
 void OpenWindowsPanel::SortAlphabetically()
 {
@@ -266,10 +257,14 @@ void OpenWindowsPanel::SortAlphabetically()
     m_mgr->GetAllTabs(tabs);
 
     // Sort editors
-    std::sort(tabs.begin(), tabs.end(), TabSorter());
+    std::sort(tabs.begin(), tabs.end(), [&](const clTab& t1, const clTab& t2) {
+        wxString file1 = GetDisplayName(t1);
+        wxString file2 = GetDisplayName(t2);
+        return file1.CmpNoCase(file2) < 0;
+    });
     Clear();
 
-    clTab::Vec_t::iterator iter = tabs.begin();
+    auto iter = tabs.begin();
     for(; iter != tabs.end(); ++iter) {
         AppendEditor(*iter);
     }
@@ -332,17 +327,23 @@ void OpenWindowsPanel::OnTabSelected(wxDataViewEvent& event)
 void OpenWindowsPanel::AppendEditor(const clTab& tab)
 {
     TabClientData* data = new TabClientData(tab);
-    wxVariant value = PrepareValue(tab);
+    bool is_modified = false;
+    wxVariant value = PrepareValue(tab, &is_modified);
 
     // the row index is the same as the row count (before we add the new entry)
     int itemIndex = m_dvListCtrl->GetItemCount();
 
     wxVector<wxVariant> cols;
     cols.push_back(value);
-    m_dvListCtrl->AppendItem(cols, (wxUIntPtr)data);
+    auto item = m_dvListCtrl->AppendItem(cols, (wxUIntPtr)data);
     if(tab.isFile) {
         m_editors.insert({ tab.filename.GetFullPath(), m_dvListCtrl->RowToItem(itemIndex) });
     }
+
+    bool saved_before = false;
+    auto editor = clGetManager()->FindEditor(tab.filename.GetFullPath());
+    saved_before = editor && editor->GetCtrl()->CanUndo();
+    MarkItemModified(item, is_modified, saved_before);
 }
 
 wxString OpenWindowsPanel::GetEditorPath(wxDataViewItem item)
@@ -364,7 +365,7 @@ void OpenWindowsPanel::Clear()
 
 void OpenWindowsPanel::PopulateView()
 {
-    if(m_toolbar->FindById(wxID_SORT_ASCENDING)->IsChecked()) {
+    if(m_sortItems) {
         SortAlphabetically();
     } else {
         SortByEditorOrder();
@@ -445,7 +446,7 @@ void OpenWindowsPanel::OnEditorModified(clCommandEvent& event)
         return;
     IEditor* editor = m_mgr->FindEditor(event.GetFileName());
     if(editor) {
-        DoMarkModify(event.GetFileName(), editor->IsEditorModified());
+        DoMarkModify(editor, event.GetFileName(), editor->IsEditorModified());
     }
 }
 
@@ -454,46 +455,48 @@ void OpenWindowsPanel::OnEditorSaved(clCommandEvent& event)
     event.Skip();
     if(!m_initDone)
         return;
-    DoMarkModify(event.GetFileName(), false);
+
+    DoMarkModify(clGetManager()->FindEditor(event.GetFileName()), event.GetFileName(), false);
 }
 
-void OpenWindowsPanel::DoMarkModify(const wxString& filename, bool b)
+void OpenWindowsPanel::DoMarkModify(IEditor* editor, const wxString& filename, bool b)
 {
     std::map<wxString, wxDataViewItem>::iterator iter = m_editors.find(filename);
     if(iter == m_editors.end())
         return;
+
     wxDataViewItem item = iter->second;
 
     wxBitmap bmp;
     TabClientData* cd = reinterpret_cast<TabClientData*>(m_dvListCtrl->GetItemData(item));
     const clTab& tab = cd->tab;
-    wxVariant value = PrepareValue(tab);
+    bool is_modified = false;
+    wxVariant value = PrepareValue(tab, &is_modified);
     m_dvListCtrl->SetValue(value, m_dvListCtrl->ItemToRow(item), 0);
+
+    // if we can do "undo" -> the file was saved
+    MarkItemModified(item, is_modified, editor && editor->GetCtrl()->CanUndo());
     m_dvListCtrl->Refresh();
 }
 
-wxVariant OpenWindowsPanel::PrepareValue(const clTab& tab)
+wxVariant OpenWindowsPanel::PrepareValue(const clTab& tab, bool* isModified)
 {
     wxString title;
-    wxStyledTextCtrl* editor(NULL);
+    wxStyledTextCtrl* editor = nullptr;
+    *isModified = false;
+    title = GetDisplayName(tab);
+
     if(tab.isFile) {
-        const wxFileName& fn = tab.filename;
-        if(fn.GetDirCount() && EditorConfigST::Get()->GetOptions()->IsTabShowPath()) {
-            title = fn.GetDirs().Last() + wxFileName::GetPathSeparator() + fn.GetFullName();
-        } else {
-            title = tab.filename.GetFullName();
-        }
-        IEditor* i_editor = clGetManager()->FindEditor(tab.filename.GetFullPath());
+        auto i_editor = clGetManager()->FindEditor(tab.filename.GetFullPath());
         if(i_editor) {
             editor = i_editor->GetCtrl();
         }
-    } else {
-        title = tab.text;
     }
 
     FileExtManager::FileType ft = FileExtManager::GetType(title, FileExtManager::TypeText);
     int imgId = clGetManager()->GetStdIcons()->GetMimeImageId(ft);
     if(editor && editor->GetModify()) {
+        *isModified = true;
         title.Prepend("*");
     }
 
@@ -513,3 +516,42 @@ void OpenWindowsPanel::OnWorkspaceClosing(clWorkspaceEvent& event)
     Clear();
     m_workspaceClosing = true;
 }
+
+void OpenWindowsPanel::MarkItemModified(const wxDataViewItem& item, bool b, bool saved_before)
+{
+    auto lexer = ColoursAndFontsManager::Get().GetLexer("diff");
+    const auto& colours = m_dvListCtrl->GetColours();
+    if(b) {
+        m_dvListCtrl->SetItemTextColour(item, lexer->GetProperty(wxSTC_DIFF_DELETED).GetFgColour());
+    } else {
+        wxColour item_colour = colours.GetItemTextColour();
+        if(saved_before) {
+            item_colour = lexer->GetProperty(wxSTC_DIFF_ADDED).GetFgColour();
+        }
+        m_dvListCtrl->SetItemTextColour(item, item_colour);
+    }
+}
+
+void OpenWindowsPanel::OnThemeChanged(clCommandEvent& event)
+{
+    event.Skip();
+    m_dvListCtrl->SetBitmaps(clGetManager()->GetStdIcons()->GetStandardMimeBitmapListPtr());
+    PopulateView();
+    m_dvListCtrl->Refresh();
+}
+
+wxString OpenWindowsPanel::GetDisplayName(const clTab& tab) const
+{
+    wxString title;
+    if(tab.isFile) {
+        const wxFileName& fn = tab.filename;
+        if(fn.GetDirCount() && EditorConfigST::Get()->GetOptions()->IsTabShowPath()) {
+            title = fn.GetDirs().Last() + wxFileName::GetPathSeparator() + fn.GetFullName();
+        } else {
+            title = tab.filename.GetFullName();
+        }
+    } else {
+        title = tab.text;
+    }
+    return title;
+}
\ No newline at end of file
