@@ -27,6 +27,8 @@
 #define PERSPECTIVEMANAGER_H
 
 #include "precompiled_header.h"
+#include "wxStringHash.h"
+
 #include <map>
 #include <wx/arrstr.h>
 #include <wx/aui/framemanager.h>
@@ -42,58 +44,45 @@ extern wxString NORMAL_LAYOUT;
 class PerspectiveManager : public wxEvtHandler
 {
 protected:
-    std::map<wxString, int> m_menuIdToName;
+    std::unordered_map<wxString, int> m_menuIdToName;
+    std::unordered_map<wxString, wxString> m_perspectives;
     int m_nextId;
     wxString m_active;
     wxString m_buildPerspective;
-    wxAuiManager* m_aui;
+    wxAuiManager* m_aui = nullptr;
 
 protected:
-    wxString DoGetPathFromName(const wxString& name);
+    /**
+     * @brief read the perspective from cache first, and then try to load it from the disk
+     * if it does not exist
+     */
+    bool GetPerspective(const wxString& name, wxString* perspective) const;
+    void SetPerspectiveToCache(const wxString& name, const wxString& content);
+
+    wxString DoGetPathFromName(const wxString& name) const;
     void DoEnsureDebuggerPanesAreVisible();
     void DoShowPane(const wxString& panename, bool show, bool& needUpdate);
     // Event handlers
     void OnPaneClosing(wxAuiManagerEvent& event);
+    void OnAuiRender(wxAuiManagerEvent& event);
 
 public:
     PerspectiveManager();
     virtual ~PerspectiveManager();
 
+    void FlushCacheToDisk();
     void ConnectEvents(wxAuiManager* mgr);
     void DisconnectEvents();
 
     void ToggleOutputPane(bool hide);
-    void SetActive(const wxString& active)
-    {
-        this->m_active = active;
-    }
-    const wxString& GetActive() const
-    {
-        return m_active;
-    }
+    void SetActive(const wxString& active) { this->m_active = active; }
+    const wxString& GetActive() const { return m_active; }
 
     bool IsDefaultActive() const;
     void LoadPerspective(const wxString& name = wxT(""));
-    void LoadPerspectiveByMenuId(int id);
     void SavePerspective(const wxString& name = wxT(""), bool notify = true);
     void SavePerspectiveIfNotExists(const wxString& name);
-
-    wxArrayString GetAllPerspectives();
     void DeleteAllPerspectives();
-    void ClearIds();
-    int MenuIdFromName(const wxString& name);
-    wxString NameFromMenuId(int id);
-    void Rename(const wxString& old, const wxString& new_name);
-    void Delete(const wxString& name);
-
-    int FirstMenuId() const
-    {
-        return PERSPECTIVE_FIRST_MENU_ID;
-    }
-    int LastMenuId() const
-    {
-        return PERSPECTIVE_LAST_MENU_ID;
-    }
 };
 
 #endif // PERSPECTIVEMANAGER_H
