@@ -25,6 +25,7 @@
 #ifndef PLUGINMANAGER_H
 #define PLUGINMANAGER_H
 
+#include "clToolBar.h"
 #include "debugger.h"
 #include "dynamiclibrary.h"
 #include "plugin.h"
@@ -38,7 +39,6 @@
 #include <wx/string.h>
 #include <wx/treectrl.h>
 
-class clToolBar;
 class clEditorBar;
 class wxBookCtrlBase;
 class EnvironmentConfig;
@@ -85,14 +85,15 @@ public:
     //------------------------------------
     void EnableClangCodeCompletion(bool b) override;
     IEditor* GetActiveEditor() override;
-    clToolBar* GetToolBar() override;
-    clMenuBar* GetMenuBar() override;
+    clToolBarGeneric* GetToolBar() override;
+    wxMenuBar* GetMenuBar() override;
     IConfigTool* GetConfigTool() override;
     TreeItemInfo GetSelectedTreeItemInfo(TreeType type) override;
     clTreeCtrl* GetFileExplorerTree() override;
     clTreeCtrl* GetWorkspaceTree() override;
     Notebook* GetOutputPaneNotebook() override;
     Notebook* GetWorkspacePaneNotebook() override;
+    Notebook* GetMainNotebook() override;
     IEditor* OpenFile(const wxString& fileName, const wxString& projectName = wxEmptyString, int lineno = wxNOT_FOUND,
                       OF_extra flags = OF_AddJump) override;
     IEditor* OpenFile(const wxString& fileName, const wxString& bmpResourceName,
@@ -156,6 +157,7 @@ public:
     size_t GetAllEditors(IEditor::List_t& editors, bool inOrder = false) override;
     size_t GetAllTabs(clTab::Vec_t& tabs) override;
     size_t GetAllBreakpoints(clDebuggerBreakpoint::Vec_t& breakpoints) override;
+    clDebuggerBreakpoint CreateBreakpoint(const wxString& filepath, int line_number) override;
     void DeleteAllBreakpoints() override;
     void SetBreakpoints(const clDebuggerBreakpoint::Vec_t& breakpoints) override;
     void LoadPerspective(const wxString& perspectiveName) override;
@@ -185,8 +187,8 @@ public:
     /**
      * @brief display message to the user using the info bar
      */
-    virtual void DisplayMessage(const wxString& message, int flags = wxICON_INFORMATION,
-                                const std::vector<std::pair<wxWindowID, wxString>>& buttons = {}) override;
+    void DisplayMessage(const wxString& message, int flags = wxICON_INFORMATION,
+                        const std::vector<std::pair<wxWindowID, wxString>>& buttons = {}) override;
 
     //------------------------------------
     // End of IManager interface
