@@ -94,9 +94,21 @@ void CenterLine(wxStyledTextCtrl* ctrl, int start_pos, int end_pos)
     clEditor::CenterLinePreserveSelection(ctrl, line);
 }
 
+wxBorder get_border_simple_theme_aware_bit()
+{
+#ifdef __WXMAC__
+    return wxBORDER_SIMPLE;
+#elif defined(__WXGTK__)
+    return wxBORDER_STATIC;
+#else
+    return clSystemSettings::Get().IsDark() ? wxBORDER_SIMPLE : wxBORDER_STATIC;
+#endif
+}
 } // namespace
+
 QuickFindBar::QuickFindBar(wxWindow* parent, wxWindowID id)
-    : QuickFindBarBase(parent, id)
+    : QuickFindBarBase(parent, id, wxDefaultPosition, wxDefaultSize,
+                       wxTAB_TRAVERSAL | get_border_simple_theme_aware_bit())
     , m_sci(NULL)
     , m_lastTextPtr(NULL)
     , m_eventsConnected(false)
@@ -106,13 +118,6 @@ QuickFindBar::QuickFindBar(wxWindow* parent, wxWindowID id)
     , m_highlightMatches(false)
     , m_inSelection(false)
 {
-    // SetBackgroundStyle(wxBG_STYLE_PAINT);
-
-    // Handle Edit events
-    m_findEventsHandler.Reset(new clEditEventsHandler(m_textCtrlFind));
-    m_replaceEventsHandler.Reset(new clEditEventsHandler(m_textCtrlReplace));
-    m_findEventsHandler->NoUnbind();
-    m_replaceEventsHandler->NoUnbind();
     m_toolbar->SetMiniToolBar(true);
     auto images = m_toolbar->GetBitmapsCreateIfNeeded();
     m_toolbar->AddTool(wxID_CLOSE, _("Close"), images->Add("file_close"), _("Close"), wxITEM_NORMAL);
@@ -202,7 +207,7 @@ QuickFindBar::QuickFindBar(wxWindow* parent, wxWindowID id)
     // Make sure that the 'Replace' field is selected when we hit TAB while in the 'Find' field
     m_textCtrlReplace->MoveAfterInTabOrder(m_textCtrlFind);
     // Bind(wxEVT_PAINT, &QuickFindBar::OnPaint, this);
-    Bind(wxEVT_ERASE_BACKGROUND, [](wxEraseEvent& e) { wxUnusedVar(e); });
+    // Bind(wxEVT_ERASE_BACKGROUND, [](wxEraseEvent& e) { wxUnusedVar(e); });
     GetSizer()->Fit(this);
     Layout();
 }
@@ -775,10 +780,10 @@ void QuickFindBar::DoReplaceAll(bool selectionOnly)
     bool isUTF8 = false;
 
     wxString input_buffer = m_sci->GetText();
-    unsigned int utfLen = ::clUTF8Length(input_buffer, input_buffer.length());
+    unsigned int utfLen = ::clUTF8Length(input_buffer.ToStdWstring().c_str(), input_buffer.length());
     isUTF8 = (utfLen != input_buffer.length());
 
-    if(!IsReplacementRegex() && !isUTF8) {
+    if(!(m_searchFlags & wxSTC_FIND_REGEXP) && !IsReplacementRegex() && !isUTF8) {
         // simple search, we can optimize it by applying the replacement on
         // a buffer instead of the editor
         replacements_done = DoReplaceInBuffer(target);
