@@ -5,20 +5,20 @@
  * @copyright GNU General Public License v2
  */
 
-#include <wx/stc/stc.h>
-#include <wx/busyinfo.h>
-#include <wx/clipbrd.h>
-
-#include "event_notifier.h"
-#include "workspace.h"
-#include "file_logger.h"
-#include "dirsaver.h"
-#include "stringsearcher.h"
-
-#include "memcheckdefs.h"
 #include "memcheckoutputview.h"
+
+#include "dirsaver.h"
+#include "event_notifier.h"
+#include "file_logger.h"
+#include "memcheckdefs.h"
 #include "memchecksettings.h"
 #include "search_thread.h"
+#include "stringsearcher.h"
+#include "workspace.h"
+
+#include <wx/busyinfo.h>
+#include <wx/clipbrd.h>
+#include <wx/stc/stc.h>
 
 MemCheckOutputView::MemCheckOutputView(wxWindow* parent, MemCheckPlugin* plugin, IManager* mgr)
     : MemCheckOutputViewBase(parent)
@@ -41,31 +41,29 @@ MemCheckOutputView::MemCheckOutputView(wxWindow* parent, MemCheckPlugin* plugin,
     m_searchCtrlFilter->SetMenu(m_searchMenu);
 
     m_searchMenu->Connect(XRCID("memcheck_search_string"), wxEVT_COMMAND_MENU_SELECTED,
-        wxCommandEventHandler(MemCheckOutputView::OnFilterErrors), NULL, this);
+                          wxCommandEventHandler(MemCheckOutputView::OnFilterErrors), NULL, this);
     m_searchMenu->Connect(XRCID("memcheck_search_string"), wxEVT_UPDATE_UI,
-        wxUpdateUIEventHandler(MemCheckOutputView::OnSuppPanelUI), NULL, this);
+                          wxUpdateUIEventHandler(MemCheckOutputView::OnSuppPanelUI), NULL, this);
     m_searchMenu->Connect(XRCID("memcheck_search_nonworkspace"), wxEVT_COMMAND_MENU_SELECTED,
-        wxCommandEventHandler(MemCheckOutputView::OnSearchNonworkspace), NULL, this);
+                          wxCommandEventHandler(MemCheckOutputView::OnSearchNonworkspace), NULL, this);
     m_searchMenu->Connect(XRCID("memcheck_search_nonworkspace"), wxEVT_UPDATE_UI,
-        wxUpdateUIEventHandler(MemCheckOutputView::OnSuppPanelUI), NULL, this);
+                          wxUpdateUIEventHandler(MemCheckOutputView::OnSuppPanelUI), NULL, this);
 }
 
 MemCheckOutputView::~MemCheckOutputView()
 {
     m_searchMenu->Disconnect(XRCID("memcheck_search_string"), wxEVT_COMMAND_MENU_SELECTED,
-        wxCommandEventHandler(MemCheckOutputView::OnFilterErrors), NULL, this);
+                             wxCommandEventHandler(MemCheckOutputView::OnFilterErrors), NULL, this);
     m_searchMenu->Disconnect(XRCID("memcheck_search_string"), wxEVT_UPDATE_UI,
-        wxUpdateUIEventHandler(MemCheckOutputView::OnSuppPanelUI), NULL, this);
+                             wxUpdateUIEventHandler(MemCheckOutputView::OnSuppPanelUI), NULL, this);
     m_searchMenu->Disconnect(XRCID("memcheck_search_nonworkspace"), wxEVT_COMMAND_MENU_SELECTED,
-        wxCommandEventHandler(MemCheckOutputView::OnSearchNonworkspace), NULL, this);
+                             wxCommandEventHandler(MemCheckOutputView::OnSearchNonworkspace), NULL, this);
     m_searchMenu->Disconnect(XRCID("memcheck_search_nonworkspace"), wxEVT_UPDATE_UI,
-        wxUpdateUIEventHandler(MemCheckOutputView::OnSuppPanelUI), NULL, this);
+                             wxUpdateUIEventHandler(MemCheckOutputView::OnSuppPanelUI), NULL, this);
 }
 
 void MemCheckOutputView::LoadErrors()
 {
-    CL_DEBUG1(PLUGIN_PREFIX("MemCheckOutputView::LoadErrors()"));
-
     if(m_mgr->IsWorkspaceOpen())
         m_workspacePath =
             m_mgr->GetWorkspace()->GetWorkspaceFileName().GetPath(wxPATH_GET_VOLUME | wxPATH_GET_SEPARATOR);
@@ -90,9 +88,12 @@ void MemCheckOutputView::ResetItemsView()
     ErrorList& errorList = m_plugin->GetProcessor()->GetErrors();
 
     unsigned int flags = 0;
-    if(m_plugin->GetSettings()->GetOmitNonWorkspace()) flags |= MC_IT_OMIT_NONWORKSPACE;
-    if(m_plugin->GetSettings()->GetOmitDuplications()) flags |= MC_IT_OMIT_DUPLICATIONS;
-    if(m_plugin->GetSettings()->GetOmitSuppressed()) flags |= MC_IT_OMIT_SUPPRESSED;
+    if(m_plugin->GetSettings()->GetOmitNonWorkspace())
+        flags |= MC_IT_OMIT_NONWORKSPACE;
+    if(m_plugin->GetSettings()->GetOmitDuplications())
+        flags |= MC_IT_OMIT_DUPLICATIONS;
+    if(m_plugin->GetSettings()->GetOmitSuppressed())
+        flags |= MC_IT_OMIT_SUPPRESSED;
 
     m_totalErrorsView = 0;
     for(MemCheckIterTools::ErrorListIterator it = MemCheckIterTools::Factory(errorList, m_workspacePath, flags);
@@ -119,7 +120,8 @@ void MemCheckOutputView::ResetItemsSupp()
     ErrorList& errorList = m_plugin->GetProcessor()->GetErrors();
 
     size_t iterFlags = 0;
-    if(m_plugin->GetSettings()->GetOmitSuppressed()) iterFlags |= MC_IT_OMIT_SUPPRESSED;
+    if(m_plugin->GetSettings()->GetOmitSuppressed())
+        iterFlags |= MC_IT_OMIT_SUPPRESSED;
 
     m_totalErrorsSupp = 0;
     for(MemCheckIterTools::ErrorListIterator it = MemCheckIterTools::Factory(errorList, wxEmptyString, iterFlags);
@@ -150,7 +152,8 @@ void MemCheckOutputView::ShowPageView(size_t page)
     m_onValueChangedLocked = false;
     m_dataViewCtrlErrorsModel->Clear();
 
-    if(m_totalErrorsView == 0) return;
+    if(m_totalErrorsView == 0)
+        return;
 
     ErrorList& errorList = m_plugin->GetProcessor()->GetErrors();
     long iStart = (long)(m_currentPage - 1) * m_plugin->GetSettings()->GetResultPageSize();
@@ -160,16 +163,20 @@ void MemCheckOutputView::ShowPageView(size_t page)
     m_currentPageIsEmptyView = (iStop - iStart) < 0;
 
     // this should never happen if m_totalErrorsView > 0, but...
-    if(m_currentPageIsEmptyView) return;
+    if(m_currentPageIsEmptyView)
+        return;
 
     wxWindowDisabler disableAll;
     wxBusyInfo wait(BUSY_MESSAGE);
     m_mgr->GetTheApp()->Yield();
 
     unsigned int flags = 0;
-    if(m_plugin->GetSettings()->GetOmitNonWorkspace()) flags |= MC_IT_OMIT_NONWORKSPACE;
-    if(m_plugin->GetSettings()->GetOmitDuplications()) flags |= MC_IT_OMIT_DUPLICATIONS;
-    if(m_plugin->GetSettings()->GetOmitSuppressed()) flags |= MC_IT_OMIT_SUPPRESSED;
+    if(m_plugin->GetSettings()->GetOmitNonWorkspace())
+        flags |= MC_IT_OMIT_NONWORKSPACE;
+    if(m_plugin->GetSettings()->GetOmitDuplications())
+        flags |= MC_IT_OMIT_DUPLICATIONS;
+    if(m_plugin->GetSettings()->GetOmitSuppressed())
+        flags |= MC_IT_OMIT_SUPPRESSED;
     size_t i = 0;
     MemCheckIterTools::ErrorListIterator it = MemCheckIterTools::Factory(errorList, m_workspacePath, flags);
     for(; i < iStart && it != errorList.end(); ++i, ++it)
@@ -178,11 +185,11 @@ void MemCheckOutputView::ShowPageView(size_t page)
     m_mgr->GetTheApp()->Yield();
     for(; i <= iStop; ++i, ++it) {
         if(it == errorList.end()) {
-            CL_WARNING(PLUGIN_PREFIX("Some items skipped. Total errors count mismatches the iterator."));
             break;
         }
         AddTree(wxDataViewItem(0), *it); // CL_DEBUG1(PLUGIN_PREFIX("adding %lu", i));
-        if(!(i % WAIT_UPDATE_PER_ITEMS)) m_mgr->GetTheApp()->Yield();
+        if(!(i % WAIT_UPDATE_PER_ITEMS))
+            m_mgr->GetTheApp()->Yield();
     }
 }
 
@@ -196,9 +203,10 @@ void MemCheckOutputView::AddTree(const wxDataViewItem& parentItem, MemCheckError
     wxVector<wxVariant> cols;
     cols.push_back(variantBitmap);
     cols.push_back(wxVariant(false));
-    cols.push_back(MemCheckDVCErrorsModel::CreateIconTextVariant(error.label,
-        (error.type == MemCheckError::TYPE_AUXILIARY ? wxXmlResource::Get()->LoadBitmap(wxT("memcheck_auxiliary")) :
-                                                       wxXmlResource::Get()->LoadBitmap(wxT("memcheck_error")))));
+    cols.push_back(MemCheckDVCErrorsModel::CreateIconTextVariant(
+        error.label,
+        (error.type == MemCheckError::TYPE_AUXILIARY ? wxXmlResource::Get()->LoadBitmap(wxT("memcheck_auxiliary"))
+                                                     : wxXmlResource::Get()->LoadBitmap(wxT("memcheck_error")))));
     cols.push_back(wxString());
     cols.push_back(wxString());
     cols.push_back(wxString());
@@ -210,9 +218,12 @@ void MemCheckOutputView::AddTree(const wxDataViewItem& parentItem, MemCheckError
     }
 
     unsigned int flags = 0;
-    if(m_plugin->GetSettings()->GetOmitNonWorkspace()) flags |= MC_IT_OMIT_NONWORKSPACE;
-    if(m_plugin->GetSettings()->GetOmitDuplications()) flags |= MC_IT_OMIT_DUPLICATIONS;
-    if(m_plugin->GetSettings()->GetOmitSuppressed()) flags |= MC_IT_OMIT_SUPPRESSED;
+    if(m_plugin->GetSettings()->GetOmitNonWorkspace())
+        flags |= MC_IT_OMIT_NONWORKSPACE;
+    if(m_plugin->GetSettings()->GetOmitDuplications())
+        flags |= MC_IT_OMIT_DUPLICATIONS;
+    if(m_plugin->GetSettings()->GetOmitSuppressed())
+        flags |= MC_IT_OMIT_SUPPRESSED;
 
     wxBitmap bmpLocation = wxXmlResource::Get()->LoadBitmap(wxT("memcheck_location"));
     MemCheckIterTools::LocationListIterator it = MemCheckIterTools::Factory(error.locations, m_workspacePath, flags);
@@ -228,7 +239,8 @@ void MemCheckOutputView::AddTree(const wxDataViewItem& parentItem, MemCheckError
         strLine << location.line;
         cols.push_back(strLine);
         cols.push_back(wxVariant(location.getObj(m_workspacePath)));
-        m_dataViewCtrlErrorsModel->AppendItem(errorItem, cols,
+        m_dataViewCtrlErrorsModel->AppendItem(
+            errorItem, cols,
             ((location.line > 0 && !location.file.IsEmpty()) ? new MemCheckErrorLocationReferrer(location) : NULL));
     }
 }
@@ -250,24 +262,23 @@ void MemCheckOutputView::OnPageLast(wxCommandEvent& event) { ShowPageView(m_page
 unsigned int MemCheckOutputView::GetColumnByName(const wxString& name)
 {
     for(unsigned int i = 0; i < m_dataViewCtrlErrors->GetColumnCount(); i++)
-        if(m_dataViewCtrlErrors->GetColumn(i)->GetTitle().IsSameAs(name, false)) return i;
-
-    CL_ERROR(PLUGIN_PREFIX("Column named '%s' not found.", name));
+        if(m_dataViewCtrlErrors->GetColumn(i)->GetTitle().IsSameAs(name, false))
+            return i;
     return -1;
 }
 
 void MemCheckOutputView::JumpToLocation(const wxDataViewItem& item)
 {
-    // CL_DEBUG1(PLUGIN_PREFIX("MemCheckOutputView::JumpToLocation()"));
-
     MemCheckErrorLocationReferrer* locationRef =
         dynamic_cast<MemCheckErrorLocationReferrer*>(m_dataViewCtrlErrorsModel->GetClientObject(item));
-    if(!locationRef) return;
+    if(!locationRef)
+        return;
 
     int line = locationRef->Get().line - 1;
     wxString fileName = locationRef->Get().getFile();
 
-    if(line < 0 || fileName.IsEmpty()) return;
+    if(line < 0 || fileName.IsEmpty())
+        return;
 
     if(m_mgr->OpenFile(fileName, wxEmptyString, line)) {
         IEditor* editor = m_mgr->GetActiveEditor();
@@ -281,13 +292,10 @@ void MemCheckOutputView::JumpToLocation(const wxDataViewItem& item)
 
 wxDataViewItem MemCheckOutputView::GetTopParent(wxDataViewItem item)
 {
-    // CL_DEBUG1(PLUGIN_PREFIX("MemCheckOutputView::GetTopParent()"));
-
     wxVector<wxVariant> cols;
     wxDataViewIconText x;
 
     if(!item.IsOk()) {
-        CL_ERROR(PLUGIN_PREFIX("Virtual root item has no parent."));
         return item;
     }
 
@@ -397,7 +405,8 @@ void MemCheckOutputView::OnJumpToNext(wxCommandEvent& event)
 {
     // CL_DEBUG1(PLUGIN_PREFIX("MemCheckOutputView::OnJumpToNext()"));
 
-    if(m_currentPageIsEmptyView) return;
+    if(m_currentPageIsEmptyView)
+        return;
 
     m_notebookOutputView->ChangeSelection(m_notebookOutputView->FindPage(m_panelErrors));
 
@@ -418,7 +427,8 @@ void MemCheckOutputView::OnJumpToPrev(wxCommandEvent& event)
 {
     // CL_DEBUG1(PLUGIN_PREFIX("MemCheckOutputView::OnJumpToPrev()"));
 
-    if(m_currentPageIsEmptyView) return;
+    if(m_currentPageIsEmptyView)
+        return;
 
     m_notebookOutputView->ChangeSelection(m_notebookOutputView->FindPage(m_panelErrors));
 
@@ -446,16 +456,17 @@ void MemCheckOutputView::MarkTree(const wxDataViewItem& item, bool checked)
     if(m_dataViewCtrlErrorsModel->IsContainer(item)) {
         wxDataViewItemArray subItems;
         m_dataViewCtrlErrorsModel->GetChildren(item, subItems);
-        for(size_t i = 0; i < subItems.GetCount(); ++i) MarkTree(subItems.Item(i), checked);
+        for(size_t i = 0; i < subItems.GetCount(); ++i)
+            MarkTree(subItems.Item(i), checked);
     }
 }
 
-
 void MemCheckOutputView::OnContextMenu(wxDataViewEvent& event)
 {
     // CL_DEBUG1(PLUGIN_PREFIX("MemCheckOutputView::OnContextMenu()"));
 
-    if(m_currentPageIsEmptyView) return;
+    if(m_currentPageIsEmptyView)
+        return;
 
     bool unmarked, marked;
     GetStatusOfErrors(unmarked, marked);
@@ -485,23 +496,29 @@ void MemCheckOutputView::OnContextMenu(wxDataViewEvent& event)
     menuItem->Enable(marked);
 
     menu.Connect(XRCID("memcheck_jump_to_location"), wxEVT_COMMAND_MENU_SELECTED,
-        wxCommandEventHandler(MemCheckOutputView::OnJumpToLocation), new wxDataViewEvent(event), (wxEvtHandler*)this);
+                 wxCommandEventHandler(MemCheckOutputView::OnJumpToLocation), new wxDataViewEvent(event),
+                 (wxEvtHandler*)this);
     menu.Connect(XRCID("memcheck_mark_all_errors"), wxEVT_COMMAND_MENU_SELECTED,
-        wxCommandEventHandler(MemCheckOutputView::OnMarkAllErrors), new wxDataViewEvent(event), (wxEvtHandler*)this);
+                 wxCommandEventHandler(MemCheckOutputView::OnMarkAllErrors), new wxDataViewEvent(event),
+                 (wxEvtHandler*)this);
     menu.Connect(XRCID("memcheck_unmark_all_errors"), wxEVT_COMMAND_MENU_SELECTED,
-        wxCommandEventHandler(MemCheckOutputView::OnUnmarkAllErrors), new wxDataViewEvent(event), (wxEvtHandler*)this);
+                 wxCommandEventHandler(MemCheckOutputView::OnUnmarkAllErrors), new wxDataViewEvent(event),
+                 (wxEvtHandler*)this);
     menu.Connect(XRCID("memcheck_suppress_error"), wxEVT_COMMAND_MENU_SELECTED,
-        wxCommandEventHandler(MemCheckOutputView::OnSuppressError), new wxDataViewEvent(event), (wxEvtHandler*)this);
+                 wxCommandEventHandler(MemCheckOutputView::OnSuppressError), new wxDataViewEvent(event),
+                 (wxEvtHandler*)this);
     menu.Connect(XRCID("memcheck_suppress_marked_errors"), wxEVT_COMMAND_MENU_SELECTED,
-        wxCommandEventHandler(MemCheckOutputView::OnSuppressMarkedErrors), new wxDataViewEvent(event),
-        (wxEvtHandler*)this);
+                 wxCommandEventHandler(MemCheckOutputView::OnSuppressMarkedErrors), new wxDataViewEvent(event),
+                 (wxEvtHandler*)this);
     menu.Connect(XRCID("memcheck_row_to_clip"), wxEVT_COMMAND_MENU_SELECTED,
-        wxCommandEventHandler(MemCheckOutputView::OnRowToClip), new wxDataViewEvent(event), (wxEvtHandler*)this);
+                 wxCommandEventHandler(MemCheckOutputView::OnRowToClip), new wxDataViewEvent(event),
+                 (wxEvtHandler*)this);
     menu.Connect(XRCID("memcheck_error_to_clip"), wxEVT_COMMAND_MENU_SELECTED,
-        wxCommandEventHandler(MemCheckOutputView::OnErrorToClip), new wxDataViewEvent(event), (wxEvtHandler*)this);
+                 wxCommandEventHandler(MemCheckOutputView::OnErrorToClip), new wxDataViewEvent(event),
+                 (wxEvtHandler*)this);
     menu.Connect(XRCID("memcheck_marked_errors_to_clip"), wxEVT_COMMAND_MENU_SELECTED,
-        wxCommandEventHandler(MemCheckOutputView::OnMarkedErrorsToClip), new wxDataViewEvent(event),
-        (wxEvtHandler*)this);
+                 wxCommandEventHandler(MemCheckOutputView::OnMarkedErrorsToClip), new wxDataViewEvent(event),
+                 (wxEvtHandler*)this);
 
     m_dataViewCtrlErrors->PopupMenu(&menu);
 }
@@ -509,22 +526,17 @@ void MemCheckOutputView::OnContextMenu(wxDataViewEvent& event)
 void MemCheckOutputView::OnJumpToLocation(wxCommandEvent& event)
 {
     wxDataViewEvent* menuEvent = dynamic_cast<wxDataViewEvent*>(event.GetEventUserData());
-    if(!menuEvent) return;
+    if(!menuEvent)
+        return;
 
     wxDataViewItem item = GetLeaf(menuEvent->GetItem());
     SetCurrentItem(item);
     JumpToLocation(item);
 }
 
-void MemCheckOutputView::OnMarkAllErrors(wxCommandEvent& event)
-{
-    MarkAllErrors(true);
-}
+void MemCheckOutputView::OnMarkAllErrors(wxCommandEvent& event) { MarkAllErrors(true); }
 
-void MemCheckOutputView::OnUnmarkAllErrors(wxCommandEvent& event)
-{
-    MarkAllErrors(false);
-}
+void MemCheckOutputView::OnUnmarkAllErrors(wxCommandEvent& event) { MarkAllErrors(false); }
 
 void MemCheckOutputView::MarkAllErrors(bool state)
 {
@@ -547,14 +559,15 @@ void MemCheckOutputView::GetStatusOfErrors(bool& unmarked, bool& marked)
     m_dataViewCtrlErrorsModel->GetChildren(wxDataViewItem(0), items);
     for(wxDataViewItemArray::iterator it = items.begin(); it != items.end(); ++it) {
         m_dataViewCtrlErrorsModel->GetValue(variant, *it, supColumn);
-        variant.GetBool() ? (marked = true):(unmarked = true);
+        variant.GetBool() ? (marked = true) : (unmarked = true);
     }
 }
 
 void MemCheckOutputView::OnSuppressError(wxCommandEvent& event)
 {
     wxDataViewEvent* menuEvent = dynamic_cast<wxDataViewEvent*>(event.GetEventUserData());
-    if(!menuEvent) return;
+    if(!menuEvent)
+        return;
 
     wxDataViewItem clickedItem = GetTopParent(menuEvent->GetItem());
     SuppressErrors(SUPPRESS_CLICKED, &clickedItem);
@@ -565,16 +578,19 @@ void MemCheckOutputView::OnSuppressMarkedErrors(wxCommandEvent& event) { Suppres
 void MemCheckOutputView::OnRowToClip(wxCommandEvent& event)
 {
     wxDataViewEvent* menuEvent = dynamic_cast<wxDataViewEvent*>(event.GetEventUserData());
-    if(!menuEvent) return;
+    if(!menuEvent)
+        return;
 
     if(wxTheClipboard->Open()) {
         MemCheckErrorReferrer* errorRef =
             dynamic_cast<MemCheckErrorReferrer*>(m_dataViewCtrlErrorsModel->GetClientObject(menuEvent->GetItem()));
-        if(errorRef) wxTheClipboard->SetData(new wxTextDataObject(errorRef->Get().label));
+        if(errorRef)
+            wxTheClipboard->SetData(new wxTextDataObject(errorRef->Get().label));
 
         MemCheckErrorLocationReferrer* locationRef = dynamic_cast<MemCheckErrorLocationReferrer*>(
             m_dataViewCtrlErrorsModel->GetClientObject(menuEvent->GetItem()));
-        if(locationRef) wxTheClipboard->SetData(new wxTextDataObject(locationRef->Get().toString()));
+        if(locationRef)
+            wxTheClipboard->SetData(new wxTextDataObject(locationRef->Get().toString()));
 
         wxTheClipboard->Close();
     }
@@ -583,11 +599,13 @@ void MemCheckOutputView::OnRowToClip(wxCommandEvent& event)
 void MemCheckOutputView::OnErrorToClip(wxCommandEvent& event)
 {
     wxDataViewEvent* menuEvent = dynamic_cast<wxDataViewEvent*>(event.GetEventUserData());
-    if(!menuEvent) return;
+    if(!menuEvent)
+        return;
 
     MemCheckErrorReferrer* errorRef = dynamic_cast<MemCheckErrorReferrer*>(
         m_dataViewCtrlErrorsModel->GetClientObject(GetTopParent(menuEvent->GetItem())));
-    if(!errorRef) return;
+    if(!errorRef)
+        return;
 
     if(wxTheClipboard->Open()) {
         wxTheClipboard->SetData(new wxTextDataObject(errorRef->Get().toString()));
@@ -598,7 +616,8 @@ void MemCheckOutputView::OnErrorToClip(wxCommandEvent& event)
 void MemCheckOutputView::OnMarkedErrorsToClip(wxCommandEvent& event)
 {
     wxDataViewEvent* menuEvent = dynamic_cast<wxDataViewEvent*>(event.GetEventUserData());
-    if(!menuEvent) return;
+    if(!menuEvent)
+        return;
 
     wxString text;
     wxVariant variant;
@@ -630,7 +649,8 @@ void MemCheckOutputView::OnOpenPlain(wxCommandEvent& event)
     IMemCheckProcessor* processor = m_plugin->GetProcessor();
     if(processor) {
         wxString name = processor->GetOutputLogFileName();
-        if(!name.IsEmpty()) m_mgr->OpenFile(name);
+        if(!name.IsEmpty())
+            m_mgr->OpenFile(name);
     }
 }
 
@@ -664,7 +684,8 @@ void MemCheckOutputView::OnSuppFileOpen(wxCommandEvent& event)
 void MemCheckOutputView::UpdateStatusSupp()
 {
     m_staticTextSuppStatus->SetLabel(wxString::Format(_("Total: %lu  Filtered: %lu  Selected: %d"), m_totalErrorsSupp,
-        m_filterResults.size(), m_listCtrlErrors->GetSelectedItemCount()));
+                                                      m_filterResults.size(),
+                                                      m_listCtrlErrors->GetSelectedItemCount()));
     m_staticTextSuppStatus->GetParent()->Layout();
 }
 
@@ -683,7 +704,8 @@ void MemCheckOutputView::SuppressErrors(unsigned int mode, wxDataViewItem* dvIte
                 MemCheckErrorReferrer* errorRef =
                     dynamic_cast<MemCheckErrorReferrer*>(m_dataViewCtrlErrorsModel->GetClientObject(*dvItem));
                 // TODO ? print error message?
-                if(!errorRef) break;
+                if(!errorRef)
+                    break;
                 editor->AppendText(wxString::Format("\n%s", errorRef->Get().getSuppression()));
                 errorRef->Get().suppressed = true;
             } break;
@@ -720,7 +742,8 @@ void MemCheckOutputView::SuppressErrors(unsigned int mode, wxDataViewItem* dvIte
                 long item = -1;
                 for(;;) {
                     item = m_listCtrlErrors->GetNextItem(item, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
-                    if(item == -1) break;
+                    if(item == -1)
+                        break;
                     editor->AppendText(wxString::Format("\n%s", m_filterResults[item]->getSuppression()));
                     m_filterResults[item]->suppressed = true;
                 }
@@ -763,10 +786,12 @@ void MemCheckOutputView::ApplyFilterSupp(unsigned int mode)
     // change filter type
     if(mode == FILTER_STRING && m_searchCtrlFilter->GetValue().IsSameAs(wxT(FILTER_NONWORKSPACE_PLACEHOLDER)))
         mode = FILTER_WORKSPACE;
-    if(mode == FILTER_STRING && m_searchCtrlFilter->GetValue().IsEmpty()) mode = FILTER_CLEAR;
+    if(mode == FILTER_STRING && m_searchCtrlFilter->GetValue().IsEmpty())
+        mode = FILTER_CLEAR;
 
     size_t iterFlags = 0;
-    if(m_plugin->GetSettings()->GetOmitSuppressed()) iterFlags |= MC_IT_OMIT_SUPPRESSED;
+    if(m_plugin->GetSettings()->GetOmitSuppressed())
+        iterFlags |= MC_IT_OMIT_SUPPRESSED;
 
     m_filterResults.clear();
     m_listCtrlErrors->SetItemCount(0);
@@ -785,20 +810,23 @@ void MemCheckOutputView::ApplyFilterSupp(unsigned int mode)
         break;
 
     case FILTER_WORKSPACE:
-        CL_DEBUG1(PLUGIN_PREFIX("m_workspacePath %s", m_workspacePath));
         m_searchCtrlFilter->SetValue(wxT(FILTER_NONWORKSPACE_PLACEHOLDER));
         m_searchCtrlFilter->SelectAll();
         for(MemCheckIterTools::ErrorListIterator it = MemCheckIterTools::Factory(errorList, wxEmptyString, iterFlags);
             it != errorList.end(); ++it) {
-            if(m_checkBoxInvert->IsChecked() == (*it).hasPath(m_workspacePath)) m_filterResults.push_back(&*it);
+            if(m_checkBoxInvert->IsChecked() == (*it).hasPath(m_workspacePath))
+                m_filterResults.push_back(&*it);
         }
         break;
 
     case FILTER_STRING:
         size_t flags = 0;
-        if(m_checkBoxCase->IsChecked()) flags |= wxSD_MATCHCASE;
-        if(m_checkBoxRegexp->IsChecked()) flags |= wxSD_REGULAREXPRESSION;
-        if(m_checkBoxWord->IsChecked()) flags |= wxSD_MATCHWHOLEWORD;
+        if(m_checkBoxCase->IsChecked())
+            flags |= wxSD_MATCHCASE;
+        if(m_checkBoxRegexp->IsChecked())
+            flags |= wxSD_REGULAREXPRESSION;
+        if(m_checkBoxWord->IsChecked())
+            flags |= wxSD_MATCHWHOLEWORD;
         int offset = 0;
         int pos = 0, len = 0;
         if(m_totalErrorsSupp > ITEMS_FOR_WAIT_DIALOG) {
@@ -810,11 +838,13 @@ void MemCheckOutputView::ApplyFilterSupp(unsigned int mode)
         for(MemCheckIterTools::ErrorListIterator it = MemCheckIterTools::Factory(errorList, wxEmptyString, iterFlags);
             it != errorList.end(); ++it) {
             if(m_checkBoxInvert->IsChecked() != StringFindReplacer::Search((*it).toString().wc_str(), offset,
-                                                    m_searchCtrlFilter->GetValue().wc_str(), flags, pos, len))
+                                                                           m_searchCtrlFilter->GetValue().wc_str(),
+                                                                           flags, pos, len))
                 m_filterResults.push_back(&*it);
             if(m_totalErrorsSupp > ITEMS_FOR_WAIT_DIALOG) {
                 ++i;
-                if(!(i % WAIT_UPDATE_PER_ITEMS)) m_mgr->GetTheApp()->Yield();
+                if(!(i % WAIT_UPDATE_PER_ITEMS))
+                    m_mgr->GetTheApp()->Yield();
             }
         }
         break;
@@ -833,7 +863,9 @@ void MemCheckOutputView::OnClearFilter(wxCommandEvent& event) { ApplyFilterSupp(
 
 void MemCheckOutputView::OnSearchNonworkspace(wxCommandEvent& event) { ApplyFilterSupp(FILTER_WORKSPACE); }
 
-void MemCheckOutputView::OnListCtrlErrorsActivated(wxListEvent& event) { /*SuppressErrors(SUPPRESS_SELECTED);*/}
+void MemCheckOutputView::OnListCtrlErrorsActivated(wxListEvent& event)
+{ /*SuppressErrors(SUPPRESS_SELECTED);*/
+}
 
 void MemCheckOutputView::OnSuppressAll(wxCommandEvent& event) { SuppressErrors(SUPPRESS_ALL); }
 
@@ -904,7 +936,8 @@ void MemCheckOutputView::OnListCtrlErrorsMouseMotion(wxMouseEvent& event)
     if(item != m_lastToolTipItem) {
         m_lastToolTipItem = item;
         m_listCtrlErrors->UnsetToolTip();
-        if(item != wxNOT_FOUND) CallAfter(&MemCheckOutputView::ListCtrlErrorsShowTip, item);
+        if(item != wxNOT_FOUND)
+            CallAfter(&MemCheckOutputView::ListCtrlErrorsShowTip, item);
     }
 }
 
@@ -967,7 +1000,7 @@ void MemCheckOutputView::OnSuppPanelUI(wxUpdateUIEvent& event)
         ready &= m_choiceSuppFile->GetSelection() != wxNOT_FOUND && m_listCtrlErrors->GetItemCount() > 0;
     } else if(id == XRCID("memcheck_suppress_selected")) {
         ready &= m_choiceSuppFile->GetSelection() != wxNOT_FOUND && m_listCtrlErrors->GetItemCount() > 0 &&
-            m_listCtrlErrors->GetSelectedItemCount() > 0;
+                 m_listCtrlErrors->GetSelectedItemCount() > 0;
     }
     event.Enable(ready);
 }
@@ -980,10 +1013,7 @@ void MemCheckOutputView::Clear()
 void MemCheckOutputView::OnStop(wxCommandEvent& event) { m_plugin->StopProcess(); }
 void MemCheckOutputView::OnStopUI(wxUpdateUIEvent& event) { event.Enable(m_plugin->IsRunning()); }
 
-void MemCheckOutputView::OnClearOutput(wxCommandEvent& event)
-{
-    Clear();
-}
+void MemCheckOutputView::OnClearOutput(wxCommandEvent& event) { Clear(); }
 
 void MemCheckOutputView::OnClearOutputUpdateUI(wxUpdateUIEvent& event)
 {
