@@ -1,10 +1,12 @@
 #include "CodeBlocksImporter.h"
-#include <wx/xml/xml.h>
-#include <wx/filefn.h>
-#include <wx/tokenzr.h>
+
 #include "macros.h"
 
-bool CodeBlocksImporter::OpenWordspace(const wxString& filename, const wxString& defaultCompiler)
+#include <wx/filefn.h>
+#include <wx/tokenzr.h>
+#include <wx/xml/xml.h>
+
+bool CodeBlocksImporter::OpenWorkspace(const wxString& filename, const wxString& defaultCompiler)
 {
     wsInfo.Assign(filename);
 
@@ -299,7 +301,8 @@ void CodeBlocksImporter::GenerateFromProject(GenericWorkspacePtr genericWorkspac
                                             while(makeCommandsChild) {
                                                 if(makeCommandsChild->GetName() == wxT("Build") &&
                                                    makeCommandsChild->HasAttribute(wxT("command"))) {
-                                                    wxString buildCommand = makeCommandsChild->GetAttribute(wxT("command"));
+                                                    wxString buildCommand =
+                                                        makeCommandsChild->GetAttribute(wxT("command"));
 
                                                     if(!genericProjectCfg->enableCustomBuild)
                                                         genericProjectCfg->enableCustomBuild = true;
@@ -307,7 +310,8 @@ void CodeBlocksImporter::GenerateFromProject(GenericWorkspacePtr genericWorkspac
                                                     genericProjectCfg->customBuildCmd = buildCommand;
                                                 } else if(makeCommandsChild->GetName() == wxT("Clean") &&
                                                           makeCommandsChild->HasAttribute(wxT("command"))) {
-                                                    wxString cleanCommand = makeCommandsChild->GetAttribute(wxT("command"));
+                                                    wxString cleanCommand =
+                                                        makeCommandsChild->GetAttribute(wxT("command"));
 
                                                     if(!genericProjectCfg->enableCustomBuild)
                                                         genericProjectCfg->enableCustomBuild = true;
