@@ -2,8 +2,11 @@
 #define GOTOANYTHINGDLG_H
 
 #include "GotoAnythingBaseUI.h"
+#include "bitmap_loader.h"
 #include "clGotoAnythingManager.h"
+#include "clThemedListCtrl.h"
 #include "codelite_exports.h"
+
 #include <vector>
 
 // class WXDLLIMPEXP_SDK GotoAnythingItemData
@@ -21,6 +24,7 @@ class WXDLLIMPEXP_SDK GotoAnythingDlg : public GotoAnythingBaseDlg
 {
     const std::vector<clGotoEntry>& m_allEntries;
     wxString m_currentFilter;
+    clThemedListCtrl::BitmapVec_t m_bitmaps;
 
 protected:
     virtual void OnItemActivated(wxDataViewEvent& event);
