@@ -2,26 +2,31 @@
 #define LSPNETWORKSOCKET_H
 
 #include "LSPNetwork.h"
-#include "cl_command_event.h"
 #include "SocketAPI/clSocketClientAsync.h"
-#include <wx/process.h>
+#include "asyncprocess.h"
+#include "cl_command_event.h"
+
+#include <wx/ffile.h>
 
 ///===------------------------------
-/// LSPNetwork based on sockets
+/// LSPNetwork based on STDIO
 ///===------------------------------
-
 class ChildProcess;
 class LSPNetworkSTDIO : public LSPNetwork
 {
 protected:
-    clAsyncSocket::Ptr_t m_socket;
     ChildProcess* m_server = nullptr;
+    wxFFile m_log;
+
+protected:
+    void DoStartLocalProcess();
+    void BindEvents();
 
 protected:
     void OnProcessTerminated(clProcessEvent& event);
     void OnProcessOutput(clProcessEvent& event);
     void OnProcessStderr(clProcessEvent& event);
-    
+
 public:
     virtual void Close();
     /**
