@@ -1,10 +1,12 @@
 #include "NewFileSystemWorkspaceDialog.h"
-#include <wx/filename.h>
+
 #include "globals.h"
+
 #include <wx/filename.h>
 
-NewFileSystemWorkspaceDialog::NewFileSystemWorkspaceDialog(wxWindow* parent)
+NewFileSystemWorkspaceDialog::NewFileSystemWorkspaceDialog(wxWindow* parent, bool autoSetNameFromPath)
     : NewFileSystemWorkspaceDialogBase(parent)
+    , m_autoSetNameFromPath(autoSetNameFromPath)
 {
     GetSizer()->Fit(this);
     CenterOnParent();
@@ -26,6 +28,10 @@ void NewFileSystemWorkspaceDialog::OnDirSelected(wxFileDirPickerEvent& event)
     event.Skip();
     wxString path = event.GetPath();
     wxFileName fndir(path, "");
-    if(fndir.GetDirCount() == 0) { return; }
-    if(m_textCtrlName->IsEmpty()) { m_textCtrlName->ChangeValue(fndir.GetDirs().Last()); }
+    if(fndir.GetDirCount() == 0) {
+        return;
+    }
+    if(m_textCtrlName->IsEmpty() && m_autoSetNameFromPath) {
+        m_textCtrlName->ChangeValue(fndir.GetDirs().Last());
+    }
 }
