@@ -26,28 +26,31 @@
 #ifndef NOTEBOOKNAVIGATIONDLG_H
 #define NOTEBOOKNAVIGATIONDLG_H
 #include "Notebook.h"
-#include "clMultiBook.h"
 #include "codelite_exports.h"
 #include "wxcrafter_plugin.h"
 
 class WXDLLIMPEXP_SDK NotebookNavigationDlg : public NotebookNavigationDlgBase
 {
     Notebook* m_book = NULL;
-    clMultiBook* m_multibook = NULL;
     int m_selection = wxNOT_FOUND;
 
 public:
     NotebookNavigationDlg(wxWindow* parent, Notebook* book);
-    NotebookNavigationDlg(wxWindow* parent, clMultiBook* book);
     virtual ~NotebookNavigationDlg();
     void CloseDialog();
 
     int GetSelection() const { return m_selection; }
 
 protected:
-    virtual void OnItemActivated(wxDataViewEvent& event);
-    virtual void OnKeyDown(wxKeyEvent& event);
-    virtual void OnKeyUp(wxKeyEvent& event);
+    void OnItemActivated(wxDataViewEvent& event) override;
+    void OnKeyDown(wxKeyEvent& event) override;
+    void OnKeyUp(wxKeyEvent& event) override;
+
+    void SelectNext();
+    void SelectPrev();
+
+    void OnHotKeyNext(wxKeyEvent& event);
+    void OnHotKeyPrev(wxKeyEvent& event);
     void FinalizeCtor();
 };
 #endif // NOTEBOOKNAVIGATIONDLG_H
