@@ -128,7 +128,7 @@ bool BuilderGNUMakeClassic::Export(const wxString& project, const wxString& conf
 
     wxArrayString depsArr = proj->GetDependencies(bld_conf_name);
 
-    CL_DEBUG("Generating Makefile...");
+    clDEBUG() << "Generating Makefile..." << endl;
     // Filter all disabled projects from the dependencies array
     wxArrayString updatedDepsArr;
     for(size_t i = 0; i < depsArr.GetCount(); ++i) {
@@ -456,7 +456,7 @@ bool BuilderGNUMakeClassic::Export(const wxString& project, const wxString& conf
     wxStringInputStream content(text);
     output << content;
 
-    CL_DEBUG("Generating Makefile...is completed");
+    clDEBUG() << "Generating Makefile...is completed" << endl;
     return true;
 }
 
@@ -990,7 +990,6 @@ void BuilderGNUMakeClassic::CreateLinkTargets(const wxString& type, BuildConfigP
 
     for(size_t i = 0; i < depsProj.GetCount(); i++) {
         wxFileName fn(depsProj.Item(i));
-        // CL_DEBUG(wxT("making %s relative to %s"), fn.GetFullPath().c_str(),
         // proj->GetFileName().GetPath().c_str());
         fn.MakeRelativeTo(proj->GetProjectPath());
         extraDeps << "\"" << fn.GetFullPath() << wxT("\" ");
