@@ -23,11 +23,13 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 #include "buildmanager.h"
+
+#include "BuilderGnuMakeMSYS.hpp"
 #include "builder.h"
-#include "builder_gnumake.h"
-#include "builder_gnumake_onestep.h"
 #include "builder_NMake.h"
+#include "builder_gnumake.h"
 #include "builder_gnumake_default.h"
+#include "builder_gnumake_onestep.h"
 
 BuildManager::BuildManager()
 {
@@ -37,6 +39,7 @@ BuildManager::BuildManager()
     AddBuilder(new BuilderGnuMakeOneStep());
 #ifdef __WXMSW__
     AddBuilder(new BuilderNMake());
+    AddBuilder(new BuilderGnuMakeMSYS());
 #endif
 }
 
@@ -44,48 +47,53 @@ BuildManager::~BuildManager() { m_builders.clear(); }
 
 void BuildManager::AddBuilder(BuilderPtr builder)
 {
-    if(!builder) { return; }
-
+    if(!builder) {
+        return;
+    }
     m_builders[builder->GetName()] = builder;
 }
 
 void BuildManager::RemoveBuilder(const wxString& name)
 {
-
-    std::map<wxString, BuilderPtr>::iterator iter = m_builders.find(name);
-    if(iter != m_builders.end()) { m_builders.erase(iter); }
+    auto iter = m_builders.find(name);
+    if(iter != m_builders.end()) {
+        m_builders.erase(iter);
+    }
 }
 
 void BuildManager::GetBuilders(std::list<wxString>& list)
 {
-    std::map<wxString, BuilderPtr>::iterator iter = m_builders.begin();
-    for(; iter != m_builders.end(); iter++) {
+    auto iter = m_builders.begin();
+    for(; iter != m_builders.end(); ++iter) {
         list.push_back(iter->second->GetName());
     }
 }
 
 BuilderPtr BuildManager::GetBuilder(const wxString& name)
 {
-    std::map<wxString, BuilderPtr>::iterator iter = m_builders.begin();
-    for(; iter != m_builders.end(); iter++) {
-        if(iter->first == name) { return iter->second; }
+    auto iter = m_builders.begin();
+    for(; iter != m_builders.end(); ++iter) {
+        if(iter->first == name) {
+            return iter->second;
+        }
     }
 
     // return the default builder
     return m_builders.begin()->second;
 }
 
-static BuildManager* gs_BuildManager = NULL;
+static BuildManager* gs_BuildManager = nullptr;
 void BuildManagerST::Free()
 {
     if(gs_BuildManager) {
         delete gs_BuildManager;
-        gs_BuildManager = NULL;
+        gs_BuildManager = nullptr;
     }
 }
 
 BuildManager* BuildManagerST::Get()
 {
-    if(gs_BuildManager == NULL) gs_BuildManager = new BuildManager;
+    if(gs_BuildManager == nullptr)
+        gs_BuildManager = new BuildManager;
     return gs_BuildManager;
 }
