@@ -1,10 +1,12 @@
+#include "clAboutDialog.h"
+
 #include "ColoursAndFontsManager.h"
 #include "bitmap_loader.h"
-#include "clAboutDialog.h"
 #include "cl_standard_paths.h"
 #include "fileutils.h"
 #include "globals.h"
 #include "imanager.h"
+
 #include <wx/filename.h>
 
 clAboutDialog::clAboutDialog(wxWindow* parent, const wxString& version)
@@ -29,17 +31,17 @@ clAboutDialog::clAboutDialog(wxWindow* parent, const wxString& version)
     wxString credits;
 
     credits << "\n==============================\n\n";
-    credits << _("Eran Ifrah (Project admin)") << "\n";
+    credits << _("Eran Ifrah (author & project admin)") << "\n";
     credits << _("David G. Hart") << "\n\n";
-    credits << "==============================\n\n";
+    credits << "==============================\n\n\n";
+    credits << _("Contributors:\n");
     credits << _("Frank Lichtner") << "\n";
     credits << _("Jacek Kucharski") << "\n";
     credits << _("Marrianne Gagnon") << "\n";
     credits << _("Scott Dolim") << "\n";
     m_stcCredits->SetText(credits);
     m_stcCredits->SetReadOnly(true);
-    CentreOnParent();
-    GetSizer()->Fit(this);
+    ::clSetSmallDialogBestSizeAndPosition(this);
 }
 
 clAboutDialog::~clAboutDialog() {}
