@@ -15,6 +15,8 @@
 #define TEXT_SPACER FromDIP(5)
 #else
 #define TEXT_SPACER 5
+#endif
+#if !wxCHECK_VERSION(3, 1, 2)
 #define SetFractionalPointSize SetPointSize
 #define wxFONTWEIGHT_SEMIBOLD wxFONTWEIGHT_BOLD
 #endif
@@ -272,7 +274,7 @@ void clButtonBase::Render(wxDC& dc)
 
     // set the pen and draw the border
     wxColour base_colour = clSystemSettings::GetDefaultPanelColour();
-    wxColour border_colour = base_colour.ChangeLightness(70);
+    wxColour border_colour = base_colour.ChangeLightness(isDark ? 50 : 70);
 #ifdef __WXMAC__
     if(isDisabled) {
         border_colour = border_colour.ChangeLightness(110);
