@@ -55,7 +55,18 @@ public:
      * The text, bitmap and other info that needs to be drawn are stored
      * in the `entry` field.
      */
-    virtual void Render(wxWindow* window, wxDC& dc, const clColours& colours, int row_index, clRowEntry* entry) = 0;
+    virtual void RenderItem(wxWindow* window, wxDC& dc, const clColours& colours, int row_index, clRowEntry* entry) = 0;
+
+    /**
+     * @brief draw the background of a given entry
+     */
+    virtual void RenderItemBackground(wxDC& dc, long tree_style, const clColours& colours, int row_index,
+                                      clRowEntry* entry) = 0;
+
+    /**
+     * @brief render the list background
+     */
+    virtual void RenderBackground(wxDC& dc, const wxRect& rect, long tree_style, const clColours& colours) = 0;
 };
 
 class WXDLLIMPEXP_SDK clControlWithItems : public clScrolledPanel
@@ -79,13 +90,15 @@ protected:
     bool m_nativeTheme = false;
     std::unique_ptr<clControlWithItemsRowRenderer> m_customRenderer;
     wxFont m_defaultFont = wxNullFont;
+    bool m_recalcColumnWidthOnPaint = true;
+    bool m_disableView = false;
 
 protected:
     void DoInitialize();
     int GetNumLineCanFitOnScreen(bool fully_fit = false) const;
     virtual clRowEntry* GetFirstItemOnScreen();
     virtual void SetFirstItemOnScreen(clRowEntry* item);
-    void RenderItems(wxDC& dc, const clRowEntry::Vec_t& items);
+    void RenderItems(wxDC& dc, long tree_style, const clRowEntry::Vec_t& items);
     void AssignRects(const clRowEntry::Vec_t& items);
     void OnSize(wxSizeEvent& event);
     void DoUpdateHeader(clRowEntry* row);
@@ -108,6 +121,12 @@ public:
     virtual void SetDefaultFont(const wxFont& font);
     virtual wxFont GetDefaultFont() const;
 
+    /**
+     * @brief give the view a "disabled" look and feel
+     */
+    void SetDisabled(bool b);
+    bool IsDisabled() const { return m_disableView; }
+
     /**
      * @brief set a custom renderer to draw the rows for this control
      * `this` takes ownership for the renderer (i.e. it will free it)
