@@ -2,19 +2,19 @@
 #define CLCUSTOMISETOOLBARDLG_H
 
 #include "ToolBarUI.h"
+#include "clToolBar.h"
+#include "wxCustomControls.hpp"
 
 #include <codelite_exports.h>
 #include <vector>
 
-class clToolBarButtonBase;
-class clToolBar;
 class WXDLLIMPEXP_SDK clCustomiseToolBarDlg : public clCustomiseToolBarBaseDlg
 {
-    clToolBar* m_toolbar;
+    clToolBarGeneric* m_toolbar;
     std::vector<clToolBarButtonBase*>& m_buttons;
 
 public:
-    clCustomiseToolBarDlg(wxWindow* parent, clToolBar* tb);
+    clCustomiseToolBarDlg(wxWindow* parent, clToolBarGeneric* tb);
     virtual ~clCustomiseToolBarDlg();
 
 protected:
