@@ -18,15 +18,43 @@ IMPLEMENT_VARIANT_OBJECT_EXPORTED(clDataViewTextBitmap, WXDLLIMPEXP_SDK);
 wxIMPLEMENT_DYNAMIC_CLASS(clDataViewCheckbox, wxObject);
 IMPLEMENT_VARIANT_OBJECT_EXPORTED(clDataViewCheckbox, WXDLLIMPEXP_SDK);
 
-wxIMPLEMENT_DYNAMIC_CLASS(clDataViewChoice, wxObject);
-IMPLEMENT_VARIANT_OBJECT_EXPORTED(clDataViewChoice, WXDLLIMPEXP_SDK);
+wxIMPLEMENT_DYNAMIC_CLASS(clDataViewTextWithButton, wxObject);
+IMPLEMENT_VARIANT_OBJECT_EXPORTED(clDataViewTextWithButton, WXDLLIMPEXP_SDK);
+
+wxIMPLEMENT_DYNAMIC_CLASS(clDataViewColour, wxObject);
+IMPLEMENT_VARIANT_OBJECT_EXPORTED(clDataViewColour, WXDLLIMPEXP_SDK);
+
+wxIMPLEMENT_DYNAMIC_CLASS(clDataViewButton, wxObject);
+IMPLEMENT_VARIANT_OBJECT_EXPORTED(clDataViewButton, WXDLLIMPEXP_SDK);
 
 wxDEFINE_EVENT(wxEVT_DATAVIEW_SEARCH_TEXT, wxDataViewEvent);
 wxDEFINE_EVENT(wxEVT_DATAVIEW_CLEAR_SEARCH, wxDataViewEvent);
-wxDEFINE_EVENT(wxEVT_DATAVIEW_CHOICE_BUTTON, wxDataViewEvent);
+wxDEFINE_EVENT(wxEVT_DATAVIEW_ACTION_BUTTON, wxDataViewEvent);
 wxDEFINE_EVENT(wxEVT_DATAVIEW_CHOICE, wxDataViewEvent);
+wxDEFINE_EVENT(wxEVT_DATAVIEW_SELECTION_CHANGING, wxDataViewEvent);
 
 std::unordered_map<int, int> clDataViewListCtrl::m_stylesMap;
+
+namespace
+{
+const wxString DROPDOWN_ARROW_UNICODE = wxT("\u25BC");
+const wxString ELLIPSIS_UNICODE = wxT("\u22EF");
+const wxString NO_BUTTON_UNICODE = wxT("");
+} // namespace
+
+const wxString& clDataViewTextWithButton::GetButtonUnicodeSymbol() const
+{
+    switch(m_button_kind) {
+    case eCellButtonType::BT_ELLIPSIS:
+        return ELLIPSIS_UNICODE;
+    case eCellButtonType::BT_DROPDOWN_ARROW:
+        return DROPDOWN_ARROW_UNICODE;
+    default:
+    case eCellButtonType::BT_NONE:
+        return NO_BUTTON_UNICODE;
+    }
+}
+
 clDataViewListCtrl::clDataViewListCtrl(wxWindow* parent, wxWindowID id, const wxPoint& pos, const wxSize& size,
                                        long style)
     : clTreeCtrl(parent, id, pos, size, style)
@@ -37,6 +65,7 @@ clDataViewListCtrl::clDataViewListCtrl(wxWindow* parent, wxWindowID id, const wx
         m_stylesMap.insert({ wxDV_ROW_LINES, wxTR_ROW_LINES });
         m_stylesMap.insert({ wxDV_MULTIPLE, wxTR_MULTIPLE });
         m_stylesMap.insert({ wxDV_ENABLE_SEARCH, wxTR_ENABLE_SEARCH });
+        m_stylesMap.insert({ wxDV_COLUMN_WIDTH_NEVER_SHRINKS, wxTR_COLUMN_WIDTH_NEVER_SHRINKS });
     }
 
     int my_style = 0;
@@ -49,6 +78,10 @@ clDataViewListCtrl::clDataViewListCtrl(wxWindow* parent, wxWindowID id, const wx
     if(style & wxDV_NO_HEADER) {
         SetShowHeader(false);
     }
+    if(style & wxDV_COLUMN_WIDTH_NEVER_SHRINKS) {
+        my_style |= wxTR_COLUMN_WIDTH_NEVER_SHRINKS;
+    }
+
     my_style |= wxTR_HIDE_ROOT;
     m_treeStyle = my_style;
 
@@ -62,10 +95,11 @@ clDataViewListCtrl::clDataViewListCtrl(wxWindow* parent, wxWindowID id, const wx
 
     // Translate the following events to wxDVC events
     Bind(wxEVT_TREE_ITEM_VALUE_CHANGED, &clDataViewListCtrl::OnConvertEvent, this);
-    Bind(wxEVT_TREE_CHOICE, &clDataViewListCtrl::OnConvertEvent, this);
+    Bind(wxEVT_TREE_ACTIONBUTTON_CLICKED, &clDataViewListCtrl::OnConvertEvent, this);
     Bind(wxEVT_TREE_BEGIN_DRAG, &clDataViewListCtrl::OnConvertEvent, this);
     Bind(wxEVT_TREE_END_DRAG, &clDataViewListCtrl::OnConvertEvent, this);
     Bind(wxEVT_TREE_SEL_CHANGED, &clDataViewListCtrl::OnConvertEvent, this);
+    Bind(wxEVT_TREE_SEL_CHANGING, &clDataViewListCtrl::OnConvertEvent, this);
     Bind(wxEVT_TREE_ITEM_ACTIVATED, &clDataViewListCtrl::OnConvertEvent, this);
     Bind(wxEVT_TREE_ITEM_MENU, &clDataViewListCtrl::OnConvertEvent, this);
     Bind(wxEVT_TREE_SEARCH_TEXT, &clDataViewListCtrl::OnConvertEvent, this);
@@ -77,15 +111,16 @@ clDataViewListCtrl::clDataViewListCtrl(wxWindow* parent, wxWindowID id, const wx
 clDataViewListCtrl::~clDataViewListCtrl()
 {
     Unbind(wxEVT_TREE_BEGIN_DRAG, &clDataViewListCtrl::OnConvertEvent, this);
-    Unbind(wxEVT_TREE_CHOICE, &clDataViewListCtrl::OnConvertEvent, this);
+    Unbind(wxEVT_TREE_ACTIONBUTTON_CLICKED, &clDataViewListCtrl::OnConvertEvent, this);
     Unbind(wxEVT_TREE_END_DRAG, &clDataViewListCtrl::OnConvertEvent, this);
     Unbind(wxEVT_TREE_SEL_CHANGED, &clDataViewListCtrl::OnConvertEvent, this);
+    Unbind(wxEVT_TREE_SEL_CHANGING, &clDataViewListCtrl::OnConvertEvent, this);
     Unbind(wxEVT_TREE_ITEM_ACTIVATED, &clDataViewListCtrl::OnConvertEvent, this);
     Unbind(wxEVT_TREE_ITEM_MENU, &clDataViewListCtrl::OnConvertEvent, this);
     Unbind(wxEVT_TREE_ITEM_VALUE_CHANGED, &clDataViewListCtrl::OnConvertEvent, this);
 }
 
-void clDataViewListCtrl::AppendItem(const wxVector<wxVariant>& values, wxUIntPtr data)
+wxDataViewItem clDataViewListCtrl::AppendItem(const wxVector<wxVariant>& values, wxUIntPtr data)
 {
     wxTreeItemId item = clTreeCtrl::AppendItem(GetRootItem(), "", -1, -1, nullptr);
     clRowEntry* child = m_model.ToPtr(item);
@@ -97,6 +132,7 @@ void clDataViewListCtrl::AppendItem(const wxVector<wxVariant>& values, wxUIntPtr
         DoSetCellValue(child, i, v);
     }
     UpdateScrollBar();
+    return DV_ITEM(item);
 }
 
 wxDataViewColumn* clDataViewListCtrl::AppendIconTextColumn(const wxString& label, wxDataViewCellMode mode, int width,
@@ -151,8 +187,17 @@ void clDataViewListCtrl::OnConvertEvent(wxTreeEvent& event)
         type = wxEVT_DATAVIEW_ITEM_DROP;
     } else if(event.GetEventType() == wxEVT_TREE_SEL_CHANGED) {
         type = wxEVT_DATAVIEW_SELECTION_CHANGED;
+    } else if(event.GetEventType() == wxEVT_TREE_SEL_CHANGING) {
+        type = wxEVT_DATAVIEW_SELECTION_CHANGING;
     } else if(event.GetEventType() == wxEVT_TREE_ITEM_ACTIVATED) {
+        // we user hit ENTER or d-clicked on an entry in the list
+        // if the current line has action button, covnert this event
+        // into action button event
         type = wxEVT_DATAVIEW_ITEM_ACTIVATED;
+        auto entry = m_model.ToPtr(event.GetItem());
+        if(entry && entry->HasButton(1)) {
+            type = wxEVT_DATAVIEW_ACTION_BUTTON;
+        }
     } else if(event.GetEventType() == wxEVT_TREE_ITEM_MENU) {
         type = wxEVT_DATAVIEW_ITEM_CONTEXT_MENU;
     } else if(event.GetEventType() == wxEVT_TREE_SEARCH_TEXT) {
@@ -162,8 +207,8 @@ void clDataViewListCtrl::OnConvertEvent(wxTreeEvent& event)
         type = wxEVT_DATAVIEW_CLEAR_SEARCH;
     } else if(event.GetEventType() == wxEVT_TREE_ITEM_VALUE_CHANGED) {
         type = wxEVT_DATAVIEW_ITEM_VALUE_CHANGED;
-    } else if(event.GetEventType() == wxEVT_TREE_CHOICE) {
-        type = wxEVT_DATAVIEW_CHOICE_BUTTON;
+    } else if(event.GetEventType() == wxEVT_TREE_ACTIONBUTTON_CLICKED) {
+        type = wxEVT_DATAVIEW_ACTION_BUTTON;
     }
     if(type != wxEVT_ANY) {
         SendDataViewEvent(type, event, eventText);
@@ -351,18 +396,22 @@ void clDataViewListCtrl::DoSetCellValue(clRowEntry* row, size_t col, const wxVar
     wxString variantType = value.GetType();
     if(variantType == "bool") {
         row->SetChecked(value.GetBool(), wxNOT_FOUND, wxString(), col);
+
     } else if(variantType == "string") {
         row->SetLabel(value.GetString(), col);
+
     } else if(variantType == "clDataViewCheckbox") {
         clDataViewCheckbox check;
         check << value;
         row->SetChecked(check.IsChecked(), check.GetBitmapIndex(), check.GetText(), col);
+
     } else if(variantType == "wxDataViewIconText") {
         // Extract the iamge + text from the wxDataViewIconText class
         wxDataViewIconText iconText;
         iconText << value;
         //  update the row with the icon + text
         row->SetLabel(iconText.GetText(), col);
+
     } else if(variantType == "clDataViewTextBitmap") {
         // Extract the iamge + text from the wxDataViewIconText class
         clDataViewTextBitmap iconText;
@@ -370,17 +419,32 @@ void clDataViewListCtrl::DoSetCellValue(clRowEntry* row, size_t col, const wxVar
         //  update the row with the icon + text
         row->SetLabel(iconText.GetText(), col);
         row->SetBitmapIndex(iconText.GetBitmapIndex(), col);
-    } else if(variantType == "clDataViewChoice") {
-        clDataViewChoice choice;
-        choice << value;
-        row->SetChoice(true, col);
-        row->SetBitmapIndex(choice.GetBitmapIndex(), col);
-        row->SetLabel(choice.GetLabel(), col);
+
+    } else if(variantType == "clDataViewTextWithButton") {
+        clDataViewTextWithButton text_with_button;
+        text_with_button << value;
+        row->SetHasButton(text_with_button.GetButtonType(), text_with_button.GetButtonUnicodeSymbol(), col);
+        row->SetBitmapIndex(text_with_button.GetBitmapIndex(), col);
+        row->SetLabel(text_with_button.GetLabel(), col);
+
+    } else if(variantType == "clDataViewButton") {
+        clDataViewButton button;
+        button << value;
+        row->SetIsButton(button.GetLabel(), col);
+        row->SetBitmapIndex(button.GetBitmapIndex(), col);
+
     } else if(variantType == "double") {
         row->SetLabel(wxString() << value.GetDouble(), col);
+
     } else if(variantType == "datetime") {
         row->SetLabel(value.GetDateTime().FormatDate(), col);
+
+    } else if(variantType == "clDataViewColour") {
+        clDataViewColour c;
+        c << value;
+        row->SetColour(c.GetColour(), col);
     }
+
     // Call this to update the view + update the header bar
     clTreeCtrl::SetItemText(wxTreeItemId(row), row->GetLabel(col), col);
 }
@@ -499,7 +563,7 @@ void clDataViewListCtrl::ShowMenuForItem(const wxDataViewItem& item, wxMenu& men
         return;
     }
 
-    wxRect r = row->GetCellRect(col);
+    wxRect r = row->GetCellButtonRect(col);
     PopupMenu(&menu, r.GetBottomLeft());
 }
 
@@ -527,7 +591,7 @@ void clDataViewListCtrl::ShowStringSelectionMenu(const wxDataViewItem& item, con
             }
         },
         wxID_ANY);
-    wxRect r = row->GetCellRect(col);
+    wxRect r = row->GetCellButtonRect(col);
     PopupMenu(&menu, r.GetBottomLeft());
     if(!selectedString.IsEmpty()) {
         // fire selection made event
@@ -621,3 +685,39 @@ void clDataViewListCtrl::CenterRow(size_t row)
     size_t first_row = row - max_rows + (max_rows / 2);
     SetFirstVisibleRow(first_row);
 }
+
+CellType clDataViewListCtrl::GetCellDataType(size_t row, size_t col) const
+{
+    return GetCellDataType(RowToItem(row), col);
+}
+
+CellType clDataViewListCtrl::GetCellDataType(const wxDataViewItem& item, size_t col) const
+{
+    auto row = m_model.ToPtr(TREE_ITEM(item));
+    if(!row) {
+        return CellType::UNKNOWN;
+    }
+    const auto& cell = row->GetColumn(col);
+    if(!cell.IsOk()) {
+        return CellType::UNKNOWN;
+    }
+
+    if(cell.IsColour()) {
+        return CellType::COLOUR;
+
+    } else if(cell.IsBool()) {
+        return CellType::CHECKBOX_TEXT;
+
+    } else if(cell.IsString()) {
+        return CellType::TEXT;
+
+    } else if(cell.HasButton() && cell.GetButtonType() == eCellButtonType::BT_DROPDOWN_ARROW) {
+        return CellType::TEXT_OPTIONS;
+
+    } else if(cell.HasButton() && cell.GetButtonType() == eCellButtonType::BT_ELLIPSIS) {
+        return CellType::TEXT_EDIT;
+
+    } else {
+        return CellType::UNKNOWN;
+    }
+}
