@@ -30,12 +30,12 @@
 #include "macros.h"
 #include "processreaderthread.h"
 #include "shell_command.h"
+#include "wxStringHash.h"
 
 #include <thread>
 #include <wx/msgdlg.h>
 #include <wx/tokenzr.h>
 #include <wx/xrc/xmlres.h>
-#include <wxStringHash.h>
 
 #define CHECK_ACTIVE_CONFIG()                \
     if(!GetSettings().GetSelectedConfig()) { \
@@ -142,7 +142,8 @@ clFileSystemWorkspace::~clFileSystemWorkspace()
 
 wxString clFileSystemWorkspace::GetActiveProjectName() const { return ""; }
 
-wxFileName clFileSystemWorkspace::GetFileName() const { return m_filename; }
+wxString clFileSystemWorkspace::GetFileName() const { return m_filename.GetFullPath(); }
+wxString clFileSystemWorkspace::GetDir() const { return m_filename.GetPath(); }
 
 wxString clFileSystemWorkspace::GetFilesMask() const
 {
@@ -214,13 +215,15 @@ void clFileSystemWorkspace::CacheFiles(bool force)
             clFileSystemEvent event(wxEVT_FS_SCAN_COMPLETED);
             wxArrayString arrfiles;
             arrfiles.Alloc(files.size());
-            for(const wxFileName& f : files) {
+            for(const wxString& s : files) {
+                wxFileName f(s);
                 arrfiles.Add(f.GetFullPath());
             }
+
             event.SetPaths(arrfiles);
             EventNotifier::Get()->QueueEvent(event.Clone());
         },
-        GetFileName().GetPath());
+        GetDir());
     thr.detach();
 }
 
@@ -306,7 +309,7 @@ void clFileSystemWorkspace::DoOpen()
     frame->GetEventHandler()->ProcessEvent(eventCloseWsp);
 
     // set the working directory to the workspace view
-    ::wxSetWorkingDirectory(GetFileName().GetPath());
+    ::wxSetWorkingDirectory(GetDir());
 
     // Create the symbols db file
     wxFileName fnFolder(GetFileName());
@@ -321,7 +324,7 @@ void clFileSystemWorkspace::DoOpen()
     }
 
     // load the new cache
-    m_backtickCache.reset(new clBacktickCache(GetFileName().GetPath()));
+    m_backtickCache.reset(new clBacktickCache(GetDir()));
 
     // Init the view
     GetView()->Clear();
@@ -333,7 +336,7 @@ void clFileSystemWorkspace::DoOpen()
     }
 
     // And now load the main folder
-    GetView()->AddFolder(GetFileName().GetPath());
+    GetView()->AddFolder(GetDir());
 
     // Notify CodeLite that this workspace is opened
     clGetManager()->GetWorkspaceView()->SelectPage(GetWorkspaceType());
@@ -341,8 +344,8 @@ void clFileSystemWorkspace::DoOpen()
 
     // Notify that the a new workspace is loaded
     clWorkspaceEvent event(wxEVT_WORKSPACE_LOADED);
-    event.SetString(GetFileName().GetFullPath());
-    event.SetFileName(GetFileName().GetFullPath());
+    event.SetString(GetFileName());
+    event.SetFileName(GetFileName());
     EventNotifier::Get()->AddPendingEvent(event);
 
     // Update the build configurations button
@@ -363,8 +366,9 @@ void clFileSystemWorkspace::DoOpen()
 
 void clFileSystemWorkspace::DoClose()
 {
-    if(!m_isLoaded)
+    if(!m_isLoaded) {
         return;
+    }
 
     // Store the session
     clGetManager()->StoreWorkspaceSession(m_filename);
@@ -439,6 +443,10 @@ void clFileSystemWorkspace::OnScanCompleted(clFileSystemEvent& event)
 
     // Trigger a non full reparse
     Parse(false);
+
+    clDEBUG() << "Sending wxEVT_WORKSPACE_FILES_SCANNED event..." << endl;
+    clWorkspaceEvent event_scan{ wxEVT_WORKSPACE_FILES_SCANNED };
+    EventNotifier::Get()->ProcessEvent(event_scan);
 }
 
 void clFileSystemWorkspace::OnParseWorkspace(wxCommandEvent& event)
@@ -457,7 +465,7 @@ void clFileSystemWorkspace::Parse(bool fullParse)
     }
 
     if(fullParse) {
-        TagsManagerST::Get()->ParseWorkspaceFull(GetFileName().GetPath());
+        TagsManagerST::Get()->ParseWorkspaceFull(GetDir());
     } else {
         TagsManagerST::Get()->ParseWorkspaceIncremental();
     }
@@ -562,6 +570,7 @@ void clFileSystemWorkspace::OnExecute(clExecuteEvent& event)
     console->SetWaitWhenDone(true);
     console->SetSink(this);
     console->SetEnvironment(envList);
+    console->SetTerminalNeeded(true);
 
     if(console->Start()) {
         m_execPID = console->GetPid();
@@ -738,7 +747,7 @@ void clFileSystemWorkspace::DoBuild(const wxString& target)
 
     // Start the process with the environemt
     wxString ssh_account;
-    wxString wd = GetFileName().GetPath();
+    wxString wd = GetDir();
 
     // make changes if SSH is enabled here
     if(flags & IProcessCreateSSH) {
@@ -808,7 +817,7 @@ void clFileSystemWorkspace::DoCreate(const wxString& name, const wxString& path,
     }
 
     // If an workspace is opened and it is the same one as this, dont do nothing
-    if(m_isLoaded && (GetFileName() == fn)) {
+    if(m_isLoaded && (GetFileName() == fn.GetFullPath())) {
         return;
     }
 
@@ -869,7 +878,7 @@ void clFileSystemWorkspace::OnFileSaved(clCommandEvent& event)
             managedBySftp = true;
         }
 
-        wxString rootPath = GetFileName().GetPath();
+        wxString rootPath = GetDir();
         wxString filePath = wxFileName(filename).GetPath();
         bool doRemoteSave = filePath.StartsWith(rootPath) && !managedBySftp;
 
@@ -880,7 +889,7 @@ void clFileSystemWorkspace::OnFileSaved(clCommandEvent& event)
 
             // Make the local file path relative to the workspace location
             wxFileName fnLocalFile(event.GetFileName());
-            fnLocalFile.MakeRelativeTo(GetFileName().GetPath());
+            fnLocalFile.MakeRelativeTo(GetDir());
 
             remoteFilePath = fnLocalFile.GetFullPath(wxPATH_UNIX);
             remoteFilePath.Prepend(remotePath + "/");
@@ -917,7 +926,7 @@ void clFileSystemWorkspace::FileSystemUpdated() { CacheFiles(true); }
 
 void clFileSystemWorkspace::OnDebug(clDebugEvent& event)
 {
-    if(!IsOpen()) {
+    if(!IsOpen() || (event.GetDebuggerName() != "GNU gdb debugger")) {
         event.Skip();
         return;
     }
@@ -968,9 +977,11 @@ void clFileSystemWorkspace::OnDebug(clDebugEvent& event)
 
     // Fire "starting" event
     clDebugEvent eventStarting(wxEVT_DEBUG_STARTING);
+    eventStarting.SetDebuggerName(GetConfig()->GetDebugger());
     eventStarting.SetClientData(&session_info);
-    if(EventNotifier::Get()->ProcessEvent(eventStarting))
+    if(EventNotifier::Get()->ProcessEvent(eventStarting)) {
         return;
+    }
 
     // Check if any plugins provided us with new breakpoints
     if(!eventStarting.GetBreakpoints().empty()) {
@@ -1007,7 +1018,7 @@ void clFileSystemWorkspace::GetExecutable(wxString& exe, wxString& args, wxStrin
 {
     exe = GetConfig()->GetExecutable();
     args = GetConfig()->GetArgs();
-    wd = GetConfig()->GetWorkingDirectory().IsEmpty() ? GetFileName().GetPath() : GetConfig()->GetWorkingDirectory();
+    wd = GetConfig()->GetWorkingDirectory().IsEmpty() ? GetDir() : GetConfig()->GetWorkingDirectory();
 
     // build the arguments
     args.Replace("\r", wxEmptyString);
@@ -1157,3 +1168,23 @@ void clFileSystemWorkspace::OnReloadWorkspace(clCommandEvent& event)
         OpenWorkspace(current_file);
     }
 }
+
+wxString clFileSystemWorkspace::GetDebuggerName() const
+{
+    if(GetConfig()) {
+        return GetConfig()->GetDebugger();
+    } else {
+        return wxEmptyString;
+    }
+}
+
+clEnvList_t clFileSystemWorkspace::GetEnvironment() const
+{
+    clEnvList_t env_list;
+    auto config = clFileSystemWorkspace::Get().GetSettings().GetSelectedConfig();
+    if(config) {
+        const wxString& envstr = config->GetEnvironment();
+        env_list = StringUtils::BuildEnvFromString(envstr);
+    }
+    return env_list;
+}
