@@ -13,8 +13,9 @@
 #include "macromanager.h"
 #include "procutils.h"
 
-#define DEFAULT_FILE_EXTENSIONS \
-    "*.cpp;*.c;*.txt;*.json;*.hpp;*.cc;*.cxx;*.xml;*.h;*.wxcp;*.py;*.php;*.rb;*.html;*.js;*.ts;*.rs"
+#define DEFAULT_FILE_EXTENSIONS                                                                                        \
+    "*.cpp;*.c;*.txt;*.json;*.hpp;*.cc;*.cxx;*.xml;*.h;*.wxcp;*.py;*.php;*.rb;*.html;*.js;*.ts;*.rs;*.iss;*.md;*.bat;" \
+    "*.sh;*.cmake"
 #define WORKSPACE_TYPE "File System Workspace"
 #define DEFAULT_EXCLUDE_FILE_PATTERN "*.o;*.pyc;*.obj;*.workspace;*.o.d;*.exe;*.dll;*.project"
 
@@ -170,9 +171,11 @@ static wxArrayString GetExtraFlags(CompilerPtr compiler)
 {
     wxArrayString flags;
     if(compiler->HasMetadata()) {
-        flags.Add("-target");
         auto md = compiler->GetMetadata();
-        flags.Add(md.GetTarget());
+        if(!md.GetTarget().IsEmpty()) {
+            flags.Add("-target");
+            flags.Add(md.GetTarget());
+        }
     }
     return flags;
 }
