@@ -1,6 +1,7 @@
+#include "clGotoAnythingManager.h"
+
 #include "GotoAnythingDlg.h"
 #include "bitmap_loader.h"
-#include "clGotoAnythingManager.h"
 #include "clKeyboardManager.h"
 #include "clWorkspaceManager.h"
 #include "cl_command_event.h"
@@ -9,11 +10,12 @@
 #include "file_logger.h"
 #include "globals.h"
 #include "imanager.h"
+
 #include <algorithm>
 #include <queue>
 #include <wx/menu.h>
-#include <wx/xrc/xmlres.h>
 #include <wx/stc/stc.h>
+#include <wx/xrc/xmlres.h>
 
 clGotoAnythingManager::clGotoAnythingManager()
 {
@@ -59,7 +61,13 @@ void clGotoAnythingManager::ShowDialog()
     evtSort.GetEntries().swap(evtShowing.GetEntries());
     EventNotifier::Get()->ProcessEvent(evtSort);
 
-    std::vector<clGotoEntry> entries = evtSort.GetEntries();
+#ifdef __WXMSW__
+    if(clGetManager()->GetActiveEditor()) {
+        clGetManager()->GetActiveEditor()->SetActive();
+    }
+#endif
+
+    const std::vector<clGotoEntry>& entries = evtSort.GetEntries();
     GotoAnythingDlg dlg(EventNotifier::Get()->TopFrame(), entries);
     dlg.ShowModal();
 }
@@ -82,10 +90,13 @@ void clGotoAnythingManager::Initialise()
     m_actions.clear();
 
     wxFrame* mainFrame = EventNotifier::Get()->TopFrame();
-    wxMenuBar* mb = mainFrame->GetMenuBar();
-    if(!mb) return;
+    auto mb = clGetManager()->GetMenuBar();
+    if(!mb) {
+        return;
+    }
+
     // Get list of menu entries
-    std::queue<std::pair<wxString, wxMenu*> > q;
+    std::queue<std::pair<wxString, wxMenu*>> q;
     for(size_t i = 0; i < mb->GetMenuCount(); ++i) {
         q.push(std::make_pair("", mb->GetMenu(i)));
     }
@@ -105,7 +116,9 @@ void clGotoAnythingManager::Initialise()
             wxMenuItem* menuItem = *iter;
             if(menuItem->GetSubMenu()) {
                 wxString labelText = menuItem->GetItemLabelText();
-                if((labelText == "Recent Files") || (labelText == "Recent Workspaces")) { continue; }
+                if((labelText == "Recent Files") || (labelText == "Recent Workspaces")) {
+                    continue;
+                }
                 q.push(std::make_pair(menuItem->GetItemLabelText() + " > ", menuItem->GetSubMenu()));
             } else if((menuItem->GetId() != wxNOT_FOUND) && (menuItem->GetId() != wxID_SEPARATOR)) {
                 clGotoEntry entry;
@@ -115,7 +128,9 @@ void clGotoAnythingManager::Initialise()
                     entry.SetFlags(clGotoEntry::kItemCheck);
                     entry.SetChecked(menuItem->IsChecked());
                 }
-                if(menuItem->GetAccel()) { entry.SetKeyboardShortcut(menuItem->GetAccel()->ToString()); }
+                if(menuItem->GetAccel()) {
+                    entry.SetKeyboardShortcut(menuItem->GetAccel()->ToString());
+                }
                 entry.SetResourceID(menuItem->GetId());
                 entry.SetBitmap(menuItem->GetBitmap().IsOk() ? menuItem->GetBitmap() : defaultBitmap);
                 if(!entry.GetDesc().IsEmpty()) {
