@@ -2,16 +2,18 @@
 #define CLSCROLLEDPANEL_H
 
 #include "clCustomScrollBar.h"
+#include "clScrollBar.h"
 #include "codelite_exports.h"
+#include "wxCustomControls.hpp"
+
 #include <wx/bitmap.h>
 #include <wx/dcgraph.h>
 #include <wx/dcmemory.h>
 #include <wx/panel.h>
 #include <wx/scrolbar.h>
 #include <wx/treebase.h>
-#include "clScrollBar.h"
 
-#if CL_USE_NATIVE_SCROLLBAR
+#if wxUSE_NATIVE_SCROLLBAR
 typedef clScrollBar ScrollBar_t;
 #else
 typedef clCustomScrollBar ScrollBar_t;
@@ -22,7 +24,7 @@ class WXDLLIMPEXP_SDK clScrolledPanel : public wxWindow
 private:
     ScrollBar_t* m_vsb = nullptr;
     ScrollBar_t* m_hsb = nullptr;
-    
+
     int m_pageSize = 0;
     int m_position = 0;
     int m_thumbSize = 0;
@@ -37,9 +39,9 @@ private:
     bool m_dragging = false;
     bool m_neverShowHScrollbar = false;
     bool m_neverShowVScrollbar = false;
-    
+
 protected:
-#if CL_USE_NATIVE_SCROLLBAR
+#if wxUSE_NATIVE_SCROLLBAR
     virtual void OnVScroll(wxScrollEvent& event);
     virtual void OnHScroll(wxScrollEvent& event);
 #else
@@ -77,7 +79,7 @@ public:
 
     ScrollBar_t* GetHScrollBar() { return m_hsb; }
     ScrollBar_t* GetVScrollBar() { return m_vsb; }
-    
+
     bool Create(wxWindow* parent, wxWindowID id = wxID_ANY, const wxPoint& pos = wxDefaultPosition,
                 const wxSize& size = wxDefaultSize, long style = 0);
     /**
@@ -159,7 +161,7 @@ public:
 
     // Process idle events. Override this in the subclass
     virtual void ProcessIdle() {}
-    
+
     /**
      * @brief should we show the scrollbar?
      */
