@@ -2,6 +2,7 @@
 #define CLTAB_H
 
 #include "codelite_exports.h"
+
 #include <vector>
 #include <wx/bitmap.h>
 #include <wx/filename.h>
@@ -11,16 +12,11 @@
 struct WXDLLIMPEXP_SDK clTab {
     typedef std::vector<clTab> Vec_t;
     wxString text;
-    wxWindow* window;
-    wxBitmap bitmap;
-    bool isFile;
+    wxWindow* window = nullptr;
+    int bitmap = wxNOT_FOUND;
+    bool isFile = false;
     wxFileName filename;
-    bool isModified;
-    clTab()
-        : window(NULL)
-        , isFile(false)
-        , isModified(false)
-    {
-    }
+    bool isModified = false;
+    clTab() {}
 };
 #endif // CLTAB_H
