@@ -4,9 +4,6 @@
 #include "Notebook.h"
 #include "clGenericNotebook.hpp"
 #include "clSystemSettings.h"
-#include "clTabRendererDefault.hpp"
-#include "clTabRendererFirefox.hpp"
-#include "clTabRendererGTK3.h"
 #include "clTabRendererMinimal.hpp"
 #include "cl_config.h"
 #include "cl_defs.h"
@@ -31,17 +28,7 @@ void GetTabColours(const clTabColours& colours, size_t style, wxColour* activeTa
 {
     *bgColour = colours.tabAreaColour;
     *activeTabBgColour = colours.activeTabBgColour;
-
-    bool is_dark = DrawingUtils::IsDark(colours.activeTabBgColour);
-    // If we are painting the active tab, check to see if the page is of type wxStyledTextCtrl
-    if(style & kNotebook_DynamicColours) {
-        auto editor = clGetManager()->GetActiveEditor();
-        if(editor) {
-            *activeTabBgColour = editor->GetCtrl()->StyleGetBackground(0);
-            is_dark = DrawingUtils::IsDark(*activeTabBgColour);
-        }
-        *bgColour = activeTabBgColour->ChangeLightness(is_dark ? 120 : 80);
-    }
+    wxUnusedVar(style);
 }
 int X_BUTTON_SIZE = 20;
 void SetBestXButtonSize(wxWindow* win) { wxUnusedVar(win); }
@@ -53,11 +40,28 @@ clTabColours::clTabColours() { UpdateColours(0); }
 void clTabColours::UpdateColours(size_t notebookStyle)
 {
     wxUnusedVar(notebookStyle);
+#ifdef __WXMAC__
+    wxColour base_colour = clSystemSettings::GetDefaultPanelColour();
+    bool is_dark = DrawingUtils::IsDark(base_colour);
+
+    tabAreaColour = base_colour.ChangeLightness(80);
+    activeTabBgColour = base_colour; //.ChangeLightness(120);
+    activeTabTextColour = clSystemSettings::GetColour(wxSYS_COLOUR_BTNTEXT);
+    activeTabPenColour = activeTabBgColour.ChangeLightness(is_dark ? 30 : 70);
+    activeTabInnerPenColour = activeTabPenColour;
+
+    // inactive tab colours
+    inactiveTabTextColour = activeTabTextColour.ChangeLightness(is_dark ? 85 : 115);
+    inactiveTabBgColour = tabAreaColour;
+    inactiveTabPenColour = tabAreaColour.ChangeLightness(90);
+    inactiveTabInnerPenColour = inactiveTabBgColour;
+    markerColour = clConfig::Get().Read("ActiveTabMarkerColour", wxColour("#dc7633"));
+#else
     wxColour base_colour = clSystemSettings::GetDefaultPanelColour();
     bool is_dark = DrawingUtils::IsDark(base_colour);
 
     tabAreaColour = base_colour.ChangeLightness(is_dark ? 60 : 90);
-    activeTabBgColour = base_colour;
+    activeTabBgColour = base_colour.ChangeLightness(is_dark ? 107 : 100);
     activeTabTextColour = clSystemSettings::GetColour(wxSYS_COLOUR_BTNTEXT);
     activeTabPenColour = base_colour;
     activeTabInnerPenColour = activeTabPenColour;
@@ -68,6 +72,7 @@ void clTabColours::UpdateColours(size_t notebookStyle)
     inactiveTabPenColour = tabAreaColour.ChangeLightness(90);
     inactiveTabInnerPenColour = inactiveTabBgColour;
     markerColour = clConfig::Get().Read("ActiveTabMarkerColour", wxColour("#dc7633"));
+#endif
 }
 
 bool clTabColours::IsDarkColours() const { return DrawingUtils::IsDark(activeTabBgColour); }
@@ -118,10 +123,10 @@ void clTabInfo::CalculateOffsets(size_t style, wxDC& dc)
     int X_spacer = m_tabCtrl ? m_tabCtrl->GetArt()->xSpacer : 10;
     bool using_bold_font = m_tabCtrl ? m_tabCtrl->GetArt()->IsUseBoldFont() : false;
 
+    wxDCFontChanger font_changer(dc);
     wxFont font = clTabRenderer::GetTabFont(using_bold_font);
     dc.SetFont(font);
 
-    bool bVerticalTabs = IS_VERTICAL_TABS(style);
     // On vertical tabs, use the short label
     wxSize sz = dc.GetTextExtent(GetBestLabel(style));
     wxSize fixedHeight = dc.GetTextExtent("Tp");
@@ -138,12 +143,13 @@ void clTabInfo::CalculateOffsets(size_t style, wxDC& dc)
     m_bmpX = wxNOT_FOUND;
     m_bmpY = wxNOT_FOUND;
 
-    if(HasBitmap() && !bVerticalTabs) {
-        const wxBitmap& bmp = m_tabCtrl->GetBitmaps()->Get(m_bitmap, false);
-        m_bmpX = m_width;
-        m_width += bmp.GetScaledWidth();
-        m_bmpY = ((m_height - bmp.GetScaledHeight()) / 2);
-        m_width += X_spacer;
+    // x button
+    wxRect xrect;
+    if((style & kNotebook_CloseButtonOnActiveTab)) {
+        xrect = wxRect(m_width, 0, X_BUTTON_SIZE, X_BUTTON_SIZE);
+        m_bmpCloseX = xrect.GetX();
+        m_bmpCloseY = 0; // we will fix this later
+        m_width += xrect.GetWidth() + m_tabCtrl->FromDIP(5);
     }
 
     // Text
@@ -153,20 +159,14 @@ void clTabInfo::CalculateOffsets(size_t style, wxDC& dc)
     m_textWidth = sz.x;
     m_width += X_spacer;
 
-    // x button
-    wxRect xrect;
-    if((style & kNotebook_CloseButtonOnActiveTab)) {
-        xrect = wxRect(m_width, 0, X_BUTTON_SIZE, X_BUTTON_SIZE);
-        m_bmpCloseX = xrect.GetX();
-        m_bmpCloseY = 0; // we will fix this later
-        m_width += xrect.GetWidth();
+    if(HasBitmap()) {
+        const wxBitmap& bmp = m_tabCtrl->GetBitmaps()->Get(m_bitmap, false);
+        m_bmpX = m_width;
+        m_width += bmp.GetScaledWidth();
+        m_bmpY = ((m_height - bmp.GetScaledHeight()) / 2);
         m_width += X_spacer;
     }
 
-    if((style & kNotebook_UnderlineActiveTab) && bVerticalTabs) {
-        m_width += 8;
-    }
-
     // Update the rect width
     m_rect.SetWidth(m_width);
     m_rect.SetHeight(m_height);
@@ -214,14 +214,7 @@ wxRect clTabInfo::GetCloseButtonRect() const
     return xRect.CenterIn(GetRect(), wxVERTICAL);
 }
 
-const wxString& clTabInfo::GetBestLabel(size_t style) const
-{
-    if((style & (kNotebook_RightTabs | kNotebook_LeftTabs)) && !m_shortLabel.empty()) {
-        return m_shortLabel;
-    } else {
-        return m_label;
-    }
-}
+const wxString& clTabInfo::GetBestLabel(size_t style) const { return m_label; }
 
 const wxBitmap& clTabInfo::GetBitmap(int index, bool disabled) const
 {
@@ -272,26 +265,7 @@ void clTabRenderer::ClearActiveTabExtraLine(clTabInfo::Ptr_t activeTab, wxDC& dc
 {
     wxPoint pt1, pt2;
     dc.SetPen(colours.activeTabPenColour);
-    if(style & kNotebook_LeftTabs) {
-        dc.SetPen(colours.activeTabBgColour);
-        pt1 = activeTab->GetRect().GetTopRight();
-        pt2 = activeTab->GetRect().GetBottomRight();
-        pt2.y -= 1;
-        DRAW_LINE(pt1, pt2);
-
-        pt1.x -= 1;
-        pt2.x -= 1;
-        DRAW_LINE(pt1, pt2);
-
-    } else if(style & kNotebook_RightTabs) {
-        // Right tabs
-        dc.SetPen(colours.activeTabBgColour);
-        pt1 = activeTab->GetRect().GetTopLeft();
-        pt2 = activeTab->GetRect().GetBottomLeft();
-        pt2.y -= 1;
-        DRAW_LINE(pt1, pt2);
-
-    } else if(style & kNotebook_BottomTabs) {
+    if(style & kNotebook_BottomTabs) {
         // bottom tabs
         dc.SetPen(colours.activeTabBgColour);
         pt1 = activeTab->GetRect().GetTopLeft();
@@ -326,8 +300,20 @@ void clTabRenderer::DrawButton(wxWindow* win, wxDC& dc, const clTabInfo& tabInfo
     wxRect buttonRect = wxRect(tabInfo.m_bmpCloseX + tabInfo.GetRect().GetX(),
                                tabInfo.m_bmpCloseY + tabInfo.GetRect().GetY(), X_BUTTON_SIZE, X_BUTTON_SIZE);
     buttonRect = buttonRect.CenterIn(tabInfo.GetRect(), wxVERTICAL);
-    DrawingUtils::DrawButtonX(dc, win, buttonRect, colours.activeTabTextColour,
-                              tabInfo.IsActive() ? colours.activeTabBgColour : colours.inactiveTabBgColour, state);
+
+    wxColour text_colour = colours.activeTabTextColour;
+    wxString unicode_symbol = wxT("\u2715");
+    if(tabInfo.IsModified()) {
+        // instead of drawing the standard X we draw
+        // a round circele marked in RED indicating that this
+        // tab is modified
+        text_colour = colours.markerColour;
+        unicode_symbol = wxT("\u25CF");
+    }
+
+    DrawingUtils::DrawButtonX(dc, win, buttonRect, text_colour,
+                              tabInfo.IsActive() ? colours.activeTabBgColour : colours.inactiveTabBgColour, state,
+                              unicode_symbol);
 }
 
 void clTabRenderer::DrawChevron(wxWindow* win, wxDC& dc, const wxRect& rect, const clTabColours& colours)
@@ -354,37 +340,17 @@ int clTabRenderer::GetDefaultBitmapHeight(int Y_spacer)
 clTabRenderer::Ptr_t clTabRenderer::CreateRenderer(const wxWindow* win, size_t tabStyle)
 {
     if(ms_Renderes.empty()) {
-        RegisterRenderer(new clTabRendererDefault(win));
-        RegisterRenderer(new clTabRendererGTK3(win));
         RegisterRenderer(new clTabRendererMinimal(win));
-        RegisterRenderer(new clTabRendererFirefox(win));
     }
-
-    wxString tab = clConfig::Get().Read("TabStyle", wxString("MINIMAL"));
-    wxString name = tab.Upper();
-
     clTabRenderer::Ptr_t renderer;
-    bool is_vertical = (tabStyle & kNotebook_LeftTabs) || (tabStyle & kNotebook_RightTabs);
-    renderer.reset(Create(win, name));
-
-    if(!renderer) {
-        renderer = Create(win, "GTK3");
-    } else {
-        // make sure the selected renderer supports vertical tabbing
-        if(is_vertical && !renderer->IsVerticalTabSupported()) {
-            renderer.reset(Create(win, "DEFAULT"));
-        }
-    }
+    renderer = Create(win, "MINIMAL");
     return renderer;
 }
 
 wxArrayString clTabRenderer::GetRenderers()
 {
     if(ms_Renderes.empty()) {
-        RegisterRenderer(new clTabRendererDefault(nullptr));
-        RegisterRenderer(new clTabRendererGTK3(nullptr));
         RegisterRenderer(new clTabRendererMinimal(nullptr));
-        RegisterRenderer(new clTabRendererFirefox(nullptr));
     }
 
     wxArrayString renderers;
@@ -422,19 +388,11 @@ wxColour clTabRenderer::DrawBackground(wxWindow* parent, wxDC& dc, const wxRect&
 
 #ifndef __WXOSX__
     bool isBottom = style & kNotebook_BottomTabs;
-    bool isLeft = style & kNotebook_LeftTabs;
-    bool isRight = style & kNotebook_RightTabs;
 
     wxPoint p1, p2;
     if(isBottom) {
         p1 = clientRect.GetTopLeft();
         p2 = clientRect.GetTopRight();
-    } else if(isLeft) {
-        p1 = clientRect.GetTopRight();
-        p2 = clientRect.GetBottomRight();
-    } else if(isRight) {
-        p1 = clientRect.GetTopLeft();
-        p2 = clientRect.GetBottomLeft();
     } else {
         p1 = clientRect.GetBottomLeft();
         p2 = clientRect.GetBottomRight();
@@ -451,17 +409,15 @@ void clTabRenderer::FinaliseBackground(wxWindow* parent, wxDC& dc, const wxRect&
     wxUnusedVar(parent);
     wxUnusedVar(activeTabRect);
 
-    if(!IS_VERTICAL_TABS(style) && ((style & kNotebook_BottomTabs) == 0)) {
-        // top tabs
-        wxColour bg_colour;
-        wxColour active_tab_colour;
-        GetTabColours(colours, style, &active_tab_colour, &bg_colour);
-        bool is_dark = DrawingUtils::IsDark(bg_colour);
-        dc.SetPen(bg_colour.ChangeLightness(is_dark ? 60 : 80));
-        dc.DrawLine(clientRect.GetTopRight(), clientRect.GetTopLeft());
-        dc.DrawLine(clientRect.GetTopLeft(), clientRect.GetBottomLeft());
-        dc.DrawLine(clientRect.GetTopRight(), clientRect.GetBottomRight());
-    }
+    // top tabs
+    wxColour bg_colour;
+    wxColour active_tab_colour;
+    GetTabColours(colours, style, &active_tab_colour, &bg_colour);
+    bool is_dark = DrawingUtils::IsDark(bg_colour);
+    dc.SetPen(bg_colour.ChangeLightness(is_dark ? 60 : 80));
+    //dc.DrawLine(clientRect.GetTopRight(), clientRect.GetTopLeft());
+    //dc.DrawLine(clientRect.GetTopLeft(), clientRect.GetBottomLeft());
+    //dc.DrawLine(clientRect.GetTopRight(), clientRect.GetBottomRight());
 }
 
 void clTabRenderer::AdjustColours(clTabColours& colours, size_t style)
@@ -477,7 +433,11 @@ void clTabRenderer::DrawMarker(wxDC& dc, const clTabInfo& tabInfo, const clTabCo
     }
 
     bool is_dark = DrawingUtils::IsDark(colours.tabAreaColour);
+#ifdef __WXMAC__
+    wxColour marker_colour = wxSystemSettings::GetColour(wxSYS_COLOUR_HIGHLIGHT);
+#else
     wxColour marker_colour = colours.tabAreaColour.ChangeLightness(is_dark ? 130 : 70);
+#endif
     wxPen markerPen(marker_colour);
 
     // Draw marker line if needed
@@ -485,18 +445,7 @@ void clTabRenderer::DrawMarker(wxDC& dc, const clTabInfo& tabInfo, const clTabCo
     bool isGTK3 = true;
     wxDirection direction;
     wxPoint p1, p2;
-    if((style & kNotebook_LeftTabs)) {
-        p1 = tabInfo.GetRect().GetTopRight();
-        p2 = tabInfo.GetRect().GetBottomRight();
-        dc.SetPen(markerPen);
-        DrawMarkerLine(dc, p1, p2, wxLEFT);
-    } else if(style & kNotebook_RightTabs) {
-        // Right tabs
-        p1 = tabInfo.GetRect().GetTopLeft();
-        p2 = tabInfo.GetRect().GetBottomLeft();
-        dc.SetPen(markerPen);
-        DrawMarkerLine(dc, p1, p2, wxRIGHT);
-    } else if(style & kNotebook_BottomTabs) {
+    if(style & kNotebook_BottomTabs) {
         // Bottom tabs
         if(isGTK3) {
             direction = wxDOWN;
