@@ -14,14 +14,14 @@
 #include <wx/settings.h>
 
 #ifdef __WXMSW__
-#define TREE_STYLE wxTR_ENABLE_SEARCH | wxBORDER_DEFAULT | wxTR_MULTIPLE
+#define TREE_STYLE wxTR_ENABLE_SEARCH | wxBORDER_DEFAULT | wxTR_MULTIPLE | wxTR_ROW_LINES
 #else
-#define TREE_STYLE wxTR_ENABLE_SEARCH | wxBORDER_DEFAULT | wxTR_MULTIPLE
+#define TREE_STYLE wxTR_ENABLE_SEARCH | wxBORDER_DEFAULT | wxTR_MULTIPLE | wxTR_ROW_LINES
 #endif
 
 clThemedTreeCtrl::clThemedTreeCtrl(wxWindow* parent, wxWindowID id, const wxPoint& pos, const wxSize& size, long style)
 {
-    Create(parent, id, pos, size, style & ~wxTR_ROW_LINES);
+    Create(parent, id, pos, size, style);
 }
 
 bool clThemedTreeCtrl::Create(wxWindow* parent, wxWindowID id, const wxPoint& pos, const wxSize& size, long style)
@@ -49,4 +49,8 @@ void clThemedTreeCtrl::OnThemeChanged(wxCommandEvent& event)
     ApplyTheme();
 }
 
-void clThemedTreeCtrl::ApplyTheme() { cl::ApplyTheme<clThemedTreeCtrl>(this); }
+void clThemedTreeCtrl::ApplyTheme()
+{
+    cl::ApplyTheme<clThemedTreeCtrl>(this);
+    ::MSWSetWindowDarkTheme(this);
+}
