@@ -1,6 +1,7 @@
 #include "clToolBarMenuButton.h"
 
-clToolBarMenuButton::clToolBarMenuButton(clToolBar* parent, wxWindowID winid, size_t bmpId, const wxString& label)
+clToolBarMenuButton::clToolBarMenuButton(clToolBarGeneric* parent, wxWindowID winid, size_t bmpId,
+                                         const wxString& label)
     : clToolBarButtonBase(parent, winid, bmpId, label, kHasMenu)
 {
 }
@@ -31,8 +32,6 @@ wxSize clToolBarMenuButton::CalculateSize(wxDC& dc) const
         sz.y = wxMax(sz.GetHeight(), height);
     }
 
-    sz.x += m_toolbar->GetXSpacer();
-    sz.x += CL_TOOL_BAR_DROPDOWN_ARROW_SIZE;
-    sz.x += m_toolbar->GetXSpacer();
+    sz.x += sz.GetHeight(); // the button width is the as the height of the button
     return sz;
 }
