@@ -6,7 +6,7 @@
 class WXDLLIMPEXP_SDK clToolBarSeparator : public clToolBarButtonBase
 {
 public:
-    clToolBarSeparator(clToolBar* parent);
+    clToolBarSeparator(clToolBarGeneric* parent);
     virtual ~clToolBarSeparator();
 
     void Render(wxDC& dc, const wxRect& rect);
@@ -14,5 +14,4 @@ public:
 public:
     virtual wxSize CalculateSize(wxDC& dc) const;
 };
-
 #endif // CLTOOLBARSEPARATOR_H
