@@ -1,16 +1,16 @@
 #ifndef CLTOOLBARSTRETCHABLESPACE_H
 #define CLTOOLBARSTRETCHABLESPACE_H
 
+#include "clToolBar.h"
 #include "clToolBarButtonBase.h"
 #include "codelite_exports.h"
 
-class clToolBar;
 class WXDLLIMPEXP_SDK clToolBarStretchableSpace : public clToolBarButtonBase
 {
     size_t m_width = 0;
 
 public:
-    clToolBarStretchableSpace(clToolBar* parent);
+    clToolBarStretchableSpace(clToolBarGeneric* parent);
     virtual ~clToolBarStretchableSpace();
 
     virtual wxSize CalculateSize(wxDC& dc) const;
@@ -19,5 +19,4 @@ public:
     void SetWidth(size_t width) { this->m_width = width; }
     size_t GetWidth() const { return m_width; }
 };
-
 #endif // CLTOOLBARSTRETCHABLESPACE_H
