@@ -1,6 +1,7 @@
 #include "clToolBarToggleButton.h"
 
-clToolBarToggleButton::clToolBarToggleButton(clToolBar* parent, wxWindowID id, size_t bitmapId, const wxString& label)
+clToolBarToggleButton::clToolBarToggleButton(clToolBarGeneric* parent, wxWindowID id, size_t bitmapId,
+                                             const wxString& label)
     : clToolBarButton(parent, id, bitmapId, label)
 {
     m_flags = kToggleButton;
