@@ -10,9 +10,13 @@ void clTreeNodeVisitor::Visit(clRowEntry* item, bool expandedItemsOnly, std::fun
     while(current) {
         bool isVisible = current->IsVisible();
         if(expandedItemsOnly && isVisible) {
-            if(!func(current, isVisible)) { return; }
+            if(!func(current, isVisible)) {
+                return;
+            }
         } else if(!expandedItemsOnly) {
-            if(!func(current, isVisible)) { return; }
+            if(!func(current, isVisible)) {
+                return;
+            }
         }
         current = current->GetNext();
     }
