@@ -25,12 +25,14 @@
 #ifndef GLOBALS_H
 #define GLOBALS_H
 
-#include "clThemedMenuBar.hpp"
 #include "codelite_exports.h"
+#include "fileextmanager.h"
 #include "macros.h"
 #include "window_locker.h"
 #include "workspace.h"
 
+#include <unordered_map>
+#include <vector>
 #include <wx/arrstr.h>
 #include <wx/bitmap.h>
 #include <wx/brush.h>
@@ -293,7 +295,7 @@ WXDLLIMPEXP_SDK void GetProjectTemplateList(std::list<ProjectPtr>& list);
  * @brief set the native Windows theme for the application
  * @param win [input]
  */
-WXDLLIMPEXP_SDK void MSWSetNativeTheme(wxWindow* win, const wxString& theme = wxT("Explorer"));
+WXDLLIMPEXP_SDK void MSWSetNativeTheme(wxWindow* win, const wxString& theme = "Explorer");
 
 /**
  * @brief under Windows 10 and later, enable dark mode controls (where it is implemented)
@@ -313,12 +315,7 @@ WXDLLIMPEXP_SDK bool MakeRelativeIfSensible(wxFileName& fn, const wxString& refe
  * @brief joins array element into a string using 'glue' as the array elements
  * separator
  */
-WXDLLIMPEXP_SDK wxString wxImplode(const wxArrayString& arr, const wxString& glue = wxT("\n"));
-
-/**
- * @brief executes a command under the proper shell and return string as the output
- */
-WXDLLIMPEXP_SDK wxString wxShellExec(const wxString& cmd, const wxString& projectName);
+WXDLLIMPEXP_SDK wxString wxImplode(const wxArrayString& arr, const wxString& glue = "\n");
 
 /**
  * @class StringManager
@@ -488,6 +485,11 @@ WXDLLIMPEXP_SDK wxString GetCppExpressionFromPos(long pos, wxStyledTextCtrl* ctr
  */
 WXDLLIMPEXP_SDK bool SaveXmlToFile(wxXmlDocument* doc, const wxString& filename);
 
+/**
+ * @brief an efficient way to load XML from file
+ */
+WXDLLIMPEXP_SDK bool LoadXmlFile(wxXmlDocument* doc, const wxString& filepath);
+
 /**
  * @brief return true if running under Cygwin environment
  * This function returns false under Linux/OSX and under Windows it checks the
@@ -525,16 +527,16 @@ WXDLLIMPEXP_SDK wxString clGetTextFromUser(const wxString& title, const wxString
 /**
  * @brief similar to wxDirSelector, but on a remote machine
  */
-WXDLLIMPEXP_SDK pair<wxString, wxString>
+WXDLLIMPEXP_SDK std::pair<wxString, wxString>
 clRemoteFolderSelector(const wxString& title, const wxString& accountName = wxEmptyString, wxWindow* parent = NULL);
 
 /**
  * @brief similar to wxFileSelector, but on a remote machine
  */
-WXDLLIMPEXP_SDK pair<wxString, wxString> clRemoteFileSelector(const wxString& title,
-                                                              const wxString& accountName = wxEmptyString,
-                                                              const wxString& filter = wxEmptyString,
-                                                              wxWindow* parent = NULL);
+WXDLLIMPEXP_SDK std::pair<wxString, wxString> clRemoteFileSelector(const wxString& title,
+                                                                   const wxString& accountName = wxEmptyString,
+                                                                   const wxString& filter = wxEmptyString,
+                                                                   wxWindow* parent = NULL);
 /**
  * @brief return the instance to the plugin manager. A convinience method
  */
@@ -664,4 +666,9 @@ WXDLLIMPEXP_SDK bool clIsCxxWorkspaceOpened();
  */
 WXDLLIMPEXP_SDK bool clIsWaylandSession();
 
+/**
+ * @brief get list of file types from the user
+ */
+WXDLLIMPEXP_SDK bool clShowFileTypeSelectionDialog(wxWindow* parent, const wxArrayString& initial_selection,
+                                                   wxArrayString* selected);
 #endif // GLOBALS_H
