@@ -27,6 +27,7 @@
 
 #include "globals.h"
 #include "ieditor.h"
+#include "macromanager.h"
 
 #include <wx/app.h>
 #include <wx/clipbrd.h>
@@ -102,6 +103,7 @@ void MacrosDlg::Initialize()
         AddMacro("`expression`", _("backticks: evaluates the expression inside the backticks into a string"));
         AddMacro("$(OutputDirectory)", _("The directory part of $(OutputFile)"));
         AddMacro("$(OutputFile)", _("The output file"));
+        AddMacro("$(Program)", _("The program to run"));
         break;
 
     case MacrosCompiler:
@@ -131,7 +133,7 @@ void MacrosDlg::Initialize()
         AddMacro("$(PreprocessorSwitch)", _("Preprocessor switch (e.g. -D)"));
         AddMacro("$(Preprocessors)", _("Expands to all preprocessors set in the project setting where each entry "
                                        "is prefixed with $(PreprocessorSwitch)"));
-        AddMacro("$(ArchiveOutputSwitch)", _("Archive switch, usually not needed (VC compiler sets it to /OUT:"));
+        AddMacro("$(ArchiveOutputSwitch)", _("Archive switch, usually not needed (VC compiler sets it to /OUT:)"));
         AddMacro("$(PreprocessOnlySwitch)", _("The compiler preprocess-only switch (e.g. -E)"));
         AddMacro("$(LinkOptions)", _("The linker options as set in the project settings"));
         AddMacro("$(IncludePath)", _("All include paths prefixed with $(IncludeSwitch)"));
@@ -164,11 +166,8 @@ void MacrosDlg::AddMacro(const wxString& name, const wxString& desc)
 
     // Only fill third column if we can and may expand the macros
     if(m_project && m_editor && name != "$(ProjectFiles)" && name != "$(ProjectFilesAbs)") {
-        wxString value = ExpandVariables(name, m_project, m_editor);
+        wxString value = MacroManager::Instance()->Expand(name, clGetManager(), m_project->GetName());
         SetColumnText(m_listCtrlMacros, row, 2, value);
-
-    } else {
-        // No third column here... don't fill it or we get an assertion
     }
 }
 
@@ -178,17 +177,7 @@ void MacrosDlg::OnCopy(wxCommandEvent& e)
 {
     if(m_item != wxNOT_FOUND) {
         wxString value = GetColumnText(m_listCtrlMacros, m_item, 0);
-#if wxUSE_CLIPBOARD
-        if(wxTheClipboard->Open()) {
-            wxTheClipboard->UsePrimarySelection(false);
-            if(!wxTheClipboard->SetData(new wxTextDataObject(value))) {
-                // wxPrintf("Failed to insert data %s to clipboard", textToCopy.GetData());
-            }
-            wxTheClipboard->Close();
-        } else {
-            wxPrintf("Failed to open the clipboard");
-        }
-#endif
+        ::CopyToClipboard(value);
     }
     m_item = wxNOT_FOUND;
 }
