@@ -68,7 +68,7 @@ documentation and/or software.
 #include <fstream>
 #include <iostream>
 #include <stdio.h>
-using namespace std;
+
 class MD5
 {
 
@@ -76,22 +76,22 @@ public:
     // methods for controlled operation:
     MD5(); // simple initializer
     void update(unsigned char* input, unsigned int input_length);
-    void update(istream& stream);
+    void update(std::istream& stream);
     void update(FILE* file);
-    void update(ifstream& stream);
+    void update(std::ifstream& stream);
     void finalize();
 
     // constructors for special circumstances.  All these constructors finalize
     // the MD5 context.
     MD5(unsigned char* string); // digest string, finalize
-    MD5(istream& stream);       // digest stream, finalize
+    MD5(std::istream& stream);  // digest stream, finalize
     MD5(FILE* file);            // digest file, close, finalize
-    MD5(ifstream& stream);      // digest stream, close, finalize
+    MD5(std::ifstream& stream); // digest stream, close, finalize
 
     // methods to acquire finalized result
     // unsigned char    *raw_digest ();  // digest as a 16-byte binary array
     const char* hex_digest(); // digest as a 33-byte ascii-hex string
-    friend ostream& operator<<(ostream&, MD5 context);
+    friend std::ostream& operator<<(std::ostream&, MD5 context);
 
 private:
     // first, some types:
