@@ -25,6 +25,8 @@
 #ifndef SESSIONMANAGER_H
 #define SESSIONMANAGER_H
 
+#include "clFilesCollector.h"
+#include "codelite_events.h"
 #include "codelite_exports.h"
 #include "debugger.h"
 #include "serialized_object.h"
@@ -101,13 +103,53 @@ public:
     const wxString& GetTabgroupName() const { return m_tabgroupName; }
 };
 
+enum {
+    wxFRD_MATCHCASE = (1 << 0),
+    wxFRD_MATCHWHOLEWORD = (1 << 1),
+    wxFRD_REGULAREXPRESSION = (1 << 2),
+    wxFRD_SEARCHUP = (1 << 3),
+    wxFRD_WRAPSEARCH = (1 << 4),
+    wxFRD_SELECTIONONLY = (1 << 5),
+    wxFRD_DISPLAYSCOPE = (1 << 6),
+    wxFRD_SAVE_BEFORE_SEARCH = (1 << 7),
+    wxFRD_SKIP_COMMENTS = (1 << 8),
+    wxFRD_SKIP_STRINGS = (1 << 9),
+    wxFRD_COLOUR_COMMENTS = (1 << 10),
+    wxFRD_SEPARATETAB_DISPLAY = (1 << 11),
+    wxFRD_ENABLE_PIPE_SUPPORT = (1 << 12),
+};
+
+struct WXDLLIMPEXP_SDK FindInFilesSession {
+    wxArrayString find_what_array;
+    wxString find_what;
+
+    wxArrayString replace_with_array;
+    wxString replace_with;
+
+    wxArrayString files_array;
+    wxString files = "*.cpp;*.cc;*.c;*.hpp;*.h;CMakeLists.txt;*.plist;*.rc";
+
+    wxArrayString where_array;
+    wxString where = "<Workspace Folder>";
+
+    wxString encoding = "ISO-8859-1";
+    size_t flags = wxFRD_MATCHCASE | wxFRD_MATCHWHOLEWORD | wxFRD_ENABLE_PIPE_SUPPORT;
+    size_t files_scanner_flags = clFilesScanner::SF_EXCLUDE_HIDDEN_DIRS;
+
+    /// construct from a json file
+    bool From(const wxString& content);
+
+    /// save to file
+    wxString Save() const;
+};
+
 /**
- * \class SessionManager
- * \brief
- * \author Eran
- * \date 09/25/07
+ * @class SessionManager
+ * @brief
+ * @author Eran
+ * @date 09/25/07
  */
-class WXDLLIMPEXP_SDK SessionManager
+class WXDLLIMPEXP_SDK SessionManager : public wxEvtHandler
 {
     wxXmlDocument m_doc;
     wxFileName m_fileName;
@@ -116,6 +158,9 @@ private:
     SessionManager();
     ~SessionManager();
 
+    void OnWorkspaceLoaded(clWorkspaceEvent& event);
+    void OnWorkspaceClosed(clWorkspaceEvent& event);
+
 public:
     static SessionManager& Get();
     bool Load(const wxString& fileName);
@@ -125,8 +170,10 @@ public:
                     const wxChar* Tag = sessionTag);
     void SetLastSession(const wxString& name);
     wxString GetLastSession();
-    void UpdateFindInFilesMaskForCurrentWorkspace(const wxString& mask);
-    wxString GetFindInFilesMaskForCurrentWorkspace();
+
+    // find in files related information
+    void SaveFindInFilesSession(const FindInFilesSession& session);
+    bool LoadFindInFilesSession(FindInFilesSession* session);
 
 private:
     wxFileName GetSessionFileName(const wxString& name, const wxString& suffix = wxT("")) const;
