@@ -1,4 +1,4 @@
-#include "MainFrame.h"
+#include "MainFrame.hpp"
 #include <wx/aboutdlg.h>
 
 MainFrame::MainFrame(wxWindow* parent)
@@ -10,12 +10,6 @@ MainFrame::~MainFrame()
 {
 }
 
-void MainFrame::OnExit(wxCommandEvent& event)
-{
-    wxUnusedVar(event);
-    Close();
-}
-
 void MainFrame::OnAbout(wxCommandEvent& event)
 {
     wxUnusedVar(event);
@@ -25,3 +19,9 @@ void MainFrame::OnAbout(wxCommandEvent& event)
     info.SetDescription(_("Short description goes here"));
     ::wxAboutBox(info);
 }
+
+void MainFrame::OnExit(wxCommandEvent& event)
+{
+    wxUnusedVar(event);
+    Close();
+}
