@@ -1,4 +1,5 @@
 #include "NodeDebugger.h"
+
 #include "NodeFileManager.h"
 #include "NodeJSDebuggerDlg.h"
 #include "NodeJSEvents.h"
@@ -15,9 +16,10 @@
 #include "imanager.h"
 #include "macros.h"
 #include "processreaderthread.h"
+
 #include <wx/msgdlg.h>
 
-#define NODE_CLI_DEBUGGER_NAME "Node.js - CLI"
+wxString NodeDebugger::NODE_CLI_DEBUGGER_NAME = "Node.js - CLI";
 
 #define CHECK_RUNNING() \
     if(!IsRunning()) {  \
@@ -222,7 +224,7 @@ void NodeDebugger::OnProcessTerminated(clProcessEvent& event)
 
 void NodeDebugger::OnProcessOutput(clProcessEvent& event)
 {
-    clDEBUG1() << event.GetOutput();
+    LOG_IF_TRACE { clDEBUG1() << event.GetOutput(); }
     {
         clDebugEvent e(wxEVT_NODEJS_DEBUGGER_UPDATE_CONSOLE);
         e.SetString(event.GetOutput());
@@ -262,18 +264,6 @@ void NodeDebugger::OnProcessOutput(clProcessEvent& event)
 void NodeDebugger::StartDebugger(const wxString& command, const wxString& command_args,
                                  const wxString& workingDirectory)
 {
-#if 0
-    if(::wxMessageBox(_("The old debugger protocol is not supported by your current Node.js version.\nWould you "
-                        "CodeLite to a CLI debug session for you in a terminal?"),
-                      _("CodeLite"), wxICON_QUESTION | wxYES_NO | wxCANCEL | wxYES_DEFAULT,
-                      EventNotifier::Get()->TopFrame()) == wxYES) {
-        clConsoleBase::Ptr_t console = clConsoleBase::GetTerminal();
-        console->SetWorkingDirectory(workingDirectory);
-        console->SetCommand(command, command_args);
-        console->SetTerminalNeeded(true);
-        console->Start();
-    }
-#else
     if(m_socket.IsConnected()) {
         clDEBUG() << "An instance of the debugger is already running";
         return;
@@ -300,9 +290,9 @@ void NodeDebugger::StartDebugger(const wxString& command, const wxString& comman
     if(one_liner.Contains("inspect")) {
         // Fire CodeLite IDE event indicating that a debug session started
         clDebugEvent cl_event(wxEVT_DEBUG_STARTED);
+        cl_event.SetDebuggerName(NODE_CLI_DEBUGGER_NAME);
         EventNotifier::Get()->AddPendingEvent(cl_event);
     }
-#endif
 }
 
 bool NodeDebugger::IsCanInteract() const { return m_process && m_canInteract; }
