@@ -1,13 +1,12 @@
-#include "WebToolsConfig.h"
 #include "JSON.h"
 #include "NodeJSLocator.h"
-#include <set>
+#include "WebToolsConfig.h"
 #include <algorithm>
+#include <set>
 #include <vector>
 
 WebToolsConfig::WebToolsConfig()
     : clConfigItem("WebTools")
-    , m_jsFlags(kJSEnableCC | kJSLibraryBrowser | kJSLibraryEcma5 | kJSLibraryEcma6 | kJSPluginNode | kJSNodeExpress)
     , m_xmlFlags(kXmlEnableCC)
     , m_htmlFlags(kHtmlEnableCC)
     , m_nodeOptions(0)
@@ -32,7 +31,6 @@ WebToolsConfig& WebToolsConfig::SaveConfig()
 
 void WebToolsConfig::FromJSON(const JSONItem& json)
 {
-    m_jsFlags = json.namedObject("m_jsFlags").toSize_t(m_jsFlags);
     m_xmlFlags = json.namedObject("m_xmlFlags").toSize_t(m_xmlFlags);
     m_htmlFlags = json.namedObject("m_htmlFlags").toSize_t(m_htmlFlags);
     m_nodeOptions = json.namedObject("m_nodeOptions").toSize_t(m_nodeOptions);
@@ -40,16 +38,19 @@ void WebToolsConfig::FromJSON(const JSONItem& json)
 
     wxString v;
     v = json.namedObject("m_nodejs").toString(v);
-    if(!v.IsEmpty() && wxFileName::FileExists(v)) { m_nodejs = v; }
+    if(!v.IsEmpty() && wxFileName::FileExists(v)) {
+        m_nodejs = v;
+    }
     v.clear();
     v = json.namedObject("m_npm").toString(v);
-    if(!v.IsEmpty() && wxFileName::FileExists(v)) { m_npm = v; }
+    if(!v.IsEmpty() && wxFileName::FileExists(v)) {
+        m_npm = v;
+    }
 }
 
 JSONItem WebToolsConfig::ToJSON() const
 {
     JSONItem element = JSONItem::createObject(GetName());
-    element.addProperty("m_jsFlags", m_jsFlags);
     element.addProperty("m_xmlFlags", m_xmlFlags);
     element.addProperty("m_htmlFlags", m_htmlFlags);
     element.addProperty("m_nodejs", m_nodejs);
@@ -64,14 +65,6 @@ wxString WebToolsConfig::GetTernProjectFile() const
     JSONItem libs = JSONItem::createArray("libs");
     root.toElement().append(libs);
 
-    if(m_jsFlags & kJSLibraryBrowser) libs.arrayAppend("browser");
-    if(m_jsFlags & kJSLibraryChai) libs.arrayAppend("chai");
-    if(m_jsFlags & kJSLibraryEcma5) libs.arrayAppend("ecma5");
-    if(m_jsFlags & kJSLibraryEcma6) libs.arrayAppend("ecma6");
-    if(m_jsFlags & kJSLibraryJQuery) libs.arrayAppend("jquery");
-    if(m_jsFlags & kJSLibraryUnderscore) libs.arrayAppend("underscore");
-    if(m_jsFlags & kJSPluginQML) libs.arrayAppend("qml");
-
     JSONItem plugins = JSONItem::createObject("plugins");
     root.toElement().append(plugins);
 
@@ -81,25 +74,6 @@ wxString WebToolsConfig::GetTernProjectFile() const
     pluginsToLoad.push_back("commonjs");
     pluginsToLoad.push_back("modules");
 
-    if(m_jsFlags & kJSPluginNode) {
-        pluginsToLoad.push_back("node_resolve");
-        pluginsToLoad.push_back("node");
-    }
-
-    if(m_jsFlags & kJSPluginRequireJS) { pluginsToLoad.push_back("requirejs"); }
-
-    if(m_jsFlags & kJSPluginStrings) { pluginsToLoad.push_back("complete_strings"); }
-
-    if(m_jsFlags & kJSPluginAngular) { pluginsToLoad.push_back("angular"); }
-
-    if(m_jsFlags & kJSWebPack) { pluginsToLoad.push_back("webpack"); }
-
-    if(m_jsFlags & kJSNodeExpress) {
-        pluginsToLoad.push_back("node_resolve");
-        pluginsToLoad.push_back("node");
-        pluginsToLoad.push_back("node-express");
-    }
-
     std::set<wxString> uniquePlugins;
     std::for_each(pluginsToLoad.begin(), pluginsToLoad.end(), [&](const wxString& name) {
         if(uniquePlugins.count(name) == 0) {
@@ -144,6 +118,8 @@ wxString WebToolsConfig::GetTempFolder(bool create) const
 {
     wxFileName fn(clStandardPaths::Get().GetUserDataDir(), "");
     fn.AppendDir("webtools");
-    if(create) { fn.Mkdir(wxS_DIR_DEFAULT, wxPATH_MKDIR_FULL); }
+    if(create) {
+        fn.Mkdir(wxS_DIR_DEFAULT, wxPATH_MKDIR_FULL);
+    }
     return fn.GetPath();
 }
