@@ -5,11 +5,10 @@
 #include "LSP/basic_types.h"
 #include "SimpleTokenizer.hpp"
 #include "entry.h"
+
 #include <unordered_set>
 #include <vector>
 
-using namespace std;
-
 enum eTokenType {
     TYPE_VARIABLE,
     TYPE_CLASS,
@@ -25,18 +24,19 @@ class LSPUtils
 {
 private:
     static void to_symbol_information(const TagEntry* tag, LSP::SymbolInformation& symbol_information,
-                                      unordered_set<wxString>* parents_seen = nullptr);
+                                      std::unordered_set<wxString>* parents_seen = nullptr);
 
 public:
     LSPUtils();
     ~LSPUtils();
 
-    static void encode_semantic_tokens(const vector<TokenWrapper>& tokens_vec, vector<int>* encoded_arr);
+    static void encode_semantic_tokens(const std::vector<TokenWrapper>& tokens_vec, std::vector<int>* encoded_arr);
     static LSP::eSymbolKind get_symbol_kind(const TagEntry* tag);
     static LSP::CompletionItem::eCompletionItemKind get_completion_kind(const TagEntry* tag);
-    static vector<LSP::SymbolInformation> to_symbol_information_array(const vector<TagEntryPtr>& tags,
-                                                                      bool for_tree_view);
-    static vector<LSP::SymbolInformation> to_symbol_information_array(const vector<TagEntry>& tags, bool for_tree_view);
+    static std::vector<LSP::SymbolInformation> to_symbol_information_array(const std::vector<TagEntryPtr>& tags,
+                                                                           bool for_tree_view);
+    static std::vector<LSP::SymbolInformation> to_symbol_information_array(const std::vector<TagEntry>& tags,
+                                                                           bool for_tree_view);
 };
 
 #endif // LSPUTILS_HPP
