@@ -9,15 +9,14 @@
 #include <wx/filename.h>
 #include <wx/string.h>
 
-using namespace std;
 class Scanner
 {
     wxStringSet_t m_missing_includes;
-    wxStringMap_t m_matches;
+    std::unordered_map<wxString, std::set<wxString> > m_matches;
 
 private:
     bool IsFileExists(const wxString& current_dir, const wxString& name, const wxArrayString& search_path,
-                      wxFileName* fixed_path);
+                      std::set<wxString>& fixed_path);
     void ParseUsingNamespace(CxxTokenizer& tokenizer, wxStringSet_t* using_ns_set);
 
     wxString fix_include_line(const wxString& include_line);
