@@ -223,6 +223,7 @@ private:
     void DoRecoverFromGitCommandError(bool clear_queue = true);
     void DoLoadBlameInfo(bool clearCache);
     void DoUpdateBlameInfo(const wxString& info, const wxString& fullpath);
+    void DoAnyFileModified();
     DECLARE_EVENT_TABLE()
 
     // Event handlers
@@ -236,6 +237,7 @@ private:
     void OnReplaceInFiles(clFileSystemEvent& event);
     void OnEditorChanged(wxCommandEvent& event);
     void OnFileSaved(clCommandEvent& e);
+    void OnFileModifiedExternally(clFileSystemEvent& e);
     void OnFilesAddedToProject(clCommandEvent& e);
     void OnFilesRemovedFromProject(clCommandEvent& e);
     void OnWorkspaceLoaded(clWorkspaceEvent& e);
@@ -267,6 +269,7 @@ private:
     void OnGarbageColletion(wxCommandEvent& e);
     void OnOpenMSYSGit(wxCommandEvent& e);
     void OnActiveProjectChanged(clProjectSettingsEvent& event);
+    void OnFileCommitListSelected(wxCommandEvent& e);
     void OnFileGitBlame(wxCommandEvent& event);
     void OnAppActivated(wxCommandEvent& event);
     void OnUpdateNavBar(clCodeCompletionEvent& event);
@@ -365,7 +368,7 @@ public:
     //--------------------------------------------
     // Abstract methods
     //--------------------------------------------
-    virtual void CreateToolBar(clToolBar* toolbar);
+    virtual void CreateToolBar(clToolBarGeneric* toolbar);
     virtual void CreatePluginMenu(wxMenu* pluginsMenu);
     virtual void HookPopupMenu(wxMenu* menu, MenuType type);
     virtual void UnPlug();
